pub fn order_mutation_from_create(
msg: &CreateOrderResponse,
) -> Result<OrderMutationResult>Expand description
CreateOrderResponse acknowledges admission only and no longer carries a
status field; synthesize "accepted".
pub fn order_mutation_from_create(
msg: &CreateOrderResponse,
) -> Result<OrderMutationResult>CreateOrderResponse acknowledges admission only and no longer carries a
status field; synthesize "accepted".