pub fn trigger_mutation_from_create(
msg: &CreateTriggerResponse,
) -> Result<TriggerMutationResult>Expand description
CreateTriggerResponse acknowledges admission only and no longer carries a
status field; synthesize "accepted".
pub fn trigger_mutation_from_create(
msg: &CreateTriggerResponse,
) -> Result<TriggerMutationResult>CreateTriggerResponse acknowledges admission only and no longer carries a
status field; synthesize "accepted".