Module v1

Module v1 

Structs

AddressBookServiceClient
Client for this service.
AddressBookServiceServer
Monomorphic dispatcher for AddressBookService.
ApiKeyServiceClient
Client for this service.
ApiKeyServiceServer
Monomorphic dispatcher for ApiKeyService.
AuthServiceClient
Client for this service.
AuthServiceServer
Monomorphic dispatcher for AuthService.
MfaServiceClient
Client for this service.
MfaServiceServer
Monomorphic dispatcher for MfaService.
PolicyServiceClient
Client for this service.
PolicyServiceServer
Monomorphic dispatcher for PolicyService.
ProfileServiceClient
Client for this service.
ProfileServiceServer
Monomorphic dispatcher for ProfileService.
ResolveServiceClient
Client for this service.
ResolveServiceServer
Monomorphic dispatcher for ResolveService.
SocialVerificationServiceClient
Client for this service.
SocialVerificationServiceServer
Monomorphic dispatcher for SocialVerificationService.
SubaccountServiceClient
Client for this service.
SubaccountServiceServer
Monomorphic dispatcher for SubaccountService.
SubaccountViewServiceClient
Client for this service.
SubaccountViewServiceServer
Monomorphic dispatcher for SubaccountViewService.

Constants

ADDRESS_BOOK_SERVICE_COPY_ADDRESS_BOOK_ENTRY_SPEC
Static Spec for the server-side CopyAddressBookEntry RPC.
ADDRESS_BOOK_SERVICE_CREATE_ADDRESS_BOOK_ENTRY_SPEC
Static Spec for the server-side CreateAddressBookEntry RPC.
ADDRESS_BOOK_SERVICE_CREATE_ADDRESS_BOOK_TAG_SPEC
Static Spec for the server-side CreateAddressBookTag RPC.
ADDRESS_BOOK_SERVICE_DELETE_ADDRESS_BOOK_ENTRY_SPEC
Static Spec for the server-side DeleteAddressBookEntry RPC.
ADDRESS_BOOK_SERVICE_DELETE_ADDRESS_BOOK_TAG_SPEC
Static Spec for the server-side DeleteAddressBookTag RPC.
ADDRESS_BOOK_SERVICE_GET_ADDRESS_BOOK_VIEW_SPEC
Static Spec for the server-side GetAddressBookView RPC.
ADDRESS_BOOK_SERVICE_GET_WITHDRAW_WHITELIST_VIEW_SPEC
Static Spec for the server-side GetWithdrawWhitelistView RPC.
ADDRESS_BOOK_SERVICE_LIST_ADDRESS_BOOKS_SPEC
Static Spec for the server-side ListAddressBooks RPC.
ADDRESS_BOOK_SERVICE_LIST_ADDRESS_BOOK_ENTRIES_SPEC
Static Spec for the server-side ListAddressBookEntries RPC.
ADDRESS_BOOK_SERVICE_LIST_INTERNAL_TRANSFER_WHITELIST_ENTRIES_SPEC
Static Spec for the server-side ListInternalTransferWhitelistEntries RPC.
ADDRESS_BOOK_SERVICE_LIST_TRANSFER_COUNTERPARTIES_SPEC
Static Spec for the server-side ListTransferCounterparties RPC.
ADDRESS_BOOK_SERVICE_LIST_TRANSFER_DESTINATIONS_SPEC
Static Spec for the server-side ListTransferDestinations RPC.
ADDRESS_BOOK_SERVICE_SERVICE_NAME
Full service name for this service.
ADDRESS_BOOK_SERVICE_UPDATE_ADDRESS_BOOK_ENTRY_SPEC
Static Spec for the server-side UpdateAddressBookEntry RPC.
ADDRESS_BOOK_SERVICE_UPDATE_ADDRESS_BOOK_TAG_SPEC
Static Spec for the server-side UpdateAddressBookTag RPC.
API_KEY_SERVICE_CREATE_API_KEY_SPEC
Static Spec for the server-side CreateApiKey RPC.
API_KEY_SERVICE_DELETE_API_KEY_SPEC
Static Spec for the server-side DeleteApiKey RPC.
API_KEY_SERVICE_GET_API_KEY_SPEC
Static Spec for the server-side GetApiKey RPC.
API_KEY_SERVICE_LIST_API_KEYS_SPEC
Static Spec for the server-side ListApiKeys RPC.
API_KEY_SERVICE_SERVICE_NAME
Full service name for this service.
API_KEY_SERVICE_UPDATE_API_KEY_SPEC
Static Spec for the server-side UpdateApiKey RPC.
AUTH_SERVICE_GET_NONCE_SPEC
Static Spec for the server-side GetNonce RPC.
AUTH_SERVICE_LOGIN_WITH_WALLET_SPEC
Static Spec for the server-side LoginWithWallet RPC.
AUTH_SERVICE_ME_SPEC
Static Spec for the server-side Me RPC.
AUTH_SERVICE_SERVICE_NAME
Full service name for this service.
MFA_SERVICE_BEGIN_MFA_CHALLENGE_SPEC
Static Spec for the server-side BeginMFAChallenge RPC.
MFA_SERVICE_BEGIN_PASSKEY_ENROLLMENT_SPEC
Static Spec for the server-side BeginPasskeyEnrollment RPC.
MFA_SERVICE_BEGIN_TOTP_ENROLLMENT_SPEC
Static Spec for the server-side BeginTOTPEnrollment RPC.
MFA_SERVICE_CLAIM_FRESH_STEP_UP_SPEC
Static Spec for the server-side ClaimFreshStepUp RPC.
MFA_SERVICE_CONSUME_FRESH_STEP_UP_SPEC
Static Spec for the server-side ConsumeFreshStepUp RPC.
MFA_SERVICE_DELETE_MFA_FACTOR_SPEC
Static Spec for the server-side DeleteMFAFactor RPC.
MFA_SERVICE_FINISH_PASSKEY_CHALLENGE_SPEC
Static Spec for the server-side FinishPasskeyChallenge RPC.
MFA_SERVICE_FINISH_PASSKEY_ENROLLMENT_SPEC
Static Spec for the server-side FinishPasskeyEnrollment RPC.
MFA_SERVICE_FINISH_TOTP_ENROLLMENT_SPEC
Static Spec for the server-side FinishTOTPEnrollment RPC.
MFA_SERVICE_LIST_MFA_FACTORS_SPEC
Static Spec for the server-side ListMFAFactors RPC.
MFA_SERVICE_REGENERATE_RECOVERY_CODES_SPEC
Static Spec for the server-side RegenerateRecoveryCodes RPC.
MFA_SERVICE_RELEASE_FRESH_STEP_UP_SPEC
Static Spec for the server-side ReleaseFreshStepUp RPC.
MFA_SERVICE_SERVICE_NAME
Full service name for this service.
MFA_SERVICE_UPDATE_MFA_FACTOR_SPEC
Static Spec for the server-side UpdateMFAFactor RPC.
MFA_SERVICE_VERIFY_RECOVERY_CODE_CHALLENGE_SPEC
Static Spec for the server-side VerifyRecoveryCodeChallenge RPC.
MFA_SERVICE_VERIFY_TOTP_CHALLENGE_SPEC
Static Spec for the server-side VerifyTOTPChallenge RPC.
POLICY_SERVICE_CREATE_API_POLICY_SPEC
Static Spec for the server-side CreateApiPolicy RPC.
POLICY_SERVICE_CREATE_SUBACCOUNT_POLICY_SPEC
Static Spec for the server-side CreateSubaccountPolicy RPC.
POLICY_SERVICE_DELETE_API_POLICY_SPEC
Static Spec for the server-side DeleteApiPolicy RPC.
POLICY_SERVICE_DELETE_SUBACCOUNT_POLICY_SPEC
Static Spec for the server-side DeleteSubaccountPolicy RPC.
POLICY_SERVICE_GET_API_POLICY_SPEC
Static Spec for the server-side GetApiPolicy RPC.
POLICY_SERVICE_GET_SUBACCOUNT_POLICY_SPEC
Static Spec for the server-side GetSubaccountPolicy RPC.
POLICY_SERVICE_LIST_API_POLICIES_SPEC
Static Spec for the server-side ListApiPolicies RPC.
POLICY_SERVICE_LIST_SUBACCOUNT_POLICIES_SPEC
Static Spec for the server-side ListSubaccountPolicies RPC.
POLICY_SERVICE_SERVICE_NAME
Full service name for this service.
POLICY_SERVICE_SET_API_KEY_POLICY_SPEC
Static Spec for the server-side SetApiKeyPolicy RPC.
POLICY_SERVICE_SET_SUBACCOUNT_POLICY_SPEC
Static Spec for the server-side SetSubaccountPolicy RPC.
POLICY_SERVICE_UPDATE_API_POLICY_SPEC
Static Spec for the server-side UpdateApiPolicy RPC.
POLICY_SERVICE_UPDATE_SUBACCOUNT_POLICY_SPEC
Static Spec for the server-side UpdateSubaccountPolicy RPC.
PROFILE_SERVICE_GET_PROFILE_SPEC
Static Spec for the server-side GetProfile RPC.
PROFILE_SERVICE_GET_USERNAME_HISTORY_SPEC
Static Spec for the server-side GetUsernameHistory RPC.
PROFILE_SERVICE_SERVICE_NAME
Full service name for this service.
PROFILE_SERVICE_UPDATE_PROFILE_SPEC
Static Spec for the server-side UpdateProfile RPC.
RESOLVE_SERVICE_RESOLVE_ACCOUNT_SPEC
Static Spec for the server-side ResolveAccount RPC.
RESOLVE_SERVICE_SERVICE_NAME
Full service name for this service.
SOCIAL_VERIFICATION_SERVICE_GET_SOCIAL_VERIFICATION_SPEC
Static Spec for the server-side GetSocialVerification RPC.
SOCIAL_VERIFICATION_SERVICE_SERVICE_NAME
Full service name for this service.
SOCIAL_VERIFICATION_SERVICE_SOCIAL_VERIFICATION_READY_SPEC
Static Spec for the server-side SocialVerificationReady RPC.
SOCIAL_VERIFICATION_SERVICE_START_SOCIAL_VERIFICATION_SPEC
Static Spec for the server-side StartSocialVerification RPC.
SUBACCOUNT_SERVICE_CREATE_SUBACCOUNT_SPEC
Static Spec for the server-side CreateSubaccount RPC.
SUBACCOUNT_SERVICE_INVITE_SUBACCOUNT_MEMBER_SPEC
Static Spec for the server-side InviteSubaccountMember RPC.
SUBACCOUNT_SERVICE_LIST_SUBACCOUNTS_SPEC
Static Spec for the server-side ListSubaccounts RPC.
SUBACCOUNT_SERVICE_LIST_SUBACCOUNT_INVITES_SPEC
Static Spec for the server-side ListSubaccountInvites RPC.
SUBACCOUNT_SERVICE_LIST_SUBACCOUNT_MEMBERS_SPEC
Static Spec for the server-side ListSubaccountMembers RPC.
SUBACCOUNT_SERVICE_REMOVE_SUBACCOUNT_MEMBER_SPEC
Static Spec for the server-side RemoveSubaccountMember RPC.
SUBACCOUNT_SERVICE_RESPOND_SUBACCOUNT_INVITE_SPEC
Static Spec for the server-side RespondSubaccountInvite RPC.
SUBACCOUNT_SERVICE_SERVICE_NAME
Full service name for this service.
SUBACCOUNT_SERVICE_SET_SUBACCOUNT_MEMBER_MFA_REQUIREMENT_SPEC
Static Spec for the server-side SetSubaccountMemberMFARequirement RPC.
SUBACCOUNT_SERVICE_UPDATE_SUBACCOUNT_MEMBER_ROLE_SPEC
Static Spec for the server-side UpdateSubaccountMemberRole RPC.
SUBACCOUNT_SERVICE_UPDATE_SUBACCOUNT_SPEC
Static Spec for the server-side UpdateSubaccount RPC.
SUBACCOUNT_VIEW_SERVICE_GET_SUBACCOUNT_SPEC
Static Spec for the server-side GetSubaccount RPC.
SUBACCOUNT_VIEW_SERVICE_LIST_SUBACCOUNT_ACTIVITY_SPEC
Static Spec for the server-side ListSubaccountActivity RPC.
SUBACCOUNT_VIEW_SERVICE_SERVICE_NAME
Full service name for this service.

Traits

AddressBookService
Server trait for AddressBookService.
AddressBookServiceExt
Extension trait for registering a service implementation with a Router.
ApiKeyService
ApiKeyService manages API keys for authenticated callers.
ApiKeyServiceExt
Extension trait for registering a service implementation with a Router.
AuthService
AuthService manages wallet login and caller authentication context.
AuthServiceExt
Extension trait for registering a service implementation with a Router.
MfaService
MFA management service for enrollment, challenges, fresh step-up proofs, and recovery codes.
MfaServiceExt
Extension trait for registering a service implementation with a Router.
PolicyService
PolicyService manages sub-account and API key policy templates and bindings.
PolicyServiceExt
Extension trait for registering a service implementation with a Router.
ProfileService
ProfileService manages the authenticated caller’s public profile.
ProfileServiceExt
Extension trait for registering a service implementation with a Router.
ResolveService
ResolveService resolves authenticated account destinations for sharing and transfer flows.
ResolveServiceExt
Extension trait for registering a service implementation with a Router.
SocialVerificationService
SocialVerificationService verifies ownership of external social accounts.
SocialVerificationServiceExt
Extension trait for registering a service implementation with a Router.
SubaccountService
Service for creating, updating, sharing, and listing sub-accounts.
SubaccountServiceExt
Extension trait for registering a service implementation with a Router.
SubaccountViewService
Read service for aggregated sub-account pages.
SubaccountViewServiceExt
Extension trait for registering a service implementation with a Router.

Type Aliases

OwnedBeginMfaChallengeRequestView
Shorthand for OwnedView<BeginMfaChallengeRequestView<'static>>.
OwnedBeginMfaChallengeResponseView
Shorthand for OwnedView<BeginMfaChallengeResponseView<'static>>.
OwnedBeginPasskeyEnrollmentRequestView
Shorthand for OwnedView<BeginPasskeyEnrollmentRequestView<'static>>.
OwnedBeginPasskeyEnrollmentResponseView
Shorthand for OwnedView<BeginPasskeyEnrollmentResponseView<'static>>.
OwnedBeginTotpEnrollmentRequestView
Shorthand for OwnedView<BeginTotpEnrollmentRequestView<'static>>.
OwnedBeginTotpEnrollmentResponseView
Shorthand for OwnedView<BeginTotpEnrollmentResponseView<'static>>.
OwnedClaimFreshStepUpRequestView
Shorthand for OwnedView<ClaimFreshStepUpRequestView<'static>>.
OwnedClaimFreshStepUpResponseView
Shorthand for OwnedView<ClaimFreshStepUpResponseView<'static>>.
OwnedCompleteMfaChallengeResponseView
Shorthand for OwnedView<CompleteMfaChallengeResponseView<'static>>.
OwnedConsumeFreshStepUpRequestView
Shorthand for OwnedView<ConsumeFreshStepUpRequestView<'static>>.
OwnedConsumeFreshStepUpResponseView
Shorthand for OwnedView<ConsumeFreshStepUpResponseView<'static>>.
OwnedCopyAddressBookEntryRequestView
Shorthand for OwnedView<CopyAddressBookEntryRequestView<'static>>.
OwnedCopyAddressBookEntryResponseView
Shorthand for OwnedView<CopyAddressBookEntryResponseView<'static>>.
OwnedCreateAddressBookEntryRequestView
Shorthand for OwnedView<CreateAddressBookEntryRequestView<'static>>.
OwnedCreateAddressBookEntryResponseView
Shorthand for OwnedView<CreateAddressBookEntryResponseView<'static>>.
OwnedCreateAddressBookTagRequestView
Shorthand for OwnedView<CreateAddressBookTagRequestView<'static>>.
OwnedCreateAddressBookTagResponseView
Shorthand for OwnedView<CreateAddressBookTagResponseView<'static>>.
OwnedCreateApiKeyRequestView
Shorthand for OwnedView<CreateApiKeyRequestView<'static>>.
OwnedCreateApiKeyResponseView
Shorthand for OwnedView<CreateApiKeyResponseView<'static>>.
OwnedCreateApiPolicyRequestView
Shorthand for OwnedView<CreateApiPolicyRequestView<'static>>.
OwnedCreateApiPolicyResponseView
Shorthand for OwnedView<CreateApiPolicyResponseView<'static>>.
OwnedCreateSubaccountPolicyRequestView
Shorthand for OwnedView<CreateSubaccountPolicyRequestView<'static>>.
OwnedCreateSubaccountPolicyResponseView
Shorthand for OwnedView<CreateSubaccountPolicyResponseView<'static>>.
OwnedCreateSubaccountRequestView
Shorthand for OwnedView<CreateSubaccountRequestView<'static>>.
OwnedCreateSubaccountResponseView
Shorthand for OwnedView<CreateSubaccountResponseView<'static>>.
OwnedDeleteAddressBookEntryRequestView
Shorthand for OwnedView<DeleteAddressBookEntryRequestView<'static>>.
OwnedDeleteAddressBookEntryResponseView
Shorthand for OwnedView<DeleteAddressBookEntryResponseView<'static>>.
OwnedDeleteAddressBookTagRequestView
Shorthand for OwnedView<DeleteAddressBookTagRequestView<'static>>.
OwnedDeleteAddressBookTagResponseView
Shorthand for OwnedView<DeleteAddressBookTagResponseView<'static>>.
OwnedDeleteApiKeyRequestView
Shorthand for OwnedView<DeleteApiKeyRequestView<'static>>.
OwnedDeleteApiKeyResponseView
Shorthand for OwnedView<DeleteApiKeyResponseView<'static>>.
OwnedDeleteApiPolicyRequestView
Shorthand for OwnedView<DeleteApiPolicyRequestView<'static>>.
OwnedDeleteApiPolicyResponseView
Shorthand for OwnedView<DeleteApiPolicyResponseView<'static>>.
OwnedDeleteMfaFactorRequestView
Shorthand for OwnedView<DeleteMfaFactorRequestView<'static>>.
OwnedDeleteMfaFactorResponseView
Shorthand for OwnedView<DeleteMfaFactorResponseView<'static>>.
OwnedDeleteSubaccountPolicyRequestView
Shorthand for OwnedView<DeleteSubaccountPolicyRequestView<'static>>.
OwnedDeleteSubaccountPolicyResponseView
Shorthand for OwnedView<DeleteSubaccountPolicyResponseView<'static>>.
OwnedFinishPasskeyChallengeRequestView
Shorthand for OwnedView<FinishPasskeyChallengeRequestView<'static>>.
OwnedFinishPasskeyEnrollmentRequestView
Shorthand for OwnedView<FinishPasskeyEnrollmentRequestView<'static>>.
OwnedFinishPasskeyEnrollmentResponseView
Shorthand for OwnedView<FinishPasskeyEnrollmentResponseView<'static>>.
OwnedFinishTotpEnrollmentRequestView
Shorthand for OwnedView<FinishTotpEnrollmentRequestView<'static>>.
OwnedFinishTotpEnrollmentResponseView
Shorthand for OwnedView<FinishTotpEnrollmentResponseView<'static>>.
OwnedGetAddressBookViewRequestView
Shorthand for OwnedView<GetAddressBookViewRequestView<'static>>.
OwnedGetAddressBookViewResponseView
Shorthand for OwnedView<GetAddressBookViewResponseView<'static>>.
OwnedGetApiKeyRequestView
Shorthand for OwnedView<GetApiKeyRequestView<'static>>.
OwnedGetApiKeyResponseView
Shorthand for OwnedView<GetApiKeyResponseView<'static>>.
OwnedGetApiPolicyRequestView
Shorthand for OwnedView<GetApiPolicyRequestView<'static>>.
OwnedGetApiPolicyResponseView
Shorthand for OwnedView<GetApiPolicyResponseView<'static>>.
OwnedGetNonceRequestView
Shorthand for OwnedView<GetNonceRequestView<'static>>.
OwnedGetNonceResponseView
Shorthand for OwnedView<GetNonceResponseView<'static>>.
OwnedGetProfileRequestView
Shorthand for OwnedView<GetProfileRequestView<'static>>.
OwnedGetSocialVerificationRequestView
Shorthand for OwnedView<GetSocialVerificationRequestView<'static>>.
OwnedGetSocialVerificationResponseView
Shorthand for OwnedView<GetSocialVerificationResponseView<'static>>.
OwnedGetSubaccountPolicyRequestView
Shorthand for OwnedView<GetSubaccountPolicyRequestView<'static>>.
OwnedGetSubaccountPolicyResponseView
Shorthand for OwnedView<GetSubaccountPolicyResponseView<'static>>.
OwnedGetSubaccountRequestView
Shorthand for OwnedView<GetSubaccountRequestView<'static>>.
OwnedGetSubaccountResponseView
Shorthand for OwnedView<GetSubaccountResponseView<'static>>.
OwnedGetUsernameHistoryRequestView
Shorthand for OwnedView<GetUsernameHistoryRequestView<'static>>.
OwnedGetUsernameHistoryResponseView
Shorthand for OwnedView<GetUsernameHistoryResponseView<'static>>.
OwnedGetWithdrawWhitelistViewRequestView
Shorthand for OwnedView<GetWithdrawWhitelistViewRequestView<'static>>.
OwnedGetWithdrawWhitelistViewResponseView
Shorthand for OwnedView<GetWithdrawWhitelistViewResponseView<'static>>.
OwnedInviteSubaccountMemberRequestView
Shorthand for OwnedView<InviteSubaccountMemberRequestView<'static>>.
OwnedInviteSubaccountMemberResponseView
Shorthand for OwnedView<InviteSubaccountMemberResponseView<'static>>.
OwnedListAddressBookEntriesRequestView
Shorthand for OwnedView<ListAddressBookEntriesRequestView<'static>>.
OwnedListAddressBookEntriesResponseView
Shorthand for OwnedView<ListAddressBookEntriesResponseView<'static>>.
OwnedListAddressBooksRequestView
Shorthand for OwnedView<ListAddressBooksRequestView<'static>>.
OwnedListAddressBooksResponseView
Shorthand for OwnedView<ListAddressBooksResponseView<'static>>.
OwnedListApiKeysRequestView
Shorthand for OwnedView<ListApiKeysRequestView<'static>>.
OwnedListApiKeysResponseView
Shorthand for OwnedView<ListApiKeysResponseView<'static>>.
OwnedListApiPoliciesRequestView
Shorthand for OwnedView<ListApiPoliciesRequestView<'static>>.
OwnedListApiPoliciesResponseView
Shorthand for OwnedView<ListApiPoliciesResponseView<'static>>.
OwnedListInternalTransferWhitelistEntriesRequestView
Shorthand for OwnedView<ListInternalTransferWhitelistEntriesRequestView<'static>>.
OwnedListInternalTransferWhitelistEntriesResponseView
Shorthand for OwnedView<ListInternalTransferWhitelistEntriesResponseView<'static>>.
OwnedListMfaFactorsRequestView
Shorthand for OwnedView<ListMfaFactorsRequestView<'static>>.
OwnedListMfaFactorsResponseView
Shorthand for OwnedView<ListMfaFactorsResponseView<'static>>.
OwnedListSubaccountEventsRequestView
Shorthand for OwnedView<ListSubaccountEventsRequestView<'static>>.
OwnedListSubaccountEventsResponseView
Shorthand for OwnedView<ListSubaccountEventsResponseView<'static>>.
OwnedListSubaccountInvitesRequestView
Shorthand for OwnedView<ListSubaccountInvitesRequestView<'static>>.
OwnedListSubaccountInvitesResponseView
Shorthand for OwnedView<ListSubaccountInvitesResponseView<'static>>.
OwnedListSubaccountMembersRequestView
Shorthand for OwnedView<ListSubaccountMembersRequestView<'static>>.
OwnedListSubaccountMembersResponseView
Shorthand for OwnedView<ListSubaccountMembersResponseView<'static>>.
OwnedListSubaccountPoliciesRequestView
Shorthand for OwnedView<ListSubaccountPoliciesRequestView<'static>>.
OwnedListSubaccountPoliciesResponseView
Shorthand for OwnedView<ListSubaccountPoliciesResponseView<'static>>.
OwnedListSubaccountsRequestView
Shorthand for OwnedView<ListSubaccountsRequestView<'static>>.
OwnedListSubaccountsResponseView
Shorthand for OwnedView<ListSubaccountsResponseView<'static>>.
OwnedListTransferCounterpartiesRequestView
Shorthand for OwnedView<ListTransferCounterpartiesRequestView<'static>>.
OwnedListTransferCounterpartiesResponseView
Shorthand for OwnedView<ListTransferCounterpartiesResponseView<'static>>.
OwnedListTransferDestinationsRequestView
Shorthand for OwnedView<ListTransferDestinationsRequestView<'static>>.
OwnedListTransferDestinationsResponseView
Shorthand for OwnedView<ListTransferDestinationsResponseView<'static>>.
OwnedLoginWithWalletRequestView
Shorthand for OwnedView<LoginWithWalletRequestView<'static>>.
OwnedLoginWithWalletResponseView
Shorthand for OwnedView<LoginWithWalletResponseView<'static>>.
OwnedMeRequestView
Shorthand for OwnedView<MeRequestView<'static>>.
OwnedMeResponseView
Shorthand for OwnedView<MeResponseView<'static>>.
OwnedRegenerateRecoveryCodesRequestView
Shorthand for OwnedView<RegenerateRecoveryCodesRequestView<'static>>.
OwnedRegenerateRecoveryCodesResponseView
Shorthand for OwnedView<RegenerateRecoveryCodesResponseView<'static>>.
OwnedReleaseFreshStepUpRequestView
Shorthand for OwnedView<ReleaseFreshStepUpRequestView<'static>>.
OwnedReleaseFreshStepUpResponseView
Shorthand for OwnedView<ReleaseFreshStepUpResponseView<'static>>.
OwnedRemoveSubaccountMemberRequestView
Shorthand for OwnedView<RemoveSubaccountMemberRequestView<'static>>.
OwnedRemoveSubaccountMemberResponseView
Shorthand for OwnedView<RemoveSubaccountMemberResponseView<'static>>.
OwnedResolveAccountRequestView
Shorthand for OwnedView<ResolveAccountRequestView<'static>>.
OwnedResolveAccountResponseView
Shorthand for OwnedView<ResolveAccountResponseView<'static>>.
OwnedRespondSubaccountInviteRequestView
Shorthand for OwnedView<RespondSubaccountInviteRequestView<'static>>.
OwnedRespondSubaccountInviteResponseView
Shorthand for OwnedView<RespondSubaccountInviteResponseView<'static>>.
OwnedSetApiKeyPolicyRequestView
Shorthand for OwnedView<SetApiKeyPolicyRequestView<'static>>.
OwnedSetApiKeyPolicyResponseView
Shorthand for OwnedView<SetApiKeyPolicyResponseView<'static>>.
OwnedSetSubaccountMemberMfaRequirementRequestView
Shorthand for OwnedView<SetSubaccountMemberMfaRequirementRequestView<'static>>.
OwnedSetSubaccountMemberMfaRequirementResponseView
Shorthand for OwnedView<SetSubaccountMemberMfaRequirementResponseView<'static>>.
OwnedSetSubaccountPolicyRequestView
Shorthand for OwnedView<SetSubaccountPolicyRequestView<'static>>.
OwnedSetSubaccountPolicyResponseView
Shorthand for OwnedView<SetSubaccountPolicyResponseView<'static>>.
OwnedSocialVerificationReadyRequestView
Shorthand for OwnedView<SocialVerificationReadyRequestView<'static>>.
OwnedSocialVerificationReadyResponseView
Shorthand for OwnedView<SocialVerificationReadyResponseView<'static>>.
OwnedStartSocialVerificationRequestView
Shorthand for OwnedView<StartSocialVerificationRequestView<'static>>.
OwnedStartSocialVerificationResponseView
Shorthand for OwnedView<StartSocialVerificationResponseView<'static>>.
OwnedUpdateAddressBookEntryRequestView
Shorthand for OwnedView<UpdateAddressBookEntryRequestView<'static>>.
OwnedUpdateAddressBookEntryResponseView
Shorthand for OwnedView<UpdateAddressBookEntryResponseView<'static>>.
OwnedUpdateAddressBookTagRequestView
Shorthand for OwnedView<UpdateAddressBookTagRequestView<'static>>.
OwnedUpdateAddressBookTagResponseView
Shorthand for OwnedView<UpdateAddressBookTagResponseView<'static>>.
OwnedUpdateApiKeyRequestView
Shorthand for OwnedView<UpdateApiKeyRequestView<'static>>.
OwnedUpdateApiKeyResponseView
Shorthand for OwnedView<UpdateApiKeyResponseView<'static>>.
OwnedUpdateApiPolicyRequestView
Shorthand for OwnedView<UpdateApiPolicyRequestView<'static>>.
OwnedUpdateApiPolicyResponseView
Shorthand for OwnedView<UpdateApiPolicyResponseView<'static>>.
OwnedUpdateMfaFactorRequestView
Shorthand for OwnedView<UpdateMfaFactorRequestView<'static>>.
OwnedUpdateMfaFactorResponseView
Shorthand for OwnedView<UpdateMfaFactorResponseView<'static>>.
OwnedUpdateSubaccountMemberRoleRequestView
Shorthand for OwnedView<UpdateSubaccountMemberRoleRequestView<'static>>.
OwnedUpdateSubaccountMemberRoleResponseView
Shorthand for OwnedView<UpdateSubaccountMemberRoleResponseView<'static>>.
OwnedUpdateSubaccountPolicyRequestView
Shorthand for OwnedView<UpdateSubaccountPolicyRequestView<'static>>.
OwnedUpdateSubaccountPolicyResponseView
Shorthand for OwnedView<UpdateSubaccountPolicyResponseView<'static>>.
OwnedUpdateSubaccountRequestView
Shorthand for OwnedView<UpdateSubaccountRequestView<'static>>.
OwnedUpdateSubaccountResponseView
Shorthand for OwnedView<UpdateSubaccountResponseView<'static>>.
OwnedUserProfilePatchView
Shorthand for OwnedView<UserProfilePatchView<'static>>.
OwnedUserProfileView
Shorthand for OwnedView<UserProfileView<'static>>.
OwnedVerifyRecoveryCodeChallengeRequestView
Shorthand for OwnedView<VerifyRecoveryCodeChallengeRequestView<'static>>.
OwnedVerifyTotpChallengeRequestView
Shorthand for OwnedView<VerifyTotpChallengeRequestView<'static>>.