Module v1

Module v1 

Structs

LayoutServiceClient
Client for this service.
LayoutServiceServer
Monomorphic dispatcher for LayoutService.

Constants

LAYOUT_SERVICE_CREATE_LAYOUT_SHARE_LINK_SPEC
Static Spec for the server-side CreateLayoutShareLink RPC.
LAYOUT_SERVICE_DELETE_LAYOUT_SPEC
Static Spec for the server-side DeleteLayout RPC.
LAYOUT_SERVICE_DELETE_LAYOUT_TEMPLATE_SUBSCRIPTION_SPEC
Static Spec for the server-side DeleteLayoutTemplateSubscription RPC.
LAYOUT_SERVICE_GET_LAYOUTS_SPEC
Static Spec for the server-side GetLayouts RPC.
LAYOUT_SERVICE_GET_LAYOUT_SPEC
Static Spec for the server-side GetLayout RPC.
LAYOUT_SERVICE_GET_LAYOUT_TEMPLATE_VERSION_SPEC
Static Spec for the server-side GetLayoutTemplateVersion RPC.
LAYOUT_SERVICE_LIST_LAYOUT_TEMPLATE_VERSIONS_SPEC
Static Spec for the server-side ListLayoutTemplateVersions RPC.
LAYOUT_SERVICE_LIST_MY_LAYOUT_TEMPLATE_SUBSCRIPTIONS_SPEC
Static Spec for the server-side ListMyLayoutTemplateSubscriptions RPC.
LAYOUT_SERVICE_LIST_OWNER_PUBLISHED_LAYOUTS_SPEC
Static Spec for the server-side ListOwnerPublishedLayouts RPC.
LAYOUT_SERVICE_PUBLISH_LAYOUT_SPEC
Static Spec for the server-side PublishLayout RPC.
LAYOUT_SERVICE_RESOLVE_LAYOUT_SHARE_TOKEN_SPEC
Static Spec for the server-side ResolveLayoutShareToken RPC.
LAYOUT_SERVICE_REVOKE_LAYOUT_SHARE_LINK_SPEC
Static Spec for the server-side RevokeLayoutShareLink RPC.
LAYOUT_SERVICE_SERVICE_NAME
Full service name for this service.
LAYOUT_SERVICE_SET_LAYOUT_TEMPLATE_SUBSCRIPTION_SPEC
Static Spec for the server-side SetLayoutTemplateSubscription RPC.
LAYOUT_SERVICE_UNPUBLISH_LAYOUT_SPEC
Static Spec for the server-side UnpublishLayout RPC.
LAYOUT_SERVICE_UPSERT_LAYOUT_SPEC
Static Spec for the server-side UpsertLayout RPC.

Traits

LayoutService
LayoutService persists saved layouts and manages public layout sharing.
LayoutServiceExt
Extension trait for registering a service implementation with a Router.

Type Aliases

OwnedCreateLayoutShareLinkRequestView
Shorthand for OwnedView<CreateLayoutShareLinkRequestView<'static>>.
OwnedCreateLayoutShareLinkResponseView
Shorthand for OwnedView<CreateLayoutShareLinkResponseView<'static>>.
OwnedDeleteLayoutRequestView
Shorthand for OwnedView<DeleteLayoutRequestView<'static>>.
OwnedDeleteLayoutResponseView
Shorthand for OwnedView<DeleteLayoutResponseView<'static>>.
OwnedDeleteLayoutTemplateSubscriptionRequestView
Shorthand for OwnedView<DeleteLayoutTemplateSubscriptionRequestView<'static>>.
OwnedDeleteLayoutTemplateSubscriptionResponseView
Shorthand for OwnedView<DeleteLayoutTemplateSubscriptionResponseView<'static>>.
OwnedGetLayoutRequestView
Shorthand for OwnedView<GetLayoutRequestView<'static>>.
OwnedGetLayoutResponseView
Shorthand for OwnedView<GetLayoutResponseView<'static>>.
OwnedGetLayoutTemplateVersionRequestView
Shorthand for OwnedView<GetLayoutTemplateVersionRequestView<'static>>.
OwnedGetLayoutTemplateVersionResponseView
Shorthand for OwnedView<GetLayoutTemplateVersionResponseView<'static>>.
OwnedGetLayoutsRequestView
Shorthand for OwnedView<GetLayoutsRequestView<'static>>.
OwnedGetLayoutsResponseView
Shorthand for OwnedView<GetLayoutsResponseView<'static>>.
OwnedListLayoutTemplateVersionsRequestView
Shorthand for OwnedView<ListLayoutTemplateVersionsRequestView<'static>>.
OwnedListLayoutTemplateVersionsResponseView
Shorthand for OwnedView<ListLayoutTemplateVersionsResponseView<'static>>.
OwnedListMyLayoutTemplateSubscriptionsRequestView
Shorthand for OwnedView<ListMyLayoutTemplateSubscriptionsRequestView<'static>>.
OwnedListMyLayoutTemplateSubscriptionsResponseView
Shorthand for OwnedView<ListMyLayoutTemplateSubscriptionsResponseView<'static>>.
OwnedListOwnerPublishedLayoutsRequestView
Shorthand for OwnedView<ListOwnerPublishedLayoutsRequestView<'static>>.
OwnedListOwnerPublishedLayoutsResponseView
Shorthand for OwnedView<ListOwnerPublishedLayoutsResponseView<'static>>.
OwnedPublishLayoutRequestView
Shorthand for OwnedView<PublishLayoutRequestView<'static>>.
OwnedPublishLayoutResponseView
Shorthand for OwnedView<PublishLayoutResponseView<'static>>.
OwnedResolveLayoutShareTokenRequestView
Shorthand for OwnedView<ResolveLayoutShareTokenRequestView<'static>>.
OwnedResolveLayoutShareTokenResponseView
Shorthand for OwnedView<ResolveLayoutShareTokenResponseView<'static>>.
OwnedRevokeLayoutShareLinkRequestView
Shorthand for OwnedView<RevokeLayoutShareLinkRequestView<'static>>.
OwnedRevokeLayoutShareLinkResponseView
Shorthand for OwnedView<RevokeLayoutShareLinkResponseView<'static>>.
OwnedSetLayoutTemplateSubscriptionRequestView
Shorthand for OwnedView<SetLayoutTemplateSubscriptionRequestView<'static>>.
OwnedSetLayoutTemplateSubscriptionResponseView
Shorthand for OwnedView<SetLayoutTemplateSubscriptionResponseView<'static>>.
OwnedUnpublishLayoutRequestView
Shorthand for OwnedView<UnpublishLayoutRequestView<'static>>.
OwnedUnpublishLayoutResponseView
Shorthand for OwnedView<UnpublishLayoutResponseView<'static>>.
OwnedUpsertLayoutRequestView
Shorthand for OwnedView<UpsertLayoutRequestView<'static>>.
OwnedUpsertLayoutResponseView
Shorthand for OwnedView<UpsertLayoutResponseView<'static>>.