Module v1

Module v1 

Structs

HeatmapServiceClient
Client for this service.
HeatmapServiceServer
Monomorphic dispatcher for HeatmapService.
MarketDataServiceClient
Client for this service.
MarketDataServiceServer
Monomorphic dispatcher for MarketDataService.

Constants

HEATMAP_SERVICE_GET_ORDERBOOK_HEATMAP_SPEC
Static Spec for the server-side GetOrderbookHeatmap RPC.
HEATMAP_SERVICE_SERVICE_NAME
Full service name for this service.
MARKET_DATA_SERVICE_GET_CANDLES_COLUMNS_SPEC
Static Spec for the server-side GetCandlesColumns RPC.
MARKET_DATA_SERVICE_GET_CANDLES_SPEC
Static Spec for the server-side GetCandles RPC.
MARKET_DATA_SERVICE_GET_SPOT_CONFIG_SPEC
Static Spec for the server-side GetSpotConfig RPC.
MARKET_DATA_SERVICE_GET_TRADES_SPEC
Static Spec for the server-side GetTrades RPC.
MARKET_DATA_SERVICE_SERVICE_NAME
Full service name for this service.

Traits

HeatmapService
HeatmapService serves historical orderbook heatmap chains.
HeatmapServiceExt
Extension trait for registering a service implementation with a Router.
MarketDataService
Server trait for MarketDataService.
MarketDataServiceExt
Extension trait for registering a service implementation with a Router.

Type Aliases

OwnedGetCandlesColumnsRequestView
Shorthand for OwnedView<GetCandlesColumnsRequestView<'static>>.
OwnedGetCandlesColumnsResponseView
Shorthand for OwnedView<GetCandlesColumnsResponseView<'static>>.
OwnedGetCandlesRequestView
Shorthand for OwnedView<GetCandlesRequestView<'static>>.
OwnedGetCandlesResponseView
Shorthand for OwnedView<GetCandlesResponseView<'static>>.
OwnedGetOrderbookHeatmapRequestView
Shorthand for OwnedView<GetOrderbookHeatmapRequestView<'static>>.
OwnedGetOrderbookHeatmapResponseView
Shorthand for OwnedView<GetOrderbookHeatmapResponseView<'static>>.
OwnedGetSpotConfigRequestView
Shorthand for OwnedView<GetSpotConfigRequestView<'static>>.
OwnedGetSpotConfigResponseView
Shorthand for OwnedView<GetSpotConfigResponseView<'static>>.
OwnedGetTradesRequestView
Shorthand for OwnedView<GetTradesRequestView<'static>>.
OwnedGetTradesResponseView
Shorthand for OwnedView<GetTradesResponseView<'static>>.