Module v1

Module v1 

Structs

InternalTransferServiceClient
Client for this service.
InternalTransferServiceServer
Monomorphic dispatcher for InternalTransferService.

Constants

INTERNAL_TRANSFER_SERVICE_CREATE_INTERNAL_TRANSFER_SPEC
Static Spec for the server-side CreateInternalTransfer RPC.
INTERNAL_TRANSFER_SERVICE_SERVICE_NAME
Full service name for this service.

Traits

InternalTransferService
InternalTransferService manages authenticated Trading to Trading internal transfer intake.
InternalTransferServiceExt
Extension trait for registering a service implementation with a Router.

Type Aliases

OwnedCreateInternalTransferRequestView
Shorthand for OwnedView<CreateInternalTransferRequestView<'static>>.
OwnedCreateInternalTransferResponseView
Shorthand for OwnedView<CreateInternalTransferResponseView<'static>>.