pub struct UserTrade {
pub symbol_id: u32,
pub match_id: String,
pub order_id: String,
pub side: String,
pub is_maker: bool,
pub price: Option<Price>,
pub qty: Option<Quantity>,
pub fee_amount_e18: String,
pub fee_asset: String,
pub referral_share_amount_e18: String,
pub ts_ns: String,
pub fee_is_rebate: bool,
}Fields
symbol_id: u32match_id: Stringorder_id: Stringside: Stringis_maker: boolprice: Option<Price>qty: Option<Quantity>fee_amount_e18: StringExact fee magnitude in fixed 18-decimal units of fee_asset.
fee_asset: StringAsset used to pay/credit the fee: quote, base, or an
UNKNOWN(<number>) forward-compatible enum value.
Exact referral share magnitude in fixed 18-decimal units of fee_asset.
ts_ns: Stringfee_is_rebate: boolTrue when fee_amount_e18 is a rebate credit instead of a fee debit.
Proto3 omits false, so sparse wire encoding only sets this for rebates.