#[repr(i32)]pub enum DestinationWhitelistStatus {
DESTINATION_WHITELIST_STATUS_UNSPECIFIED = 0,
DESTINATION_NOT_WHITELISTED = 1,
DESTINATION_WHITELIST_ACTIVE = 2,
DESTINATION_WHITELIST_UNRESOLVED = 3,
}Expand description
DestinationWhitelistStatus describes whether a transfer destination currently has an active whitelist allowance.
Variants
DESTINATION_WHITELIST_STATUS_UNSPECIFIED = 0
Whitelist status is not specified.
DESTINATION_NOT_WHITELISTED = 1
Destination is not whitelisted.
DESTINATION_WHITELIST_ACTIVE = 2
Destination has an active whitelist entry and can be used now.
DESTINATION_WHITELIST_UNRESOLVED = 3
Whitelist status could not be resolved for this destination.
Implementations
Sourceimpl DestinationWhitelistStatus
impl DestinationWhitelistStatus
Sourcepub const DestinationWhitelistStatusUnspecified: Self = Self::DESTINATION_WHITELIST_STATUS_UNSPECIFIED
pub const DestinationWhitelistStatusUnspecified: Self = Self::DESTINATION_WHITELIST_STATUS_UNSPECIFIED
Idiomatic alias for Self::DESTINATION_WHITELIST_STATUS_UNSPECIFIED; Debug prints the variant name.
Sourcepub const DestinationNotWhitelisted: Self = Self::DESTINATION_NOT_WHITELISTED
pub const DestinationNotWhitelisted: Self = Self::DESTINATION_NOT_WHITELISTED
Idiomatic alias for Self::DESTINATION_NOT_WHITELISTED; Debug prints the variant name.
Sourcepub const DestinationWhitelistActive: Self = Self::DESTINATION_WHITELIST_ACTIVE
pub const DestinationWhitelistActive: Self = Self::DESTINATION_WHITELIST_ACTIVE
Idiomatic alias for Self::DESTINATION_WHITELIST_ACTIVE; Debug prints the variant name.
Sourcepub const DestinationWhitelistUnresolved: Self = Self::DESTINATION_WHITELIST_UNRESOLVED
pub const DestinationWhitelistUnresolved: Self = Self::DESTINATION_WHITELIST_UNRESOLVED
Idiomatic alias for Self::DESTINATION_WHITELIST_UNRESOLVED; Debug prints the variant name.