PolicyAction

Enum PolicyAction 

#[repr(i32)]
pub enum PolicyAction {
Show 13 variants UNSPECIFIED = 0, TRADE_SPOT = 1, TRADE_PERP = 2, INTERNAL_TRANSFER = 3, EXTERNAL_WITHDRAW = 4, READ_BALANCES = 5, READ_SPOT = 6, READ_PERP = 7, READ_INTERNAL_TRANSFERS = 8, READ_EXTERNAL_WITHDRAWALS = 9, READ_TRANSFER_CONTROLS = 11, MANAGE_ADDRESS_BOOK = 12, MANAGE_TRANSFER_WHITELISTS = 13,
}
PolicyAction is a high-level permission that can be granted by a policy. Write-style actions also grant the matching read visibility where needed by the product experience.

Variants



UNSPECIFIED = 0

No policy action selected. Requests must choose one or more explicit actions.



TRADE_SPOT = 1

Allow placing/modifying/cancelling spot orders.



TRADE_PERP = 2

Allow placing/modifying/cancelling perpetual futures orders.



INTERNAL_TRANSFER = 3

Allow internal transfers between sub-accounts or linked Polyester accounts.



EXTERNAL_WITHDRAW = 4

Allow external withdrawals to whitelisted addresses.



READ_BALANCES = 5

Allow reading balances, positions and equity for a sub-account or API key.



READ_SPOT = 6

Allow reading spot orders/trades/positions (no write).



READ_PERP = 7

Allow reading perp orders/trades/positions (no write).



READ_INTERNAL_TRANSFERS = 8

Allow reading internal transfer history.



READ_EXTERNAL_WITHDRAWALS = 9

Allow reading external withdrawal history.



READ_TRANSFER_CONTROLS = 11

Allow listing destination books, address book entries, recents, and mirrored whitelist state.



MANAGE_ADDRESS_BOOK = 12

Allow creating, updating, deleting, and copying saved destination entries.



MANAGE_TRANSFER_WHITELISTS = 13

Allow mutating internal-transfer whitelist rows and requesting withdraw whitelist changes.

Implementations

Source

impl PolicyAction

pub const Unspecified: Self = Self::UNSPECIFIED

Idiomatic alias for Self::UNSPECIFIED; Debug prints the variant name.

pub const TradeSpot: Self = Self::TRADE_SPOT

Idiomatic alias for Self::TRADE_SPOT; Debug prints the variant name.

pub const TradePerp: Self = Self::TRADE_PERP

Idiomatic alias for Self::TRADE_PERP; Debug prints the variant name.

pub const InternalTransfer: Self = Self::INTERNAL_TRANSFER

Idiomatic alias for Self::INTERNAL_TRANSFER; Debug prints the variant name.

pub const ExternalWithdraw: Self = Self::EXTERNAL_WITHDRAW

Idiomatic alias for Self::EXTERNAL_WITHDRAW; Debug prints the variant name.

pub const ReadBalances: Self = Self::READ_BALANCES

Idiomatic alias for Self::READ_BALANCES; Debug prints the variant name.

pub const ReadSpot: Self = Self::READ_SPOT

Idiomatic alias for Self::READ_SPOT; Debug prints the variant name.

pub const ReadPerp: Self = Self::READ_PERP

Idiomatic alias for Self::READ_PERP; Debug prints the variant name.

pub const ReadInternalTransfers: Self = Self::READ_INTERNAL_TRANSFERS

Idiomatic alias for Self::READ_INTERNAL_TRANSFERS; Debug prints the variant name.

pub const ReadExternalWithdrawals: Self = Self::READ_EXTERNAL_WITHDRAWALS

Idiomatic alias for Self::READ_EXTERNAL_WITHDRAWALS; Debug prints the variant name.

pub const ReadTransferControls: Self = Self::READ_TRANSFER_CONTROLS

Idiomatic alias for Self::READ_TRANSFER_CONTROLS; Debug prints the variant name.

pub const ManageAddressBook: Self = Self::MANAGE_ADDRESS_BOOK

Idiomatic alias for Self::MANAGE_ADDRESS_BOOK; Debug prints the variant name.

pub const ManageTransferWhitelists: Self = Self::MANAGE_TRANSFER_WHITELISTS

Idiomatic alias for Self::MANAGE_TRANSFER_WHITELISTS; Debug prints the variant name.