#[repr(i32)]pub enum SessionLevel {
SESSION_LEVEL_UNSPECIFIED = 0,
PRIMARY_AUTHENTICATED = 1,
MFA_ELEVATED = 2,
FRESH_STEP_UP = 3,
}Expand description
Session assurance level for the current interactive authentication context.
Variants
SESSION_LEVEL_UNSPECIFIED = 0
No session assurance level was specified.
PRIMARY_AUTHENTICATED = 1
Primary login has completed, but MFA has not elevated this session.
MFA_ELEVATED = 2
MFA has elevated this session for ordinary protected account activity.
FRESH_STEP_UP = 3
A short-lived proof for one high-risk action.
Implementations
Sourceimpl SessionLevel
impl SessionLevel
Sourcepub const SessionLevelUnspecified: Self = Self::SESSION_LEVEL_UNSPECIFIED
pub const SessionLevelUnspecified: Self = Self::SESSION_LEVEL_UNSPECIFIED
Idiomatic alias for Self::SESSION_LEVEL_UNSPECIFIED; Debug prints the variant name.
Sourcepub const PrimaryAuthenticated: Self = Self::PRIMARY_AUTHENTICATED
pub const PrimaryAuthenticated: Self = Self::PRIMARY_AUTHENTICATED
Idiomatic alias for Self::PRIMARY_AUTHENTICATED; Debug prints the variant name.
Sourcepub const MfaElevated: Self = Self::MFA_ELEVATED
pub const MfaElevated: Self = Self::MFA_ELEVATED
Idiomatic alias for Self::MFA_ELEVATED; Debug prints the variant name.
Sourcepub const FreshStepUp: Self = Self::FRESH_STEP_UP
pub const FreshStepUp: Self = Self::FRESH_STEP_UP
Idiomatic alias for Self::FRESH_STEP_UP; Debug prints the variant name.