#[repr(i32)]pub enum SubaccountRole {
SUBACCOUNT_ROLE_UNSPECIFIED = 0,
VIEWER = 1,
TRADER = 2,
LEVERAGED_TRADER = 3,
TREASURY = 4,
ADMIN = 5,
OWNER = 6,
}Expand description
Role granted to a root account on a sub-account.
Variants
SUBACCOUNT_ROLE_UNSPECIFIED = 0
No sub-account role was specified.
VIEWER = 1
Can view permitted sub-account data.
TRADER = 2
Can place and manage spot orders where policy allows.
LEVERAGED_TRADER = 3
Can place and manage spot and leverage-enabled orders where policy allows.
TREASURY = 4
Can manage permitted funding and treasury actions where policy allows.
ADMIN = 5
Can administer delegated members and settings, except owner-only controls.
OWNER = 6
Owns the sub-account and can administer all sub-account settings.
Implementations
Sourceimpl SubaccountRole
impl SubaccountRole
Sourcepub const SubaccountRoleUnspecified: Self = Self::SUBACCOUNT_ROLE_UNSPECIFIED
pub const SubaccountRoleUnspecified: Self = Self::SUBACCOUNT_ROLE_UNSPECIFIED
Idiomatic alias for Self::SUBACCOUNT_ROLE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Viewer: Self = Self::VIEWER
pub const Viewer: Self = Self::VIEWER
Idiomatic alias for Self::VIEWER; Debug prints the variant name.
Sourcepub const Trader: Self = Self::TRADER
pub const Trader: Self = Self::TRADER
Idiomatic alias for Self::TRADER; Debug prints the variant name.
Sourcepub const LeveragedTrader: Self = Self::LEVERAGED_TRADER
pub const LeveragedTrader: Self = Self::LEVERAGED_TRADER
Idiomatic alias for Self::LEVERAGED_TRADER; Debug prints the variant name.
Sourcepub const Treasury: Self = Self::TREASURY
pub const Treasury: Self = Self::TREASURY
Idiomatic alias for Self::TREASURY; Debug prints the variant name.
Sourcepub const Admin: Self = Self::ADMIN
pub const Admin: Self = Self::ADMIN
Idiomatic alias for Self::ADMIN; Debug prints the variant name.
Sourcepub const Owner: Self = Self::OWNER
pub const Owner: Self = Self::OWNER
Idiomatic alias for Self::OWNER; Debug prints the variant name.