pub struct ExternalRecentDestination {
pub scope: MessageField<AccountScopeRef>,
pub last_direction: EnumValue<TransferCounterpartyDirection>,
pub saved: bool,
pub address_book_entry_id: u64,
pub use_count: u64,
pub last_seen_at: MessageField<Timestamp>,
pub polychain_chain_id: u32,
pub address: String,
/* private fields */
}Fields
scope: MessageField<AccountScopeRef>Address book where this destination was observed.
Field 1: scope
last_direction: EnumValue<TransferCounterpartyDirection>Direction of the most recent interaction.
Field 2: last_direction
saved: boolWhether this destination is already saved in the address book.
Field 3: saved
address_book_entry_id: u64Saved address book entry id when saved is true.
Field 4: address_book_entry_id
use_count: u64Number of transfers observed for this destination.
Field 5: use_count
last_seen_at: MessageField<Timestamp>Time this destination was last used, as a UTC timestamp.
Field 6: last_seen_at
polychain_chain_id: u32External network identifier for the destination address.
Field 7: polychain_chain_id
address: StringDestination address on the selected external network.
Field 8: address
Implementations