pub struct InternalAddressBookEntry {Show 15 fields
pub address_book_entry_id: u64,
pub scope: MessageField<AccountScopeRef>,
pub label: String,
pub note: String,
pub tag_ids: Vec<u64>,
pub whitelist_status: EnumValue<DestinationWhitelistStatus>,
pub root_account_id: u64,
pub target_account_id: u64,
pub target_scope_type: EnumValue<AccountScopeType>,
pub smart_account_address: String,
pub root_username: String,
pub subaccount_label: String,
pub created_at: MessageField<Timestamp>,
pub updated_at: MessageField<Timestamp>,
pub revision: u64,
/* private fields */
}Fields
address_book_entry_id: u64Stable public id of the saved internal destination.
Field 1: address_book_entry_id
scope: MessageField<AccountScopeRef>Address book that owns this entry.
Field 2: scope
label: StringUser-defined display label.
Field 3: label
note: StringOptional user-defined note.
Field 4: note
tag_ids: Vec<u64>Tag ids attached to this entry. See GetAddressBookViewResponse.tags for tag details.
Field 5: tag_ids
whitelist_status: EnumValue<DestinationWhitelistStatus>Current active whitelist status for this destination.
Field 6: whitelist_status
root_account_id: u64Root account that owns the target internal account.
Field 7: root_account_id
target_account_id: u64Target account or subaccount public id.
Field 8: target_account_id
target_scope_type: EnumValue<AccountScopeType>Whether target_account_id identifies a root account or a subaccount.
Field 9: target_scope_type
smart_account_address: StringSmart account address for the internal transfer destination.
Field 10: smart_account_address
root_username: StringUsername for the destination root account, when available.
Field 11: root_username
subaccount_label: StringLabel for the destination subaccount, when the destination is a subaccount.
Field 12: subaccount_label
created_at: MessageField<Timestamp>Time this entry was created, as a UTC timestamp.
Field 13: created_at
updated_at: MessageField<Timestamp>Time this entry was last updated, as a UTC timestamp.
Field 14: updated_at
revision: u64Monotonic resource revision used for conditional updates.
Field 15: revision
Implementations