pub struct InternalRecentDestination {
pub scope: MessageField<AccountScopeRef>,
pub last_direction: EnumValue<TransferCounterpartyDirection>,
pub saved: bool,
pub address_book_entry_id: u64,
pub use_count: u64,
pub last_seen_at: MessageField<Timestamp>,
pub root_account_id: u64,
pub target_account_id: u64,
pub target_scope_type: EnumValue<AccountScopeType>,
pub smart_account_address: String,
pub root_username: String,
pub subaccount_label: String,
/* private fields */
}Fields
scope: MessageField<AccountScopeRef>Address book where this destination was observed.
Field 1: scope
last_direction: EnumValue<TransferCounterpartyDirection>Direction of the most recent interaction.
Field 2: last_direction
saved: boolWhether this destination is already saved in the address book.
Field 3: saved
address_book_entry_id: u64Saved address book entry id when saved is true.
Field 4: address_book_entry_id
use_count: u64Number of transfers observed for this destination.
Field 5: use_count
last_seen_at: MessageField<Timestamp>Time this destination was last used, as a UTC timestamp.
Field 6: last_seen_at
root_account_id: u64Root account that owns the target internal account.
Field 7: root_account_id
target_account_id: u64Target account or subaccount public id.
Field 8: target_account_id
target_scope_type: EnumValue<AccountScopeType>Whether target_account_id identifies a root account or a subaccount.
Field 9: target_scope_type
smart_account_address: StringSmart account address for the internal transfer destination.
Field 10: smart_account_address
root_username: StringUsername for the destination root account, when available.
Field 11: root_username
subaccount_label: StringLabel for the destination subaccount, when the destination is a subaccount.
Field 12: subaccount_label
Implementations