pub struct SocialVerification {Show 13 fields
pub id: i64,
pub provider: EnumValue<SocialProvider>,
pub method: EnumValue<SocialVerificationMethod>,
pub handle: String,
pub provider_user_id: String,
pub challenge_code: String,
pub status: EnumValue<SocialVerificationStatus>,
pub requested_at: MessageField<Timestamp>,
pub expires_at: MessageField<Timestamp>,
pub verified_at: MessageField<Timestamp>,
pub attempts: i32,
pub last_error: String,
pub updated_at: MessageField<Timestamp>,
/* private fields */
}Expand description
SocialVerification describes the caller’s current verification state for one social provider.
Fields
id: i64Verification identifier.
Field 12: id
provider: EnumValue<SocialProvider>Provider account being verified.
Field 1: provider
method: EnumValue<SocialVerificationMethod>Method used for this verification. If unspecified at start time, profile verification is used.
Field 11: method
handle: StringProvider handle being verified. Handles are returned lowercase and without a leading “@”.
Field 2: handle
provider_user_id: StringStable provider-side user identifier. Empty until verification succeeds.
Field 3: provider_user_id
challenge_code: StringChallenge code the user must place according to the verification method. Codes start with “poly_” and expire after 15 minutes.
Field 13: challenge_code
status: EnumValue<SocialVerificationStatus>Current verification status.
Field 4: status
requested_at: MessageField<Timestamp>Time in UTC when the current challenge code was issued.
Field 5: requested_at
expires_at: MessageField<Timestamp>Time in UTC when the current challenge code expires.
Field 6: expires_at
verified_at: MessageField<Timestamp>Time in UTC when verification succeeded. Empty until status is STATUS_VERIFIED.
Field 7: verified_at
attempts: i32Number of recorded provider-check attempts for this challenge.
Field 9: attempts
last_error: StringLast verification error, if the most recent check failed. Empty when there is no recorded error.
Field 10: last_error
updated_at: MessageField<Timestamp>Time in UTC when this verification state last changed.
Field 15: updated_at
Implementations