pub struct SubaccountMemberView {
pub account_id: u64,
pub role: EnumValue<SubaccountRole>,
pub username: String,
pub smart_account_address: String,
pub avatar_url: String,
pub mfa_enrolled: bool,
/* private fields */
}Expand description
Member summary for a root account with access to a sub-account.
Fields
account_id: u64Identifier for the member’s root account (opaque ID).
Field 1: account_id
role: EnumValue<SubaccountRole>Effective role on this sub-account.
Field 2: role
username: StringOptional username for the member’s root account.
Field 3: username
smart_account_address: StringSmart Account address for the member’s root account, if any.
Field 4: smart_account_address
avatar_url: StringOptional avatar URL for the member’s root account.
Field 5: avatar_url
mfa_enrolled: boolTrue when the member has at least one MFA factor enrolled on their root account.
Field 6: mfa_enrolled
Implementations