pub struct TransferCounterparty {
pub counterparty_id: u64,
pub scope: MessageField<AccountScopeRef>,
pub direction: EnumValue<TransferCounterpartyDirection>,
pub kind: EnumValue<AddressBookEntryKind>,
pub saved: bool,
pub address_book_entry_id: u64,
pub use_count: u64,
pub first_seen_at: MessageField<Timestamp>,
pub last_seen_at: MessageField<Timestamp>,
pub counterparty: Option<Counterparty>,
/* private fields */
}Fields
counterparty_id: u64Stable public id of this transfer counterparty.
Field 1: counterparty_id
scope: MessageField<AccountScopeRef>Address book where this counterparty was observed.
Field 2: scope
direction: EnumValue<TransferCounterpartyDirection>Most recent transfer direction for this counterparty.
Field 3: direction
kind: EnumValue<AddressBookEntryKind>Counterparty type.
Field 4: kind
saved: boolWhether this counterparty is already saved in the address book.
Field 5: saved
address_book_entry_id: u64Saved address book entry id when saved is true.
Field 6: address_book_entry_id
use_count: u64Number of transfers observed for this counterparty.
Field 7: use_count
first_seen_at: MessageField<Timestamp>Time this counterparty was first observed, as a UTC timestamp.
Field 8: first_seen_at
last_seen_at: MessageField<Timestamp>Time this counterparty was last observed, as a UTC timestamp.
Field 9: last_seen_at
counterparty: Option<Counterparty>Implementations