#[repr(i32)]pub enum FlowDomain {
DOMAIN_UNSPECIFIED = 0,
DOMAIN_EXTERNAL_CHAIN = 1,
DOMAIN_ZIPPER = 2,
DOMAIN_FUNDING = 3,
DOMAIN_TRADING = 4,
DOMAIN_LENDING = 5,
}Expand description
FlowDomain identifies the product domain that currently owns or processes the value represented by the lifecycle.
Variants
DOMAIN_UNSPECIFIED = 0
DOMAIN_EXTERNAL_CHAIN = 1
Value still belongs to an external chain outside Polyester.
DOMAIN_ZIPPER = 2
Value is inside the Zipper layer on Polyester Chain.
DOMAIN_FUNDING = 3
Value is inside FundingAccount.
DOMAIN_TRADING = 4
Value is inside TradingGateway or the trading domain.
DOMAIN_LENDING = 5
Value is inside the lending domain or pool.
Implementations
Sourceimpl FlowDomain
impl FlowDomain
Sourcepub const DomainUnspecified: Self = Self::DOMAIN_UNSPECIFIED
pub const DomainUnspecified: Self = Self::DOMAIN_UNSPECIFIED
Idiomatic alias for Self::DOMAIN_UNSPECIFIED; Debug prints the variant name.
Sourcepub const DomainExternalChain: Self = Self::DOMAIN_EXTERNAL_CHAIN
pub const DomainExternalChain: Self = Self::DOMAIN_EXTERNAL_CHAIN
Idiomatic alias for Self::DOMAIN_EXTERNAL_CHAIN; Debug prints the variant name.
Sourcepub const DomainZipper: Self = Self::DOMAIN_ZIPPER
pub const DomainZipper: Self = Self::DOMAIN_ZIPPER
Idiomatic alias for Self::DOMAIN_ZIPPER; Debug prints the variant name.
Sourcepub const DomainFunding: Self = Self::DOMAIN_FUNDING
pub const DomainFunding: Self = Self::DOMAIN_FUNDING
Idiomatic alias for Self::DOMAIN_FUNDING; Debug prints the variant name.
Sourcepub const DomainTrading: Self = Self::DOMAIN_TRADING
pub const DomainTrading: Self = Self::DOMAIN_TRADING
Idiomatic alias for Self::DOMAIN_TRADING; Debug prints the variant name.
Sourcepub const DomainLending: Self = Self::DOMAIN_LENDING
pub const DomainLending: Self = Self::DOMAIN_LENDING
Idiomatic alias for Self::DOMAIN_LENDING; Debug prints the variant name.