#[repr(i32)]pub enum FlowState {
STATE_UNSPECIFIED = 0,
STATE_PENDING_SOURCE = 1,
STATE_PENDING_POLYESTER_CHAIN = 2,
STATE_PENDING_LEDGER = 3,
STATE_COMPLETED = 4,
STATE_FAILED = 5,
STATE_DROPPED = 6,
STATE_REFUNDED = 7,
}Expand description
FlowState is the latest lifecycle state after folding normalized facts.
Variants
STATE_UNSPECIFIED = 0
STATE_PENDING_SOURCE = 1
Flow exists and is still waiting on source-chain progress.
STATE_PENDING_POLYESTER_CHAIN = 2
Flow is now progressing on Polyester Chain after source readiness.
STATE_PENDING_LEDGER = 3
Flow is now waiting for an off-chain ledger effect or settlement effect.
STATE_COMPLETED = 4
Flow completed successfully.
STATE_FAILED = 5
Flow failed and is no longer progressing.
STATE_DROPPED = 6
Flow was dropped before successful completion.
STATE_REFUNDED = 7
Flow ended in a refund or reversal.
Implementations
Sourceimpl FlowState
impl FlowState
Sourcepub const StateUnspecified: Self = Self::STATE_UNSPECIFIED
pub const StateUnspecified: Self = Self::STATE_UNSPECIFIED
Idiomatic alias for Self::STATE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const StatePendingSource: Self = Self::STATE_PENDING_SOURCE
pub const StatePendingSource: Self = Self::STATE_PENDING_SOURCE
Idiomatic alias for Self::STATE_PENDING_SOURCE; Debug prints the variant name.
Sourcepub const StatePendingPolyesterChain: Self = Self::STATE_PENDING_POLYESTER_CHAIN
pub const StatePendingPolyesterChain: Self = Self::STATE_PENDING_POLYESTER_CHAIN
Idiomatic alias for Self::STATE_PENDING_POLYESTER_CHAIN; Debug prints the variant name.
Sourcepub const StatePendingLedger: Self = Self::STATE_PENDING_LEDGER
pub const StatePendingLedger: Self = Self::STATE_PENDING_LEDGER
Idiomatic alias for Self::STATE_PENDING_LEDGER; Debug prints the variant name.
Sourcepub const StateCompleted: Self = Self::STATE_COMPLETED
pub const StateCompleted: Self = Self::STATE_COMPLETED
Idiomatic alias for Self::STATE_COMPLETED; Debug prints the variant name.
Sourcepub const StateFailed: Self = Self::STATE_FAILED
pub const StateFailed: Self = Self::STATE_FAILED
Idiomatic alias for Self::STATE_FAILED; Debug prints the variant name.
Sourcepub const StateDropped: Self = Self::STATE_DROPPED
pub const StateDropped: Self = Self::STATE_DROPPED
Idiomatic alias for Self::STATE_DROPPED; Debug prints the variant name.
Sourcepub const StateRefunded: Self = Self::STATE_REFUNDED
pub const StateRefunded: Self = Self::STATE_REFUNDED
Idiomatic alias for Self::STATE_REFUNDED; Debug prints the variant name.