#[repr(i32)]pub enum FlowStep {
FLOW_STEP_UNSPECIFIED = 0,
FLOW_STEP_SOURCE = 1,
FLOW_STEP_TRANSFER = 2,
FLOW_STEP_REQUEST = 3,
FLOW_STEP_VALIDATION = 4,
FLOW_STEP_EXECUTION = 5,
FLOW_STEP_BRIDGE_FULFILLMENT = 6,
FLOW_STEP_DROPPED = 7,
FLOW_STEP_FAILED = 8,
FLOW_STEP_REFUNDED = 9,
FLOW_STEP_FULFILLING = 10,
FLOW_STEP_SETTLEMENT = 11,
}Expand description
FlowStep is the public lifecycle step shown in API and realtime read models. It is business-facing and intentionally hides the lower-level technical milestone taxonomy.
Variants
FLOW_STEP_UNSPECIFIED = 0
Step is not specified.
FLOW_STEP_SOURCE = 1
External-chain / relayer source tracking before Polyester can continue.
FLOW_STEP_TRANSFER = 2
Deposit-side mint and downstream crediting / transfer stage.
FLOW_STEP_REQUEST = 3
Polyester request creation stage.
FLOW_STEP_VALIDATION = 4
Polyester validation / quorum stage.
FLOW_STEP_EXECUTION = 5
Polyester execution stage.
FLOW_STEP_BRIDGE_FULFILLMENT = 6
Bridge fulfillment before final ledger settlement.
FLOW_STEP_DROPPED = 7
Flow was dropped before success.
FLOW_STEP_FAILED = 8
Flow failed in a user-visible way.
FLOW_STEP_REFUNDED = 9
Flow reached a refund or reversal result.
FLOW_STEP_FULFILLING = 10
Withdraw destination tx hash was committed and the flow is waiting for the final fulfillment confirmation.
FLOW_STEP_SETTLEMENT = 11
Off-chain ledger settlement was durably confirmed.
Implementations
Sourceimpl FlowStep
impl FlowStep
Sourcepub const Unspecified: Self = Self::FLOW_STEP_UNSPECIFIED
pub const Unspecified: Self = Self::FLOW_STEP_UNSPECIFIED
Idiomatic alias for Self::FLOW_STEP_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Source: Self = Self::FLOW_STEP_SOURCE
pub const Source: Self = Self::FLOW_STEP_SOURCE
Idiomatic alias for Self::FLOW_STEP_SOURCE; Debug prints the variant name.
Sourcepub const Transfer: Self = Self::FLOW_STEP_TRANSFER
pub const Transfer: Self = Self::FLOW_STEP_TRANSFER
Idiomatic alias for Self::FLOW_STEP_TRANSFER; Debug prints the variant name.
Sourcepub const Request: Self = Self::FLOW_STEP_REQUEST
pub const Request: Self = Self::FLOW_STEP_REQUEST
Idiomatic alias for Self::FLOW_STEP_REQUEST; Debug prints the variant name.
Sourcepub const Validation: Self = Self::FLOW_STEP_VALIDATION
pub const Validation: Self = Self::FLOW_STEP_VALIDATION
Idiomatic alias for Self::FLOW_STEP_VALIDATION; Debug prints the variant name.
Sourcepub const Execution: Self = Self::FLOW_STEP_EXECUTION
pub const Execution: Self = Self::FLOW_STEP_EXECUTION
Idiomatic alias for Self::FLOW_STEP_EXECUTION; Debug prints the variant name.
Sourcepub const BridgeFulfillment: Self = Self::FLOW_STEP_BRIDGE_FULFILLMENT
pub const BridgeFulfillment: Self = Self::FLOW_STEP_BRIDGE_FULFILLMENT
Idiomatic alias for Self::FLOW_STEP_BRIDGE_FULFILLMENT; Debug prints the variant name.
Sourcepub const Dropped: Self = Self::FLOW_STEP_DROPPED
pub const Dropped: Self = Self::FLOW_STEP_DROPPED
Idiomatic alias for Self::FLOW_STEP_DROPPED; Debug prints the variant name.
Sourcepub const Failed: Self = Self::FLOW_STEP_FAILED
pub const Failed: Self = Self::FLOW_STEP_FAILED
Idiomatic alias for Self::FLOW_STEP_FAILED; Debug prints the variant name.
Sourcepub const Refunded: Self = Self::FLOW_STEP_REFUNDED
pub const Refunded: Self = Self::FLOW_STEP_REFUNDED
Idiomatic alias for Self::FLOW_STEP_REFUNDED; Debug prints the variant name.
Sourcepub const Fulfilling: Self = Self::FLOW_STEP_FULFILLING
pub const Fulfilling: Self = Self::FLOW_STEP_FULFILLING
Idiomatic alias for Self::FLOW_STEP_FULFILLING; Debug prints the variant name.
Sourcepub const Settlement: Self = Self::FLOW_STEP_SETTLEMENT
pub const Settlement: Self = Self::FLOW_STEP_SETTLEMENT
Idiomatic alias for Self::FLOW_STEP_SETTLEMENT; Debug prints the variant name.