#[repr(i32)]pub enum FlowTimelineStatus {
TIMELINE_STATUS_UNSPECIFIED = 0,
TIMELINE_STATUS_COMPLETED = 1,
TIMELINE_STATUS_CURRENT = 2,
TIMELINE_STATUS_PLANNED = 3,
}Expand description
FlowTimelineStatus describes how a progress timeline item relates to the current user-facing flow state.
Variants
TIMELINE_STATUS_UNSPECIFIED = 0
Timeline status is not specified.
TIMELINE_STATUS_COMPLETED = 1
Step has been observed or is behind the current progress step.
TIMELINE_STATUS_CURRENT = 2
Step is the current active progress step.
TIMELINE_STATUS_PLANNED = 3
Step is expected but has not been observed yet.
Implementations
Sourceimpl FlowTimelineStatus
impl FlowTimelineStatus
Sourcepub const TimelineStatusUnspecified: Self = Self::TIMELINE_STATUS_UNSPECIFIED
pub const TimelineStatusUnspecified: Self = Self::TIMELINE_STATUS_UNSPECIFIED
Idiomatic alias for Self::TIMELINE_STATUS_UNSPECIFIED; Debug prints the variant name.
Sourcepub const TimelineStatusCompleted: Self = Self::TIMELINE_STATUS_COMPLETED
pub const TimelineStatusCompleted: Self = Self::TIMELINE_STATUS_COMPLETED
Idiomatic alias for Self::TIMELINE_STATUS_COMPLETED; Debug prints the variant name.
Sourcepub const TimelineStatusCurrent: Self = Self::TIMELINE_STATUS_CURRENT
pub const TimelineStatusCurrent: Self = Self::TIMELINE_STATUS_CURRENT
Idiomatic alias for Self::TIMELINE_STATUS_CURRENT; Debug prints the variant name.
Sourcepub const TimelineStatusPlanned: Self = Self::TIMELINE_STATUS_PLANNED
pub const TimelineStatusPlanned: Self = Self::TIMELINE_STATUS_PLANNED
Idiomatic alias for Self::TIMELINE_STATUS_PLANNED; Debug prints the variant name.