#[repr(i32)]pub enum LifecycleReason {
REASON_UNSPECIFIED = 0,
ZIPPER_VALIDATION_REJECTED = 101,
ZIPPER_EXECUTION_REJECTED = 102,
ZIPPER_WITHDRAW_EXECUTION_FAILED = 103,
ZIPPER_DEPOSIT_REFUND_FAILED = 104,
LEDGER_MIRROR_REJECTED = 200,
LEDGER_MIRROR_TRANSFER_EXCEEDS_CREDITS = 201,
LEDGER_MIRROR_TRANSFER_EXISTS = 202,
LEDGER_MIRROR_PENDING_TRANSFER_NOT_FOUND = 203,
LEDGER_MIRROR_TRANSFER_ID_ALREADY_FAILED = 204,
}Expand description
LifecycleReason is the stable product-facing reason catalog for failed, dropped, refunded, or otherwise notable lifecycle states.
Variants
REASON_UNSPECIFIED = 0
ZIPPER_VALIDATION_REJECTED = 101
Zipper validators reached the rejection quorum.
ZIPPER_EXECUTION_REJECTED = 102
Zipper execution rejected the request.
ZIPPER_WITHDRAW_EXECUTION_FAILED = 103
Zipper withdraw execution failed.
ZIPPER_DEPOSIT_REFUND_FAILED = 104
Zipper deposit refund failed.
LEDGER_MIRROR_REJECTED = 200
Ledger mirror rejected a command before it could be durably applied.
LEDGER_MIRROR_TRANSFER_EXCEEDS_CREDITS = 201
Ledger settlement rejected the mirror command because the source account did not have enough credits for the transfer.
LEDGER_MIRROR_TRANSFER_EXISTS = 202
Ledger settlement reported that the transfer already exists for this mirror command identity.
LEDGER_MIRROR_PENDING_TRANSFER_NOT_FOUND = 203
Ledger settlement reported that the pending transfer referenced by the command was not found.
LEDGER_MIRROR_TRANSFER_ID_ALREADY_FAILED = 204
Ledger settlement reported that this transfer id is already marked failed.
Implementations
Sourceimpl LifecycleReason
impl LifecycleReason
Sourcepub const ReasonUnspecified: Self = Self::REASON_UNSPECIFIED
pub const ReasonUnspecified: Self = Self::REASON_UNSPECIFIED
Idiomatic alias for Self::REASON_UNSPECIFIED; Debug prints the variant name.
Sourcepub const ZipperValidationRejected: Self = Self::ZIPPER_VALIDATION_REJECTED
pub const ZipperValidationRejected: Self = Self::ZIPPER_VALIDATION_REJECTED
Idiomatic alias for Self::ZIPPER_VALIDATION_REJECTED; Debug prints the variant name.
Sourcepub const ZipperExecutionRejected: Self = Self::ZIPPER_EXECUTION_REJECTED
pub const ZipperExecutionRejected: Self = Self::ZIPPER_EXECUTION_REJECTED
Idiomatic alias for Self::ZIPPER_EXECUTION_REJECTED; Debug prints the variant name.
Sourcepub const ZipperWithdrawExecutionFailed: Self = Self::ZIPPER_WITHDRAW_EXECUTION_FAILED
pub const ZipperWithdrawExecutionFailed: Self = Self::ZIPPER_WITHDRAW_EXECUTION_FAILED
Idiomatic alias for Self::ZIPPER_WITHDRAW_EXECUTION_FAILED; Debug prints the variant name.
Sourcepub const ZipperDepositRefundFailed: Self = Self::ZIPPER_DEPOSIT_REFUND_FAILED
pub const ZipperDepositRefundFailed: Self = Self::ZIPPER_DEPOSIT_REFUND_FAILED
Idiomatic alias for Self::ZIPPER_DEPOSIT_REFUND_FAILED; Debug prints the variant name.
Sourcepub const LedgerMirrorRejected: Self = Self::LEDGER_MIRROR_REJECTED
pub const LedgerMirrorRejected: Self = Self::LEDGER_MIRROR_REJECTED
Idiomatic alias for Self::LEDGER_MIRROR_REJECTED; Debug prints the variant name.
Sourcepub const LedgerMirrorTransferExceedsCredits: Self = Self::LEDGER_MIRROR_TRANSFER_EXCEEDS_CREDITS
pub const LedgerMirrorTransferExceedsCredits: Self = Self::LEDGER_MIRROR_TRANSFER_EXCEEDS_CREDITS
Idiomatic alias for Self::LEDGER_MIRROR_TRANSFER_EXCEEDS_CREDITS; Debug prints the variant name.
Sourcepub const LedgerMirrorTransferExists: Self = Self::LEDGER_MIRROR_TRANSFER_EXISTS
pub const LedgerMirrorTransferExists: Self = Self::LEDGER_MIRROR_TRANSFER_EXISTS
Idiomatic alias for Self::LEDGER_MIRROR_TRANSFER_EXISTS; Debug prints the variant name.
Sourcepub const LedgerMirrorPendingTransferNotFound: Self = Self::LEDGER_MIRROR_PENDING_TRANSFER_NOT_FOUND
pub const LedgerMirrorPendingTransferNotFound: Self = Self::LEDGER_MIRROR_PENDING_TRANSFER_NOT_FOUND
Idiomatic alias for Self::LEDGER_MIRROR_PENDING_TRANSFER_NOT_FOUND; Debug prints the variant name.
Sourcepub const LedgerMirrorTransferIdAlreadyFailed: Self = Self::LEDGER_MIRROR_TRANSFER_ID_ALREADY_FAILED
pub const LedgerMirrorTransferIdAlreadyFailed: Self = Self::LEDGER_MIRROR_TRANSFER_ID_ALREADY_FAILED
Idiomatic alias for Self::LEDGER_MIRROR_TRANSFER_ID_ALREADY_FAILED; Debug prints the variant name.