#[repr(i32)]pub enum RequestFeeStatus {
REQUEST_FEE_STATUS_UNSPECIFIED = 0,
REQUEST_FEE_STATUS_LOCKED = 1,
REQUEST_FEE_STATUS_SETTLED = 2,
}Expand description
RequestFeeStatus identifies the current lifecycle state of a request-scoped on-chain fee snapshot.
Variants
REQUEST_FEE_STATUS_UNSPECIFIED = 0
REQUEST_FEE_STATUS_LOCKED = 1
The request locked a fee snapshot at creation time.
REQUEST_FEE_STATUS_SETTLED = 2
The request completed far enough for the locked fee to settle.
Implementations
Sourceimpl RequestFeeStatus
impl RequestFeeStatus
Sourcepub const Unspecified: Self = Self::REQUEST_FEE_STATUS_UNSPECIFIED
pub const Unspecified: Self = Self::REQUEST_FEE_STATUS_UNSPECIFIED
Idiomatic alias for Self::REQUEST_FEE_STATUS_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Locked: Self = Self::REQUEST_FEE_STATUS_LOCKED
pub const Locked: Self = Self::REQUEST_FEE_STATUS_LOCKED
Idiomatic alias for Self::REQUEST_FEE_STATUS_LOCKED; Debug prints the variant name.
Sourcepub const Settled: Self = Self::REQUEST_FEE_STATUS_SETTLED
pub const Settled: Self = Self::REQUEST_FEE_STATUS_SETTLED
Idiomatic alias for Self::REQUEST_FEE_STATUS_SETTLED; Debug prints the variant name.