#[repr(i32)]pub enum Sort {
SORT_UNSPECIFIED = 0,
SORT_NEWEST = 1,
SORT_OLDEST = 2,
}Expand description
Sort selects lifecycle list direction.
Variants
SORT_UNSPECIFIED = 0
Sort order was not specified; server defaults apply.
SORT_NEWEST = 1
Return newest rows first for the selected ordering timestamp.
SORT_OLDEST = 2
Return oldest rows first for the selected ordering timestamp.
Implementations
Sourceimpl Sort
impl Sort
Sourcepub const Unspecified: Self = Self::SORT_UNSPECIFIED
pub const Unspecified: Self = Self::SORT_UNSPECIFIED
Idiomatic alias for Self::SORT_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Newest: Self = Self::SORT_NEWEST
pub const Newest: Self = Self::SORT_NEWEST
Idiomatic alias for Self::SORT_NEWEST; Debug prints the variant name.
Sourcepub const Oldest: Self = Self::SORT_OLDEST
pub const Oldest: Self = Self::SORT_OLDEST
Idiomatic alias for Self::SORT_OLDEST; Debug prints the variant name.