#[repr(i32)]pub enum TxLookupKind {
TX_UNSPECIFIED = 0,
TX_SOURCE = 1,
TX_ANY = 2,
}Expand description
TxLookupKind controls which transaction reference fields are searched.
Variants
TX_UNSPECIFIED = 0
Lookup mode was not specified.
TX_SOURCE = 1
Match only the original source transaction hash for a flow.
TX_ANY = 2
Match either the source transaction hash or the latest known activity transaction reference.
Implementations
Sourceimpl TxLookupKind
impl TxLookupKind
Sourcepub const TxUnspecified: Self = Self::TX_UNSPECIFIED
pub const TxUnspecified: Self = Self::TX_UNSPECIFIED
Idiomatic alias for Self::TX_UNSPECIFIED; Debug prints the variant name.
Sourcepub const TxSource: Self = Self::TX_SOURCE
pub const TxSource: Self = Self::TX_SOURCE
Idiomatic alias for Self::TX_SOURCE; Debug prints the variant name.
Sourcepub const TxAny: Self = Self::TX_ANY
pub const TxAny: Self = Self::TX_ANY
Idiomatic alias for Self::TX_ANY; Debug prints the variant name.