#[repr(i32)]pub enum WithdrawDestinationValidationCode {
RESULT_UNSPECIFIED = 0,
VALID = 1,
INVALID_ADDRESS = 2,
UNSUPPORTED_CHAIN = 3,
POLYESTER_SMART_ACCOUNT = 4,
TOKEN_CONTRACT = 5,
DENYLISTED_ADDRESS = 6,
}Expand description
WithdrawDestinationValidationCode identifies the public outcome of an external-chain destination validation.
Variants
RESULT_UNSPECIFIED = 0
No validation outcome was produced.
VALID = 1
The destination is valid and may be used for a withdraw.
INVALID_ADDRESS = 2
The address is not valid for the selected destination chain.
UNSUPPORTED_CHAIN = 3
The selected destination chain is not supported for withdraws.
POLYESTER_SMART_ACCOUNT = 4
The destination is a Polyester smart account and cannot be used for an external-chain withdraw.
TOKEN_CONTRACT = 5
The destination is a token contract and cannot receive withdrawals.
DENYLISTED_ADDRESS = 6
The destination is blocked by Polyester’s user-safety denylist.
Implementations
Sourceimpl WithdrawDestinationValidationCode
impl WithdrawDestinationValidationCode
Sourcepub const ResultUnspecified: Self = Self::RESULT_UNSPECIFIED
pub const ResultUnspecified: Self = Self::RESULT_UNSPECIFIED
Idiomatic alias for Self::RESULT_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Valid: Self = Self::VALID
pub const Valid: Self = Self::VALID
Idiomatic alias for Self::VALID; Debug prints the variant name.
Sourcepub const InvalidAddress: Self = Self::INVALID_ADDRESS
pub const InvalidAddress: Self = Self::INVALID_ADDRESS
Idiomatic alias for Self::INVALID_ADDRESS; Debug prints the variant name.
Sourcepub const UnsupportedChain: Self = Self::UNSUPPORTED_CHAIN
pub const UnsupportedChain: Self = Self::UNSUPPORTED_CHAIN
Idiomatic alias for Self::UNSUPPORTED_CHAIN; Debug prints the variant name.
Sourcepub const PolyesterSmartAccount: Self = Self::POLYESTER_SMART_ACCOUNT
pub const PolyesterSmartAccount: Self = Self::POLYESTER_SMART_ACCOUNT
Idiomatic alias for Self::POLYESTER_SMART_ACCOUNT; Debug prints the variant name.
Sourcepub const TokenContract: Self = Self::TOKEN_CONTRACT
pub const TokenContract: Self = Self::TOKEN_CONTRACT
Idiomatic alias for Self::TOKEN_CONTRACT; Debug prints the variant name.
Sourcepub const DenylistedAddress: Self = Self::DENYLISTED_ADDRESS
pub const DenylistedAddress: Self = Self::DENYLISTED_ADDRESS
Idiomatic alias for Self::DENYLISTED_ADDRESS; Debug prints the variant name.