pub struct AssetChainVariant {
pub zipped_asset_id: u32,
pub chain_id: u32,
pub is_native_asset: bool,
pub network_fee: String,
pub ztoken_address: String,
pub source_address: String,
pub source_decimals: u32,
pub ztoken_decimals: u32,
pub deposit_min_amount: String,
pub withdraw_min_amount: String,
pub supply_q: u64,
/* private fields */
}Expand description
AssetChainVariant describes one chain route that can be used to deposit into or withdraw from a unified Polyester asset.
Fields
zipped_asset_id: u32Canonical zipped asset route id.
Field 1: zipped_asset_id
chain_id: u32Chain that this asset belongs to.
Field 2: chain_id
is_native_asset: boolTrue when the asset is the native gas/token of the source chain.
Field 3: is_native_asset
network_fee: StringLatest known network fee for this chain asset variant as a human-readable string in zToken units, with insignificant trailing zeroes trimmed.
Field 4: network_fee
ztoken_address: StringPolyester zToken contract address for this chain asset variant.
Field 6: ztoken_address
source_address: StringSource-chain token contract, mint, or native sentinel address.
Field 7: source_address
source_decimals: u32Source-chain token decimals.
Field 8: source_decimals
ztoken_decimals: u32zToken decimals on Polyester chain.
Field 9: ztoken_decimals
deposit_min_amount: StringMinimum deposit amount for this variant as a human-readable string in zToken units.
Field 10: deposit_min_amount
withdraw_min_amount: StringMinimum withdraw amount for this variant as a human-readable string in zToken units.
Field 11: withdraw_min_amount
supply_q: u64Latest zToken supply for this chain asset variant, scaled by the parent unified asset’s quantity_scale. Decode: supply_q / 10^quantity_scale.
Field 12: supply_q
Implementations