#[repr(i32)]pub enum BoardAudience {
AUDIENCE_UNSPECIFIED = 0,
PRIVATE = 1,
PUBLIC = 2,
FOLLOWERS = 3,
}Expand description
BoardAudience controls which audience rule applies when no explicit ACL entry matches.
Variants
AUDIENCE_UNSPECIFIED = 0
Audience is not specified.
PRIVATE = 1
Only the owner and explicit ACL entries have access.
PUBLIC = 2
Any caller gets the board default role.
FOLLOWERS = 3
Followers of the owner get the board default role.
Implementations
Sourceimpl BoardAudience
impl BoardAudience
Sourcepub const AudienceUnspecified: Self = Self::AUDIENCE_UNSPECIFIED
pub const AudienceUnspecified: Self = Self::AUDIENCE_UNSPECIFIED
Idiomatic alias for Self::AUDIENCE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Private: Self = Self::PRIVATE
pub const Private: Self = Self::PRIVATE
Idiomatic alias for Self::PRIVATE; Debug prints the variant name.
Sourcepub const Public: Self = Self::PUBLIC
pub const Public: Self = Self::PUBLIC
Idiomatic alias for Self::PUBLIC; Debug prints the variant name.
Sourcepub const Followers: Self = Self::FOLLOWERS
pub const Followers: Self = Self::FOLLOWERS
Idiomatic alias for Self::FOLLOWERS; Debug prints the variant name.