#[repr(i32)]pub enum BoardRole {
ROLE_UNSPECIFIED = 0,
VIEWER = 1,
EDITOR = 2,
OWNER = 3,
}Expand description
BoardRole is the resolved capability level for a caller on a board.
Variants
ROLE_UNSPECIFIED = 0
Role is not specified, which means the caller has no board access.
VIEWER = 1
Viewer can read board metadata and join the room as read-only.
EDITOR = 2
Editor can view and edit board content in the room.
OWNER = 3
Owner can view, edit, archive, and manage sharing settings.
Implementations
Sourceimpl BoardRole
impl BoardRole
Sourcepub const RoleUnspecified: Self = Self::ROLE_UNSPECIFIED
pub const RoleUnspecified: Self = Self::ROLE_UNSPECIFIED
Idiomatic alias for Self::ROLE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Viewer: Self = Self::VIEWER
pub const Viewer: Self = Self::VIEWER
Idiomatic alias for Self::VIEWER; Debug prints the variant name.
Sourcepub const Editor: Self = Self::EDITOR
pub const Editor: Self = Self::EDITOR
Idiomatic alias for Self::EDITOR; Debug prints the variant name.
Sourcepub const Owner: Self = Self::OWNER
pub const Owner: Self = Self::OWNER
Idiomatic alias for Self::OWNER; Debug prints the variant name.