pub struct MintJoinTokenResponse {
pub board_id: String,
pub access: MessageField<BoardAccess>,
pub expires_at: MessageField<Timestamp>,
pub token: String,
pub room_id: String,
pub connection_id: String,
pub socket_path: String,
pub presence: MessageField<PresencePayload>,
pub access_version: u64,
/* private fields */
}Expand description
MintJoinTokenResponse returns the signed room admission contract for the caller.
Fields
board_id: StringBoard identifier as a UUID string.
Field 1: board_id
access: MessageField<BoardAccess>Resolved caller access for the board.
Field 2: access
expires_at: MessageField<Timestamp>Token expiry time in UTC. Join tokens expire 5 minutes after issuance.
Field 3: expires_at
token: StringSigned short-lived room admission token.
Field 4: token
room_id: StringRoom identifier the client should join. This is the board ID.
Field 5: room_id
connection_id: StringUnique connection identifier embedded in the token.
Field 6: connection_id
socket_path: StringRealtime room URL the client should connect to.
Field 7: socket_path
presence: MessageField<PresencePayload>Lightweight local presence payload for the caller.
Field 8: presence
access_version: u64Access version embedded in the token; clients must refresh when the board access version changes.
Field 9: access_version
Implementations