pub struct UpdateBoardResponse {
pub board: MessageField<Board>,
pub acl_entries: Vec<BoardAclEntry>,
pub access: MessageField<BoardAccess>,
/* private fields */
}Expand description
UpdateBoardResponse returns the updated board.
Fields
board: MessageField<Board>Updated board metadata.
Field 1: board
acl_entries: Vec<BoardAclEntry>Explicit ACL entries ordered by creation time, subject type, then subject ID. Returned only for callers who can manage the board.
Field 2: acl_entries
access: MessageField<BoardAccess>Resolved caller access.
Field 3: access
Implementations