GetBalanceHistoryRequestView

Struct GetBalanceHistoryRequestView 

pub struct GetBalanceHistoryRequestView<'a> {
    pub subaccount_id: Option<u64>,
    pub range: EnumValue<BalanceRange>,
    pub ledger: u32,
    pub account_codes: RepeatedView<'a, EnumValue<AccountCode>>,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}

Fields

subaccount_id: Option<u64>

Optional sub-account to scope balances to. If omitted, balances are returned for the authenticated root account derived from the JWT or API key. The logical account id itself is always derived from the caller’s JWT or API key, not from this payload.

Field 1: subaccount_id

range: EnumValue<BalanceRange>

History window to return. When unset/UNSPECIFIED, defaults to 1D.

Field 2: range

ledger: u32

Optional public asset filter. When unset/0, returns all assets.

Field 3: ledger

account_codes: RepeatedView<'a, EnumValue<AccountCode>>

Optional subset of account buckets to return. When empty, returns all account buckets.

Field 4: account_codes

__buffa_unknown_fields: UnknownFieldsView<'a>