pub struct Candle {
pub symbol_id: u32,
pub timeframe: EnumValue<Timeframe>,
pub ts_sec: u64,
pub open: i64,
pub high: i64,
pub low: i64,
pub close: i64,
pub volume: i64,
/* private fields */
}Expand description
Candle contains one public OHLCV bucket.
Candle represents a single OHLCV bucket for a symbol and timeframe.
Fields
symbol_id: u32numeric spot market identifier
Field 1: symbol_id
timeframe: EnumValue<Timeframe>timeframe of this candle
Field 2: timeframe
ts_sec: u64bucket start timestamp (seconds since epoch, UTC)
Field 3: ts_sec
open: i64opening price in quote units scaled by 1e6
Field 4: open
high: i64highest traded price in quote units scaled by 1e6
Field 5: high
low: i64lowest traded price in quote units scaled by 1e6
Field 6: low
close: i64closing price in quote units scaled by 1e6
Field 7: close
volume: i64Traded base-asset quantity scaled by the pair’s base_quantity_scale from GetSpotConfig.
Field 8: volume
Implementations