pub struct GetSpotConfigResponse {
pub assets: Vec<AssetConfig>,
pub pairs: Vec<PairConfig>,
pub ts_sec: u64,
/* private fields */
}Expand description
GetSpotConfigResponse contains a cacheable spot reference-data snapshot.
Fields
assets: Vec<AssetConfig>Assets ordered by asset code in ascending alphabetical order.
Field 1: assets
pairs: Vec<PairConfig>Pairs ordered by symbol in ascending alphabetical order.
Field 2: pairs
ts_sec: u64Snapshot generation timestamp, in seconds since the Unix epoch (UTC).
Field 3: ts_sec
Implementations