#[repr(i32)]pub enum ErrorCode {
ERROR_CODE_UNSPECIFIED = 0,
ERROR_CODE_BAD_REQUEST = 1,
ERROR_CODE_INVALID_ARGUMENT = 2,
ERROR_CODE_NOT_FOUND = 3,
ERROR_CODE_UNAVAILABLE = 4,
ERROR_CODE_UPSTREAM_ERROR = 5,
}Expand description
ErrorCode is a stable domain error code enum for Market Overview. It is used for consistent error surfaces across ConnectRPC and REST.
Variants
ERROR_CODE_UNSPECIFIED = 0
ERROR_CODE_BAD_REQUEST = 1
ERROR_CODE_INVALID_ARGUMENT = 2
ERROR_CODE_NOT_FOUND = 3
ERROR_CODE_UNAVAILABLE = 4
ERROR_CODE_UPSTREAM_ERROR = 5
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub const Unspecified: Self = Self::ERROR_CODE_UNSPECIFIED
pub const Unspecified: Self = Self::ERROR_CODE_UNSPECIFIED
Idiomatic alias for Self::ERROR_CODE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const BadRequest: Self = Self::ERROR_CODE_BAD_REQUEST
pub const BadRequest: Self = Self::ERROR_CODE_BAD_REQUEST
Idiomatic alias for Self::ERROR_CODE_BAD_REQUEST; Debug prints the variant name.
Sourcepub const InvalidArgument: Self = Self::ERROR_CODE_INVALID_ARGUMENT
pub const InvalidArgument: Self = Self::ERROR_CODE_INVALID_ARGUMENT
Idiomatic alias for Self::ERROR_CODE_INVALID_ARGUMENT; Debug prints the variant name.
Sourcepub const NotFound: Self = Self::ERROR_CODE_NOT_FOUND
pub const NotFound: Self = Self::ERROR_CODE_NOT_FOUND
Idiomatic alias for Self::ERROR_CODE_NOT_FOUND; Debug prints the variant name.
Idiomatic alias for Self::ERROR_CODE_UNAVAILABLE; Debug prints the variant name.
Sourcepub const UpstreamError: Self = Self::ERROR_CODE_UPSTREAM_ERROR
pub const UpstreamError: Self = Self::ERROR_CODE_UPSTREAM_ERROR
Idiomatic alias for Self::ERROR_CODE_UPSTREAM_ERROR; Debug prints the variant name.