#[repr(i32)]pub enum ModifyActionTaken {
MODIFY_ACTION_UNSPECIFIED = 0,
AMENDED = 1,
REPLACED = 2,
}Expand description
ModifyActionTaken describes what action was applied for a modify request.
Variants
MODIFY_ACTION_UNSPECIFIED = 0
Modify action is unknown or the request was rejected.
AMENDED = 1
Existing order was amended in place.
REPLACED = 2
Existing order was canceled and replaced with a new order.
Implementations
Sourceimpl ModifyActionTaken
impl ModifyActionTaken
Sourcepub const ModifyActionUnspecified: Self = Self::MODIFY_ACTION_UNSPECIFIED
pub const ModifyActionUnspecified: Self = Self::MODIFY_ACTION_UNSPECIFIED
Idiomatic alias for Self::MODIFY_ACTION_UNSPECIFIED; Debug prints the variant name.
Sourcepub const Amended: Self = Self::AMENDED
pub const Amended: Self = Self::AMENDED
Idiomatic alias for Self::AMENDED; Debug prints the variant name.
Sourcepub const Replaced: Self = Self::REPLACED
pub const Replaced: Self = Self::REPLACED
Idiomatic alias for Self::REPLACED; Debug prints the variant name.