pub struct AttachedRiskLegState {
pub status: EnumValue<Status>,
pub armed_ts_ns: u64,
pub terminal_ts_ns: u64,
pub trigger_id: Option<u64>,
pub child_order_id: Option<u64>,
/* private fields */
}Expand description
AttachedRiskLegState provides runtime linkage/state for one attached-risk leg.
Fields
status: EnumValue<Status>Current runtime lifecycle status for this attached-risk leg.
Field 1: status
armed_ts_ns: u64Time the leg was armed, in nanoseconds since epoch (UTC). Zero if not armed.
Field 2: armed_ts_ns
terminal_ts_ns: u64Time the leg reached a terminal state, in nanoseconds since epoch (UTC). Zero if not terminal.
Field 3: terminal_ts_ns
trigger_id: Option<u64>Trigger identifier for this attached-risk leg.
Field 4: trigger_id
child_order_id: Option<u64>Child order ID created by this leg after it fires.
Field 5: child_order_id
Implementations
Sourceimpl AttachedRiskLegState
impl AttachedRiskLegState
Sourcepub fn with_trigger_id(self, value: u64) -> Self
pub fn with_trigger_id(self, value: u64) -> Self
Sets Self::trigger_id to Some(value), consuming and returning self.
Sourcepub fn with_child_order_id(self, value: u64) -> Self
pub fn with_child_order_id(self, value: u64) -> Self
Sets Self::child_order_id to Some(value), consuming and returning self.