pub struct GetOrderHistoryRequest {
pub subaccount_id: Option<u64>,
pub symbol_id: Vec<u32>,
pub side: EnumValue<Side>,
pub status: EnumValue<OrderStatus>,
pub start_ts_ns: Option<u64>,
pub end_ts_ns: Option<u64>,
pub limit: Option<u32>,
pub page_token: String,
pub include_attached_risk: Option<bool>,
pub include_attached_risk_state: Option<bool>,
/* private fields */
}Expand description
GetOrderHistoryRequest lists terminal orders for an account.
Fields
subaccount_id: Option<u64>Target sub-account numeric ID. When omitted, uses caller’s root account.
Field 1: subaccount_id
symbol_id: Vec<u32>Optional filter by symbol_id values. Empty means all symbols.
Field 2: symbol_id
side: EnumValue<Side>Optional side filter.
Field 3: side
status: EnumValue<OrderStatus>Optional status filter.
Field 4: status
start_ts_ns: Option<u64>Inclusive start of the time range, in nanoseconds since epoch (UTC).
Field 10: start_ts_ns
end_ts_ns: Option<u64>Inclusive end of the time range, in nanoseconds since epoch (UTC).
Field 11: end_ts_ns
limit: Option<u32>Max number of orders to return (1-1000, default 100).
Field 12: limit
page_token: StringOpaque keyset cursor from a previous response. The cursor is exclusive and bound to the authenticated account, sub-account scope, filters, time range, and sort order.
Field 13: page_token
include_attached_risk: Option<bool>Include attached-risk policy details in each order (defaults to false when unset).
Field 14: include_attached_risk
include_attached_risk_state: Option<bool>Include attached-risk state details in each order (defaults to false when unset).
Field 15: include_attached_risk_state
Implementations
Sourceimpl GetOrderHistoryRequest
impl GetOrderHistoryRequest
Sourcepub fn with_subaccount_id(self, value: u64) -> Self
pub fn with_subaccount_id(self, value: u64) -> Self
Sets Self::subaccount_id to Some(value), consuming and returning self.
Sourcepub fn with_start_ts_ns(self, value: u64) -> Self
pub fn with_start_ts_ns(self, value: u64) -> Self
Sets Self::start_ts_ns to Some(value), consuming and returning self.
Sourcepub fn with_end_ts_ns(self, value: u64) -> Self
pub fn with_end_ts_ns(self, value: u64) -> Self
Sets Self::end_ts_ns to Some(value), consuming and returning self.
Sourcepub fn with_limit(self, value: u32) -> Self
pub fn with_limit(self, value: u32) -> Self
Sets Self::limit to Some(value), consuming and returning self.
Sourcepub fn with_include_attached_risk(self, value: bool) -> Self
pub fn with_include_attached_risk(self, value: bool) -> Self
Sets Self::include_attached_risk to Some(value), consuming and returning self.
Sourcepub fn with_include_attached_risk_state(self, value: bool) -> Self
pub fn with_include_attached_risk_state(self, value: bool) -> Self
Sets Self::include_attached_risk_state to Some(value), consuming and returning self.