pub struct Drawing {Show 14 fields
pub owner_id: u64,
pub drawing_id: u64,
pub layer: MessageField<LayerRef>,
pub engine_symbol_id: u32,
pub type: u32,
pub version: u32,
pub payload: Vec<u8>,
pub bbox_time_min_ms: u64,
pub bbox_time_max_ms: u64,
pub bbox_price_min: f64,
pub bbox_price_max: f64,
pub updated_at_ms: u64,
pub deleted_at_ms: u64,
pub client_updated_at_ms: u64,
/* private fields */
}Expand description
Drawing is a shape or annotation stored inside a layer.
Fields
owner_id: u64Account that owns the drawing.
Field 1: owner_id
drawing_id: u64Drawing identifier unique within the owner account.
Field 2: drawing_id
layer: MessageField<LayerRef>Parent layer for the drawing.
Field 3: layer
engine_symbol_id: u32Engine symbol identifier for the drawing market.
Field 4: engine_symbol_id
type: u32Client-defined drawing type identifier.
Field 5: type
version: u32Client-defined payload schema version.
Field 6: version
payload: Vec<u8>Serialized drawing payload bytes.
Field 7: payload
bbox_time_min_ms: u64Minimum drawing time bound in milliseconds since epoch (UTC); 0 means unset.
Field 8: bbox_time_min_ms
bbox_time_max_ms: u64Maximum drawing time bound in milliseconds since epoch (UTC); 0 means unset.
Field 9: bbox_time_max_ms
bbox_price_min: f64Minimum drawing price bound; 0 means unset.
Field 10: bbox_price_min
bbox_price_max: f64Maximum drawing price bound; 0 means unset.
Field 11: bbox_price_max
updated_at_ms: u64Server-assigned commit timestamp in milliseconds since epoch (UTC).
Field 12: updated_at_ms
deleted_at_ms: u64Server-assigned deletion timestamp in milliseconds since epoch (UTC); 0 means not deleted.
Field 13: deleted_at_ms
client_updated_at_ms: u64Client-assigned commit timestamp in milliseconds since epoch (UTC), used for last-write-wins merge.
Field 14: client_updated_at_ms
Implementations