Module v1

Module v1 

Modules

__buffa
create_internal_transfer_request

Structs

CreateInternalTransferRequest
CreateInternalTransferRequest creates or returns one accepted Trading to Trading internal transfer for the authenticated source account.
CreateInternalTransferRequestOwnedView
Self-contained, 'static owned view of a CreateInternalTransferRequest message.
CreateInternalTransferRequestView
CreateInternalTransferRequest creates or returns one accepted Trading to Trading internal transfer for the authenticated source account.
CreateInternalTransferResponse
CreateInternalTransferResponse returns the accepted request and transfer identifiers for later correlation.
CreateInternalTransferResponseOwnedView
Self-contained, 'static owned view of a CreateInternalTransferResponse message.
CreateInternalTransferResponseView
CreateInternalTransferResponse returns the accepted request and transfer identifiers for later correlation.
ResolvedDestination
ResolvedDestination describes the normalized transfer destination selected by the server after public-id / smart-account resolution.
ResolvedDestinationOwnedView
Self-contained, 'static owned view of a ResolvedDestination message.
ResolvedDestinationView
ResolvedDestination describes the normalized transfer destination selected by the server after public-id / smart-account resolution.

Enums

InternalTransferStatus
InternalTransferStatus is the public user-facing status for an internal transfer request.

Functions

register_types
Register this package’s Any type entries and extension entries.