pub struct CreateInternalTransferRequest {
pub subaccount_id: u64,
pub asset_id: u32,
pub amount_e18: MessageField<U128>,
pub idempotency_key: String,
pub destination: Option<Destination>,
/* private fields */
}Expand description
CreateInternalTransferRequest creates or returns one accepted Trading to Trading internal transfer for the authenticated source account.
Fields
subaccount_id: u64Optional source subaccount public id. When omitted, the authenticated caller’s root account is used as the source account.
Field 1: subaccount_id
asset_id: u32Canonical public unified asset id for the asset being transferred.
Field 5: asset_id
amount_e18: MessageField<U128>Transfer amount in canonical 18-decimal unified asset units. For example, 0.5 is encoded as 500000000000000000.
Field 6: amount_e18
idempotency_key: StringStable client-supplied idempotency key used to collapse safe retries.
Field 7: idempotency_key
destination: Option<Destination>Implementations