Skip to main content Module v1 Copy item path Source __buffa address_book_entry create_address_book_entry_request market_scope transfer_counterparty transfer_destination AccountIdentity AccountIdentity is a lightweight identity view for a root account. AccountIdentityOwnedView Self-contained, 'static owned view of a AccountIdentity message. AccountIdentityView AccountIdentity is a lightweight identity view for a root account. AccountScopeRef AccountScopeRefOwnedView Self-contained, 'static owned view of a AccountScopeRef message. AccountScopeRefView ActivityEvent Activity or audit event for a sub-account. ActivityEventOwnedView Self-contained, 'static owned view of a ActivityEvent message. ActivityEventView Activity or audit event for a sub-account. AddressBook AddressBookEntriesView AddressBookEntriesViewOwnedView Self-contained, 'static owned view of a AddressBookEntriesView message. AddressBookEntriesViewView AddressBookEntry AddressBookEntryOwnedView Self-contained, 'static owned view of a AddressBookEntry message. AddressBookEntryUpdateSpec AddressBookEntryUpdateSpec contains mutable saved-destination metadata. AddressBookEntryUpdateSpecOwnedView Self-contained, 'static owned view of a AddressBookEntryUpdateSpec message. AddressBookEntryUpdateSpecView AddressBookEntryUpdateSpec contains mutable saved-destination metadata. AddressBookEntryView AddressBookOwnedView Self-contained, 'static owned view of a AddressBook message. AddressBookRecentDestinationsView AddressBookRecentDestinationsViewOwnedView Self-contained, 'static owned view of a AddressBookRecentDestinationsView message. AddressBookRecentDestinationsViewView AddressBookTag AddressBookTagInput AddressBookTagInputOwnedView Self-contained, 'static owned view of a AddressBookTagInput message. AddressBookTagInputView AddressBookTagOwnedView Self-contained, 'static owned view of a AddressBookTag message. AddressBookTagSummary AddressBookTagSummaryOwnedView Self-contained, 'static owned view of a AddressBookTagSummary message. AddressBookTagSummaryView AddressBookTagView AddressBookView AddressBookViewInvalidated AddressBookViewInvalidated notifies clients to refetch the address-book aggregate view. AddressBookViewInvalidatedOwnedView Self-contained, 'static owned view of a AddressBookViewInvalidated message. AddressBookViewInvalidatedView AddressBookViewInvalidated notifies clients to refetch the address-book aggregate view. ApiKey ApiKey is public API key metadata. It never includes the private key or seed. ApiKeyOwnedView Self-contained, 'static owned view of a ApiKey message. ApiKeyUpdateSpec ApiKeyUpdateSpec contains mutable API key configuration. ApiKeyUpdateSpecOwnedView Self-contained, 'static owned view of a ApiKeyUpdateSpec message. ApiKeyUpdateSpecView ApiKeyUpdateSpec contains mutable API key configuration. ApiKeyView ApiKey is public API key metadata. It never includes the private key or seed. ApiPolicySpec ApiPolicySpec contains the mutable configuration of an API key policy. ApiPolicySpecOwnedView Self-contained, 'static owned view of a ApiPolicySpec message. ApiPolicySpecView ApiPolicySpec contains the mutable configuration of an API key policy. ApiPolicyView ApiPolicyView is the public view of an API key policy template. API key
policy limits are additional caps and cannot exceed the sub-account policy. ApiPolicyViewOwnedView Self-contained, 'static owned view of a ApiPolicyView message. ApiPolicyViewView ApiPolicyView is the public view of an API key policy template. API key
policy limits are additional caps and cannot exceed the sub-account policy. AuthErrorDetail AuthErrorDetail describes an authentication or account-domain failure. AuthErrorDetailOwnedView Self-contained, 'static owned view of a AuthErrorDetail message. AuthErrorDetailView AuthErrorDetail describes an authentication or account-domain failure. BeginMFAChallengeRequest Request to start an MFA challenge. BeginMFAChallengeRequestOwnedView Self-contained, 'static owned view of a BeginMFAChallengeRequest message. BeginMFAChallengeRequestView Request to start an MFA challenge. BeginMFAChallengeResponse Response returned after starting an MFA challenge. BeginMFAChallengeResponseOwnedView Self-contained, 'static owned view of a BeginMFAChallengeResponse message. BeginMFAChallengeResponseView Response returned after starting an MFA challenge. BeginPasskeyEnrollmentRequest Request to begin passkey enrollment. BeginPasskeyEnrollmentRequestOwnedView Self-contained, 'static owned view of a BeginPasskeyEnrollmentRequest message. BeginPasskeyEnrollmentRequestView Request to begin passkey enrollment. BeginPasskeyEnrollmentResponse Response containing passkey enrollment options. BeginPasskeyEnrollmentResponseOwnedView Self-contained, 'static owned view of a BeginPasskeyEnrollmentResponse message. BeginPasskeyEnrollmentResponseView Response containing passkey enrollment options. BeginTOTPEnrollmentRequest Request to begin authenticator-app enrollment. BeginTOTPEnrollmentRequestOwnedView Self-contained, 'static owned view of a BeginTOTPEnrollmentRequest message. BeginTOTPEnrollmentRequestView Request to begin authenticator-app enrollment. BeginTOTPEnrollmentResponse Response containing the authenticator-app enrollment secret. BeginTOTPEnrollmentResponseOwnedView Self-contained, 'static owned view of a BeginTOTPEnrollmentResponse message. BeginTOTPEnrollmentResponseView Response containing the authenticator-app enrollment secret. ClaimFreshStepUpRequest Request to bind a fresh step-up proof to one protected request. ClaimFreshStepUpRequestOwnedView Self-contained, 'static owned view of a ClaimFreshStepUpRequest message. ClaimFreshStepUpRequestView Request to bind a fresh step-up proof to one protected request. ClaimFreshStepUpResponse Response returned after a fresh step-up proof is claimed. ClaimFreshStepUpResponseOwnedView Self-contained, 'static owned view of a ClaimFreshStepUpResponse message. ClaimFreshStepUpResponseView Response returned after a fresh step-up proof is claimed. CompleteMFAChallengeResponse Response returned after an MFA challenge is completed. CompleteMFAChallengeResponseOwnedView Self-contained, 'static owned view of a CompleteMFAChallengeResponse message. CompleteMFAChallengeResponseView Response returned after an MFA challenge is completed. ConsumeFreshStepUpRequest Request to consume a claimed fresh step-up proof after the protected request succeeds. ConsumeFreshStepUpRequestOwnedView Self-contained, 'static owned view of a ConsumeFreshStepUpRequest message. ConsumeFreshStepUpRequestView Request to consume a claimed fresh step-up proof after the protected request succeeds. ConsumeFreshStepUpResponse Empty response returned after a fresh step-up proof is consumed. ConsumeFreshStepUpResponseOwnedView Self-contained, 'static owned view of a ConsumeFreshStepUpResponse message. ConsumeFreshStepUpResponseView Empty response returned after a fresh step-up proof is consumed. CopyAddressBookEntryRequest CopyAddressBookEntryRequestOwnedView Self-contained, 'static owned view of a CopyAddressBookEntryRequest message. CopyAddressBookEntryRequestView CopyAddressBookEntryResponse CopyAddressBookEntryResponseOwnedView Self-contained, 'static owned view of a CopyAddressBookEntryResponse message. CopyAddressBookEntryResponseView CreateAddressBookEntryRequest CreateAddressBookEntryRequestOwnedView Self-contained, 'static owned view of a CreateAddressBookEntryRequest message. CreateAddressBookEntryRequestView CreateAddressBookEntryResponse CreateAddressBookEntryResponseOwnedView Self-contained, 'static owned view of a CreateAddressBookEntryResponse message. CreateAddressBookEntryResponseView CreateAddressBookTagRequest CreateAddressBookTagRequestOwnedView Self-contained, 'static owned view of a CreateAddressBookTagRequest message. CreateAddressBookTagRequestView CreateAddressBookTagResponse CreateAddressBookTagResponseOwnedView Self-contained, 'static owned view of a CreateAddressBookTagResponse message. CreateAddressBookTagResponseView CreateApiKeyRequest CreateApiKeyRequest creates a new API key. Clients generate the Ed25519 key
pair locally and submit only the public key. CreateApiKeyRequestOwnedView Self-contained, 'static owned view of a CreateApiKeyRequest message. CreateApiKeyRequestView CreateApiKeyRequest creates a new API key. Clients generate the Ed25519 key
pair locally and submit only the public key. CreateApiKeyResponse CreateApiKeyResponse returns the created API key metadata. CreateApiKeyResponseOwnedView Self-contained, 'static owned view of a CreateApiKeyResponse message. CreateApiKeyResponseView CreateApiKeyResponse returns the created API key metadata. CreateApiPolicyRequest CreateApiPolicyRequest defines a new API key policy template. CreateApiPolicyRequestOwnedView Self-contained, 'static owned view of a CreateApiPolicyRequest message. CreateApiPolicyRequestView CreateApiPolicyRequest defines a new API key policy template. CreateApiPolicyResponse CreateApiPolicyResponse returns the created API key policy. CreateApiPolicyResponseOwnedView Self-contained, 'static owned view of a CreateApiPolicyResponse message. CreateApiPolicyResponseView CreateApiPolicyResponse returns the created API key policy. CreateSubaccountPolicyRequest CreateSubaccountPolicyRequest defines a new sub-account policy template, with
an optional attach step for one target sub-account. CreateSubaccountPolicyRequestOwnedView Self-contained, 'static owned view of a CreateSubaccountPolicyRequest message. CreateSubaccountPolicyRequestView CreateSubaccountPolicyRequest defines a new sub-account policy template, with
an optional attach step for one target sub-account. CreateSubaccountPolicyResponse CreateSubaccountPolicyResponse returns the created sub-account policy. CreateSubaccountPolicyResponseOwnedView Self-contained, 'static owned view of a CreateSubaccountPolicyResponse message. CreateSubaccountPolicyResponseView CreateSubaccountPolicyResponse returns the created sub-account policy. CreateSubaccountRequest Request to create a new sub-account under the caller’s root account. CreateSubaccountRequestOwnedView Self-contained, 'static owned view of a CreateSubaccountRequest message. CreateSubaccountRequestView Request to create a new sub-account under the caller’s root account. CreateSubaccountResponse Response returned after creating a sub-account. CreateSubaccountResponseOwnedView Self-contained, 'static owned view of a CreateSubaccountResponse message. CreateSubaccountResponseView Response returned after creating a sub-account. DeleteAddressBookEntryRequest DeleteAddressBookEntryRequestOwnedView Self-contained, 'static owned view of a DeleteAddressBookEntryRequest message. DeleteAddressBookEntryRequestView DeleteAddressBookEntryResponse DeleteAddressBookEntryResponseOwnedView Self-contained, 'static owned view of a DeleteAddressBookEntryResponse message. DeleteAddressBookEntryResponseView DeleteAddressBookTagRequest DeleteAddressBookTagRequestOwnedView Self-contained, 'static owned view of a DeleteAddressBookTagRequest message. DeleteAddressBookTagRequestView DeleteAddressBookTagResponse DeleteAddressBookTagResponseOwnedView Self-contained, 'static owned view of a DeleteAddressBookTagResponse message. DeleteAddressBookTagResponseView DeleteApiKeyRequest DeleteApiKeyRequest permanently revokes an API key. DeleteApiKeyRequestOwnedView Self-contained, 'static owned view of a DeleteApiKeyRequest message. DeleteApiKeyRequestView DeleteApiKeyRequest permanently revokes an API key. DeleteApiKeyResponse DeleteApiKeyResponse is empty when revocation succeeds. DeleteApiKeyResponseOwnedView Self-contained, 'static owned view of a DeleteApiKeyResponse message. DeleteApiKeyResponseView DeleteApiKeyResponse is empty when revocation succeeds. DeleteApiPolicyRequest DeleteApiPolicyRequest deletes an API key policy template when it is not in use. DeleteApiPolicyRequestOwnedView Self-contained, 'static owned view of a DeleteApiPolicyRequest message. DeleteApiPolicyRequestView DeleteApiPolicyRequest deletes an API key policy template when it is not in use. DeleteApiPolicyResponse DeleteApiPolicyResponse is empty when the delete succeeds. DeleteApiPolicyResponseOwnedView Self-contained, 'static owned view of a DeleteApiPolicyResponse message. DeleteApiPolicyResponseView DeleteApiPolicyResponse is empty when the delete succeeds. DeleteMFAFactorRequest Request to delete an MFA factor. DeleteMFAFactorRequestOwnedView Self-contained, 'static owned view of a DeleteMFAFactorRequest message. DeleteMFAFactorRequestView Request to delete an MFA factor. DeleteMFAFactorResponse Empty response returned after an MFA factor is deleted. DeleteMFAFactorResponseOwnedView Self-contained, 'static owned view of a DeleteMFAFactorResponse message. DeleteMFAFactorResponseView Empty response returned after an MFA factor is deleted. DeleteSubaccountPolicyRequest DeleteSubaccountPolicyRequest deletes a sub-account policy template when it
is not in use. DeleteSubaccountPolicyRequestOwnedView Self-contained, 'static owned view of a DeleteSubaccountPolicyRequest message. DeleteSubaccountPolicyRequestView DeleteSubaccountPolicyRequest deletes a sub-account policy template when it
is not in use. DeleteSubaccountPolicyResponse DeleteSubaccountPolicyResponse is empty when the delete succeeds. DeleteSubaccountPolicyResponseOwnedView Self-contained, 'static owned view of a DeleteSubaccountPolicyResponse message. DeleteSubaccountPolicyResponseView DeleteSubaccountPolicyResponse is empty when the delete succeeds. ExternalAddressBookEntry ExternalAddressBookEntryOwnedView Self-contained, 'static owned view of a ExternalAddressBookEntry message. ExternalAddressBookEntryView ExternalRecentDestination ExternalRecentDestinationOwnedView Self-contained, 'static owned view of a ExternalRecentDestination message. ExternalRecentDestinationView ExternalWithdrawAddress ExternalWithdrawAddressOwnedView Self-contained, 'static owned view of a ExternalWithdrawAddress message. ExternalWithdrawAddressView FinishPasskeyChallengeRequest Request to verify an MFA challenge with a passkey. FinishPasskeyChallengeRequestOwnedView Self-contained, 'static owned view of a FinishPasskeyChallengeRequest message. FinishPasskeyChallengeRequestView Request to verify an MFA challenge with a passkey. FinishPasskeyEnrollmentRequest Request to finish passkey enrollment. FinishPasskeyEnrollmentRequestOwnedView Self-contained, 'static owned view of a FinishPasskeyEnrollmentRequest message. FinishPasskeyEnrollmentRequestView Request to finish passkey enrollment. FinishPasskeyEnrollmentResponse Response returned after passkey enrollment succeeds. FinishPasskeyEnrollmentResponseOwnedView Self-contained, 'static owned view of a FinishPasskeyEnrollmentResponse message. FinishPasskeyEnrollmentResponseView Response returned after passkey enrollment succeeds. FinishTOTPEnrollmentRequest Request to finish authenticator-app enrollment. FinishTOTPEnrollmentRequestOwnedView Self-contained, 'static owned view of a FinishTOTPEnrollmentRequest message. FinishTOTPEnrollmentRequestView Request to finish authenticator-app enrollment. FinishTOTPEnrollmentResponse Response returned after authenticator-app enrollment succeeds. FinishTOTPEnrollmentResponseOwnedView Self-contained, 'static owned view of a FinishTOTPEnrollmentResponse message. FinishTOTPEnrollmentResponseView Response returned after authenticator-app enrollment succeeds. GetAddressBookViewRequest GetAddressBookViewRequestOwnedView Self-contained, 'static owned view of a GetAddressBookViewRequest message. GetAddressBookViewRequestView GetAddressBookViewResponse GetAddressBookViewResponseOwnedView Self-contained, 'static owned view of a GetAddressBookViewResponse message. GetAddressBookViewResponseView GetApiKeyRequest GetApiKeyRequest returns a single API key owned by the caller’s account. GetApiKeyRequestOwnedView Self-contained, 'static owned view of a GetApiKeyRequest message. GetApiKeyRequestView GetApiKeyRequest returns a single API key owned by the caller’s account. GetApiKeyResponse GetApiKeyResponse returns one API key owned by the caller. GetApiKeyResponseOwnedView Self-contained, 'static owned view of a GetApiKeyResponse message. GetApiKeyResponseView GetApiKeyResponse returns one API key owned by the caller. GetApiPolicyRequest GetApiPolicyRequest fetches one API key policy template by ID. GetApiPolicyRequestOwnedView Self-contained, 'static owned view of a GetApiPolicyRequest message. GetApiPolicyRequestView GetApiPolicyRequest fetches one API key policy template by ID. GetApiPolicyResponse GetApiPolicyResponse returns the requested API key policy. GetApiPolicyResponseOwnedView Self-contained, 'static owned view of a GetApiPolicyResponse message. GetApiPolicyResponseView GetApiPolicyResponse returns the requested API key policy. GetNonceRequest GetNonceRequest requests a short-lived login nonce for a smart-account
address. The wallet must sign a message containing this nonce before login. GetNonceRequestOwnedView Self-contained, 'static owned view of a GetNonceRequest message. GetNonceRequestView GetNonceRequest requests a short-lived login nonce for a smart-account
address. The wallet must sign a message containing this nonce before login. GetNonceResponse GetNonceResponse contains the nonce that must be signed for wallet login. GetNonceResponseOwnedView Self-contained, 'static owned view of a GetNonceResponse message. GetNonceResponseView GetNonceResponse contains the nonce that must be signed for wallet login. GetProfileRequest GetProfileRequest fetches the authenticated caller’s profile. GetProfileRequestOwnedView Self-contained, 'static owned view of a GetProfileRequest message. GetProfileRequestView GetProfileRequest fetches the authenticated caller’s profile. GetSocialVerificationRequest GetSocialVerificationRequest fetches the caller’s current social verification
state for one provider. GetSocialVerificationRequestOwnedView Self-contained, 'static owned view of a GetSocialVerificationRequest message. GetSocialVerificationRequestView GetSocialVerificationRequest fetches the caller’s current social verification
state for one provider. GetSocialVerificationResponse GetSocialVerificationResponse contains the caller’s current social
verification state for one provider. GetSocialVerificationResponseOwnedView Self-contained, 'static owned view of a GetSocialVerificationResponse message. GetSocialVerificationResponseView GetSocialVerificationResponse contains the caller’s current social
verification state for one provider. GetSubaccountPolicyRequest GetSubaccountPolicyRequest fetches one sub-account policy template by ID. GetSubaccountPolicyRequestOwnedView Self-contained, 'static owned view of a GetSubaccountPolicyRequest message. GetSubaccountPolicyRequestView GetSubaccountPolicyRequest fetches one sub-account policy template by ID. GetSubaccountPolicyResponse GetSubaccountPolicyResponse returns the requested sub-account policy. GetSubaccountPolicyResponseOwnedView Self-contained, 'static owned view of a GetSubaccountPolicyResponse message. GetSubaccountPolicyResponseView GetSubaccountPolicyResponse returns the requested sub-account policy. GetSubaccountRequest Request for an aggregated sub-account read view. GetSubaccountRequestOwnedView Self-contained, 'static owned view of a GetSubaccountRequest message. GetSubaccountRequestView Request for an aggregated sub-account read view. GetSubaccountResponse Aggregated sub-account read view. GetSubaccountResponseOwnedView Self-contained, 'static owned view of a GetSubaccountResponse message. GetSubaccountResponseView Aggregated sub-account read view. GetUsernameHistoryRequest GetUsernameHistoryRequest fetches recent username changes for the
authenticated caller. GetUsernameHistoryRequestOwnedView Self-contained, 'static owned view of a GetUsernameHistoryRequest message. GetUsernameHistoryRequestView GetUsernameHistoryRequest fetches recent username changes for the
authenticated caller. GetUsernameHistoryResponse GetUsernameHistoryResponse contains the caller’s recent username history,
newest first. At most 20 entries are returned. GetUsernameHistoryResponseOwnedView Self-contained, 'static owned view of a GetUsernameHistoryResponse message. GetUsernameHistoryResponseView GetUsernameHistoryResponse contains the caller’s recent username history,
newest first. At most 20 entries are returned. GetWithdrawWhitelistViewRequest GetWithdrawWhitelistViewRequestOwnedView Self-contained, 'static owned view of a GetWithdrawWhitelistViewRequest message. GetWithdrawWhitelistViewRequestView GetWithdrawWhitelistViewResponse GetWithdrawWhitelistViewResponseOwnedView Self-contained, 'static owned view of a GetWithdrawWhitelistViewResponse message. GetWithdrawWhitelistViewResponseView InternalAddressBookEntry InternalAddressBookEntryOwnedView Self-contained, 'static owned view of a InternalAddressBookEntry message. InternalAddressBookEntryView InternalRecentDestination InternalRecentDestinationOwnedView Self-contained, 'static owned view of a InternalRecentDestination message. InternalRecentDestinationView InternalTransferAccount InternalTransferAccountOwnedView Self-contained, 'static owned view of a InternalTransferAccount message. InternalTransferAccountView InternalTransferWhitelistEntry InternalTransferWhitelistEntryOwnedView Self-contained, 'static owned view of a InternalTransferWhitelistEntry message. InternalTransferWhitelistEntryView InviteSubaccountMemberRequest Request to invite another root account to a sub-account. InviteSubaccountMemberRequestOwnedView Self-contained, 'static owned view of a InviteSubaccountMemberRequest message. InviteSubaccountMemberRequestView Request to invite another root account to a sub-account. InviteSubaccountMemberResponse Response containing the created or refreshed invitation. InviteSubaccountMemberResponseOwnedView Self-contained, 'static owned view of a InviteSubaccountMemberResponse message. InviteSubaccountMemberResponseView Response containing the created or refreshed invitation. ListAddressBookEntriesRequest ListAddressBookEntriesRequestOwnedView Self-contained, 'static owned view of a ListAddressBookEntriesRequest message. ListAddressBookEntriesRequestView ListAddressBookEntriesResponse ListAddressBookEntriesResponseOwnedView Self-contained, 'static owned view of a ListAddressBookEntriesResponse message. ListAddressBookEntriesResponseView ListAddressBooksRequest ListAddressBooksRequestOwnedView Self-contained, 'static owned view of a ListAddressBooksRequest message. ListAddressBooksRequestView ListAddressBooksResponse ListAddressBooksResponseOwnedView Self-contained, 'static owned view of a ListAddressBooksResponse message. ListAddressBooksResponseView ListApiKeysRequest ListApiKeysRequest lists non-revoked API keys owned by the caller. ListApiKeysRequestOwnedView Self-contained, 'static owned view of a ListApiKeysRequest message. ListApiKeysRequestView ListApiKeysRequest lists non-revoked API keys owned by the caller. ListApiKeysResponse ListApiKeysResponse contains matching API keys, newest first by creation time. ListApiKeysResponseOwnedView Self-contained, 'static owned view of a ListApiKeysResponse message. ListApiKeysResponseView ListApiKeysResponse contains matching API keys, newest first by creation time. ListApiPoliciesRequest ListApiPoliciesRequest lists the finite set of API key policies visible in
the requested account scope. Results are sorted by ascending policy ID and
are not paginated. ListApiPoliciesRequestOwnedView Self-contained, 'static owned view of a ListApiPoliciesRequest message. ListApiPoliciesRequestView ListApiPoliciesRequest lists the finite set of API key policies visible in
the requested account scope. Results are sorted by ascending policy ID and
are not paginated. ListApiPoliciesResponse ListApiPoliciesResponse contains API key policy templates sorted by ascending
policy ID. ListApiPoliciesResponseOwnedView Self-contained, 'static owned view of a ListApiPoliciesResponse message. ListApiPoliciesResponseView ListApiPoliciesResponse contains API key policy templates sorted by ascending
policy ID. ListInternalTransferWhitelistEntriesRequest ListInternalTransferWhitelistEntriesRequestOwnedView Self-contained, 'static owned view of a ListInternalTransferWhitelistEntriesRequest message. ListInternalTransferWhitelistEntriesRequestView ListInternalTransferWhitelistEntriesResponse ListInternalTransferWhitelistEntriesResponseOwnedView Self-contained, 'static owned view of a ListInternalTransferWhitelistEntriesResponse message. ListInternalTransferWhitelistEntriesResponseView ListMFAFactorsRequest Request to list the caller’s MFA factors. ListMFAFactorsRequestOwnedView Self-contained, 'static owned view of a ListMFAFactorsRequest message. ListMFAFactorsRequestView Request to list the caller’s MFA factors. ListMFAFactorsResponse Response containing the caller’s enrolled MFA factors. ListMFAFactorsResponseOwnedView Self-contained, 'static owned view of a ListMFAFactorsResponse message. ListMFAFactorsResponseView Response containing the caller’s enrolled MFA factors. ListSubaccountEventsRequest Request to list sub-account activity. ListSubaccountEventsRequestOwnedView Self-contained, 'static owned view of a ListSubaccountEventsRequest message. ListSubaccountEventsRequestView Request to list sub-account activity. ListSubaccountEventsResponse Response containing sub-account activity events. ListSubaccountEventsResponseOwnedView Self-contained, 'static owned view of a ListSubaccountEventsResponse message. ListSubaccountEventsResponseView Response containing sub-account activity events. ListSubaccountInvitesRequest Request to list sub-account invitations. ListSubaccountInvitesRequestOwnedView Self-contained, 'static owned view of a ListSubaccountInvitesRequest message. ListSubaccountInvitesRequestView Request to list sub-account invitations. ListSubaccountInvitesResponse Response containing sub-account invitations. ListSubaccountInvitesResponseOwnedView Self-contained, 'static owned view of a ListSubaccountInvitesResponse message. ListSubaccountInvitesResponseView Response containing sub-account invitations. ListSubaccountMembersRequest Request to list members for a sub-account. ListSubaccountMembersRequestOwnedView Self-contained, 'static owned view of a ListSubaccountMembersRequest message. ListSubaccountMembersRequestView Request to list members for a sub-account. ListSubaccountMembersResponse Response containing the members of a sub-account. ListSubaccountMembersResponseOwnedView Self-contained, 'static owned view of a ListSubaccountMembersResponse message. ListSubaccountMembersResponseView Response containing the members of a sub-account. ListSubaccountPoliciesRequest ListSubaccountPoliciesRequest lists the finite set of sub-account policies
visible in the requested account scope. Results are sorted by ascending
policy ID and are not paginated. ListSubaccountPoliciesRequestOwnedView Self-contained, 'static owned view of a ListSubaccountPoliciesRequest message. ListSubaccountPoliciesRequestView ListSubaccountPoliciesRequest lists the finite set of sub-account policies
visible in the requested account scope. Results are sorted by ascending
policy ID and are not paginated. ListSubaccountPoliciesResponse ListSubaccountPoliciesResponse contains sub-account policy templates sorted
by ascending policy ID. ListSubaccountPoliciesResponseOwnedView Self-contained, 'static owned view of a ListSubaccountPoliciesResponse message. ListSubaccountPoliciesResponseView ListSubaccountPoliciesResponse contains sub-account policy templates sorted
by ascending policy ID. ListSubaccountsRequest Request to list sub-accounts owned by or shared with the caller. ListSubaccountsRequestOwnedView Self-contained, 'static owned view of a ListSubaccountsRequest message. ListSubaccountsRequestView Request to list sub-accounts owned by or shared with the caller. ListSubaccountsResponse Response containing sub-accounts visible to the caller. ListSubaccountsResponseOwnedView Self-contained, 'static owned view of a ListSubaccountsResponse message. ListSubaccountsResponseView Response containing sub-accounts visible to the caller. ListTransferCounterpartiesRequest ListTransferCounterpartiesRequestOwnedView Self-contained, 'static owned view of a ListTransferCounterpartiesRequest message. ListTransferCounterpartiesRequestView ListTransferCounterpartiesResponse ListTransferCounterpartiesResponseOwnedView Self-contained, 'static owned view of a ListTransferCounterpartiesResponse message. ListTransferCounterpartiesResponseView ListTransferDestinationsRequest ListTransferDestinationsRequestOwnedView Self-contained, 'static owned view of a ListTransferDestinationsRequest message. ListTransferDestinationsRequestView ListTransferDestinationsResponse ListTransferDestinationsResponseOwnedView Self-contained, 'static owned view of a ListTransferDestinationsResponse message. ListTransferDestinationsResponseView LoginWithWalletRequest LoginWithWalletRequest completes smart-account wallet login using a signed
nonce. LoginWithWalletRequestOwnedView Self-contained, 'static owned view of a LoginWithWalletRequest message. LoginWithWalletRequestView LoginWithWalletRequest completes smart-account wallet login using a signed
nonce. LoginWithWalletResponse LoginWithWalletResponse returns a session token for the authenticated root
account. LoginWithWalletResponseOwnedView Self-contained, 'static owned view of a LoginWithWalletResponse message. LoginWithWalletResponseView LoginWithWalletResponse returns a session token for the authenticated root
account. MFAFactor Enrolled MFA factor metadata visible to the account owner. MFAFactorOwnedView Self-contained, 'static owned view of a MFAFactor message. MFAFactorView Enrolled MFA factor metadata visible to the account owner. MarketScope MarketScope describes how a policy applies to spot markets or perp contracts. MarketScopeOwnedView Self-contained, 'static owned view of a MarketScope message. MarketScopeView MarketScope describes how a policy applies to spot markets or perp contracts. MeRequest MeRequest introspects the authenticated caller from the presented access
token or API key. MeRequestOwnedView Self-contained, 'static owned view of a MeRequest message. MeRequestView MeRequest introspects the authenticated caller from the presented access
token or API key. MeResponse MeResponse describes the authenticated caller and current session context. MeResponseOwnedView Self-contained, 'static owned view of a MeResponse message. MeResponseView MeResponse describes the authenticated caller and current session context. MirroredWithdrawWhitelistEntry MirroredWithdrawWhitelistEntryOwnedView Self-contained, 'static owned view of a MirroredWithdrawWhitelistEntry message. MirroredWithdrawWhitelistEntryView PerpMarketRule PerpMarketRule describes an allowed perp contract and optional max leverage. PerpMarketRuleOwnedView Self-contained, 'static owned view of a PerpMarketRule message. PerpMarketRuleView PerpMarketRule describes an allowed perp contract and optional max leverage. ProfileErrorDetail ProfileErrorDetail describes a profile validation failure returned by the API. ProfileErrorDetailOwnedView Self-contained, 'static owned view of a ProfileErrorDetail message. ProfileErrorDetailView ProfileErrorDetail describes a profile validation failure returned by the API. RegenerateRecoveryCodesRequest Request to rotate recovery codes. RegenerateRecoveryCodesRequestOwnedView Self-contained, 'static owned view of a RegenerateRecoveryCodesRequest message. RegenerateRecoveryCodesRequestView Request to rotate recovery codes. RegenerateRecoveryCodesResponse Response containing newly generated recovery codes. RegenerateRecoveryCodesResponseOwnedView Self-contained, 'static owned view of a RegenerateRecoveryCodesResponse message. RegenerateRecoveryCodesResponseView Response containing newly generated recovery codes. ReleaseFreshStepUpRequest Request to release a claimed fresh step-up proof when the protected request does not complete. ReleaseFreshStepUpRequestOwnedView Self-contained, 'static owned view of a ReleaseFreshStepUpRequest message. ReleaseFreshStepUpRequestView Request to release a claimed fresh step-up proof when the protected request does not complete. ReleaseFreshStepUpResponse Empty response returned after a fresh step-up proof is released. ReleaseFreshStepUpResponseOwnedView Self-contained, 'static owned view of a ReleaseFreshStepUpResponse message. ReleaseFreshStepUpResponseView Empty response returned after a fresh step-up proof is released. RemoveSubaccountMemberRequest Request to remove a delegated member from a sub-account. RemoveSubaccountMemberRequestOwnedView Self-contained, 'static owned view of a RemoveSubaccountMemberRequest message. RemoveSubaccountMemberRequestView Request to remove a delegated member from a sub-account. RemoveSubaccountMemberResponse Empty response returned after removing a sub-account member. RemoveSubaccountMemberResponseOwnedView Self-contained, 'static owned view of a RemoveSubaccountMemberResponse message. RemoveSubaccountMemberResponseView Empty response returned after removing a sub-account member. RequestedInternalTransferAccount RequestedInternalTransferAccountOwnedView Self-contained, 'static owned view of a RequestedInternalTransferAccount message. RequestedInternalTransferAccountView ResolveAccountRequest ResolveAccountRequest searches for a transfer or sharing destination by
username, account ID, or smart-account address. ResolveAccountRequestOwnedView Self-contained, 'static owned view of a ResolveAccountRequest message. ResolveAccountRequestView ResolveAccountRequest searches for a transfer or sharing destination by
username, account ID, or smart-account address. ResolveAccountResponse ResolveAccountResponse contains matching accounts. Username and root-only
smart-account lookups return at most 5 matches; smart-account lookups with
include_subaccounts may return at most 10 matches. ResolveAccountResponseOwnedView Self-contained, 'static owned view of a ResolveAccountResponse message. ResolveAccountResponseView ResolveAccountResponse contains matching accounts. Username and root-only
smart-account lookups return at most 5 matches; smart-account lookups with
include_subaccounts may return at most 10 matches. ResolvedAccount ResolvedAccount represents a lightweight view of a destination account for
sharing or internal transfers. ResolvedAccountOwnedView Self-contained, 'static owned view of a ResolvedAccount message. ResolvedAccountView ResolvedAccount represents a lightweight view of a destination account for
sharing or internal transfers. RespondSubaccountInviteRequest Request to accept, decline, or cancel an invitation. RespondSubaccountInviteRequestOwnedView Self-contained, 'static owned view of a RespondSubaccountInviteRequest message. RespondSubaccountInviteRequestView Request to accept, decline, or cancel an invitation. RespondSubaccountInviteResponse Response containing the updated invitation. RespondSubaccountInviteResponseOwnedView Self-contained, 'static owned view of a RespondSubaccountInviteResponse message. RespondSubaccountInviteResponseView Response containing the updated invitation. SessionInfo Current assurance details for an interactive session. SessionInfoOwnedView Self-contained, 'static owned view of a SessionInfo message. SessionInfoView Current assurance details for an interactive session. SetApiKeyPolicyRequest SetApiKeyPolicyRequest attaches or clears a policy template on an API key. SetApiKeyPolicyRequestOwnedView Self-contained, 'static owned view of a SetApiKeyPolicyRequest message. SetApiKeyPolicyRequestView SetApiKeyPolicyRequest attaches or clears a policy template on an API key. SetApiKeyPolicyResponse SetApiKeyPolicyResponse is empty when the policy binding succeeds. SetApiKeyPolicyResponseOwnedView Self-contained, 'static owned view of a SetApiKeyPolicyResponse message. SetApiKeyPolicyResponseView SetApiKeyPolicyResponse is empty when the policy binding succeeds. SetSubaccountMemberMFARequirementRequest Request to update the delegated-member MFA requirement for a sub-account. SetSubaccountMemberMFARequirementRequestOwnedView Self-contained, 'static owned view of a SetSubaccountMemberMFARequirementRequest message. SetSubaccountMemberMFARequirementRequestView Request to update the delegated-member MFA requirement for a sub-account. SetSubaccountMemberMFARequirementResponse Empty response returned after updating the delegated-member MFA requirement. SetSubaccountMemberMFARequirementResponseOwnedView Self-contained, 'static owned view of a SetSubaccountMemberMFARequirementResponse message. SetSubaccountMemberMFARequirementResponseView Empty response returned after updating the delegated-member MFA requirement. SetSubaccountPolicyRequest SetSubaccountPolicyRequest attaches or clears a policy template on a
sub-account. SetSubaccountPolicyRequestOwnedView Self-contained, 'static owned view of a SetSubaccountPolicyRequest message. SetSubaccountPolicyRequestView SetSubaccountPolicyRequest attaches or clears a policy template on a
sub-account. SetSubaccountPolicyResponse SetSubaccountPolicyResponse is empty when the policy binding succeeds. SetSubaccountPolicyResponseOwnedView Self-contained, 'static owned view of a SetSubaccountPolicyResponse message. SetSubaccountPolicyResponseView SetSubaccountPolicyResponse is empty when the policy binding succeeds. SocialVerification SocialVerification describes the caller’s current verification state for one
social provider. SocialVerificationOwnedView Self-contained, 'static owned view of a SocialVerification message. SocialVerificationReadyRequest SocialVerificationReadyRequest tells the API that the challenge code has been
placed and the provider account is ready to check. SocialVerificationReadyRequestOwnedView Self-contained, 'static owned view of a SocialVerificationReadyRequest message. SocialVerificationReadyRequestView SocialVerificationReadyRequest tells the API that the challenge code has been
placed and the provider account is ready to check. SocialVerificationReadyResponse SocialVerificationReadyResponse returns the verification after it has been
queued for a provider check. SocialVerificationReadyResponseOwnedView Self-contained, 'static owned view of a SocialVerificationReadyResponse message. SocialVerificationReadyResponseView SocialVerificationReadyResponse returns the verification after it has been
queued for a provider check. SocialVerificationView SocialVerification describes the caller’s current verification state for one
social provider. SpotMarketRule SpotMarketRule describes an allowed spot market for a sub-account policy. SpotMarketRuleOwnedView Self-contained, 'static owned view of a SpotMarketRule message. SpotMarketRuleView SpotMarketRule describes an allowed spot market for a sub-account policy. StartSocialVerificationRequest StartSocialVerificationRequest starts or restarts social account verification.
Starting again for the same provider replaces the previous challenge. StartSocialVerificationRequestOwnedView Self-contained, 'static owned view of a StartSocialVerificationRequest message. StartSocialVerificationRequestView StartSocialVerificationRequest starts or restarts social account verification.
Starting again for the same provider replaces the previous challenge. StartSocialVerificationResponse Response returned after starting social account verification. StartSocialVerificationResponseOwnedView Self-contained, 'static owned view of a StartSocialVerificationResponse message. StartSocialVerificationResponseView Response returned after starting social account verification. Subaccount Sub-account summary visible to the caller. SubaccountInvite View of a pending or historical invitation to a sub-account. SubaccountInviteOwnedView Self-contained, 'static owned view of a SubaccountInvite message. SubaccountInviteView View of a pending or historical invitation to a sub-account. SubaccountMemberView Member summary for a root account with access to a sub-account. SubaccountMemberViewOwnedView Self-contained, 'static owned view of a SubaccountMemberView message. SubaccountMemberViewView Member summary for a root account with access to a sub-account. SubaccountOwnedView Self-contained, 'static owned view of a Subaccount message. SubaccountPolicySpec SubaccountPolicySpec contains the mutable configuration of a sub-account policy. SubaccountPolicySpecOwnedView Self-contained, 'static owned view of a SubaccountPolicySpec message. SubaccountPolicySpecView SubaccountPolicySpec contains the mutable configuration of a sub-account policy. SubaccountPolicyView SubaccountPolicyView is the public view of a sub-account policy. SubaccountPolicyViewOwnedView Self-contained, 'static owned view of a SubaccountPolicyView message. SubaccountPolicyViewView SubaccountPolicyView is the public view of a sub-account policy. SubaccountRoleView Role summary for one sub-account visible to the caller. SubaccountRoleViewOwnedView Self-contained, 'static owned view of a SubaccountRoleView message. SubaccountRoleViewView Role summary for one sub-account visible to the caller. SubaccountUpdateSpec SubaccountUpdateSpec contains mutable display and status configuration. SubaccountUpdateSpecOwnedView Self-contained, 'static owned view of a SubaccountUpdateSpec message. SubaccountUpdateSpecView SubaccountUpdateSpec contains mutable display and status configuration. SubaccountView Sub-account summary visible to the caller. TransferCounterparty TransferCounterpartyOwnedView Self-contained, 'static owned view of a TransferCounterparty message. TransferCounterpartyView TransferDestination TransferDestinationOwnedView Self-contained, 'static owned view of a TransferDestination message. TransferDestinationView UpdateAddressBookEntryRequest UpdateAddressBookEntryRequestOwnedView Self-contained, 'static owned view of a UpdateAddressBookEntryRequest message. UpdateAddressBookEntryRequestView UpdateAddressBookEntryResponse UpdateAddressBookEntryResponseOwnedView Self-contained, 'static owned view of a UpdateAddressBookEntryResponse message. UpdateAddressBookEntryResponseView UpdateAddressBookTagRequest UpdateAddressBookTagRequestOwnedView Self-contained, 'static owned view of a UpdateAddressBookTagRequest message. UpdateAddressBookTagRequestView UpdateAddressBookTagResponse UpdateAddressBookTagResponseOwnedView Self-contained, 'static owned view of a UpdateAddressBookTagResponse message. UpdateAddressBookTagResponseView UpdateApiKeyRequest UpdateApiKeyRequest changes selected mutable fields on an existing API key. UpdateApiKeyRequestOwnedView Self-contained, 'static owned view of a UpdateApiKeyRequest message. UpdateApiKeyRequestView UpdateApiKeyRequest changes selected mutable fields on an existing API key. UpdateApiKeyResponse UpdateApiKeyResponse returns the API key after applying the update. UpdateApiKeyResponseOwnedView Self-contained, 'static owned view of a UpdateApiKeyResponse message. UpdateApiKeyResponseView UpdateApiKeyResponse returns the API key after applying the update. UpdateApiPolicyRequest UpdateApiPolicyRequest changes selected mutable fields on an existing API
key policy. UpdateApiPolicyRequestOwnedView Self-contained, 'static owned view of a UpdateApiPolicyRequest message. UpdateApiPolicyRequestView UpdateApiPolicyRequest changes selected mutable fields on an existing API
key policy. UpdateApiPolicyResponse UpdateApiPolicyResponse returns the updated API key policy. UpdateApiPolicyResponseOwnedView Self-contained, 'static owned view of a UpdateApiPolicyResponse message. UpdateApiPolicyResponseView UpdateApiPolicyResponse returns the updated API key policy. UpdateMFAFactorRequest Request to update an MFA factor label. UpdateMFAFactorRequestOwnedView Self-contained, 'static owned view of a UpdateMFAFactorRequest message. UpdateMFAFactorRequestView Request to update an MFA factor label. UpdateMFAFactorResponse Response containing the updated MFA factor. UpdateMFAFactorResponseOwnedView Self-contained, 'static owned view of a UpdateMFAFactorResponse message. UpdateMFAFactorResponseView Response containing the updated MFA factor. UpdateSubaccountMemberRoleRequest Request to change the role of an existing sub-account member without sending a new invitation. UpdateSubaccountMemberRoleRequestOwnedView Self-contained, 'static owned view of a UpdateSubaccountMemberRoleRequest message. UpdateSubaccountMemberRoleRequestView Request to change the role of an existing sub-account member without sending a new invitation. UpdateSubaccountMemberRoleResponse Empty response returned after updating a member role. UpdateSubaccountMemberRoleResponseOwnedView Self-contained, 'static owned view of a UpdateSubaccountMemberRoleResponse message. UpdateSubaccountMemberRoleResponseView Empty response returned after updating a member role. UpdateSubaccountPolicyRequest UpdateSubaccountPolicyRequest changes selected mutable fields on an existing
sub-account policy. UpdateSubaccountPolicyRequestOwnedView Self-contained, 'static owned view of a UpdateSubaccountPolicyRequest message. UpdateSubaccountPolicyRequestView UpdateSubaccountPolicyRequest changes selected mutable fields on an existing
sub-account policy. UpdateSubaccountPolicyResponse UpdateSubaccountPolicyResponse returns the updated sub-account policy. UpdateSubaccountPolicyResponseOwnedView Self-contained, 'static owned view of a UpdateSubaccountPolicyResponse message. UpdateSubaccountPolicyResponseView UpdateSubaccountPolicyResponse returns the updated sub-account policy. UpdateSubaccountRequest Request to change selected mutable fields for a sub-account. UpdateSubaccountRequestOwnedView Self-contained, 'static owned view of a UpdateSubaccountRequest message. UpdateSubaccountRequestView Request to change selected mutable fields for a sub-account. UpdateSubaccountResponse Response returned after updating a sub-account. UpdateSubaccountResponseOwnedView Self-contained, 'static owned view of a UpdateSubaccountResponse message. UpdateSubaccountResponseView Response returned after updating a sub-account. UserProfile UserProfile is the caller’s public profile and account metadata. UserProfileOwnedView Self-contained, 'static owned view of a UserProfile message. UserProfilePatch UserProfilePatch is a partial profile update. Fields are
optional/presence-aware: UserProfilePatchOwnedView Self-contained, 'static owned view of a UserProfilePatch message. UserProfilePatchView UserProfilePatch is a partial profile update. Fields are
optional/presence-aware: UserProfileView UserProfile is the caller’s public profile and account metadata. UsernameHistoryEntry UsernameHistoryEntry records a previous username claim for the caller. UsernameHistoryEntryOwnedView Self-contained, 'static owned view of a UsernameHistoryEntry message. UsernameHistoryEntryView UsernameHistoryEntry records a previous username claim for the caller. VerifyRecoveryCodeChallengeRequest Request to verify an MFA challenge with a recovery code. VerifyRecoveryCodeChallengeRequestOwnedView Self-contained, 'static owned view of a VerifyRecoveryCodeChallengeRequest message. VerifyRecoveryCodeChallengeRequestView Request to verify an MFA challenge with a recovery code. VerifyTOTPChallengeRequest Request to verify an MFA challenge with an authenticator-app code. VerifyTOTPChallengeRequestOwnedView Self-contained, 'static owned view of a VerifyTOTPChallengeRequest message. VerifyTOTPChallengeRequestView Request to verify an MFA challenge with an authenticator-app code. WithdrawWhitelistView WithdrawWhitelistViewOwnedView Self-contained, 'static owned view of a WithdrawWhitelistView message. WithdrawWhitelistViewView AccountScopeType AccountScopeType identifies whether address-book data belongs to the root account or a subaccount. ActivityEntityKind Entity category affected by an activity event. ActivityEventAction Action recorded by an activity event. ActivityEventSource Client channel from which an activity event originated. AddressBookEntryKind AddressBookEntryKind identifies the type of saved transfer destination. ApiKeyStatus Status of an API key. AuthErrorCode High-level error codes for authentication and account-domain failures. DestinationWhitelistStatus DestinationWhitelistStatus describes whether a transfer destination currently has an active whitelist allowance. InternalWhitelistResolutionStatus InternalWhitelistResolutionStatus shows whether an internal account destination could be matched to account details. MFAChallengePurpose Reason a user is completing an MFA challenge. MFAFactorType Type of MFA factor or one-time recovery method. PolicyAction PolicyAction is a high-level permission that can be granted by a policy.
Write-style actions also grant the matching read visibility where needed by
the product experience. ProfileErrorCode — Typed errors for ProfileService — ResolveHint ResolveHint controls how ResolveAccount interprets the query. SessionLevel Session assurance level for the current interactive authentication context. SocialProvider Social account provider used for account ownership verification. SocialVerificationMethod How the user proves control of the provider account. SocialVerificationStatus Current state of a social account verification attempt. SubaccountInviteAction Action to take on a sub-account invitation. SubaccountInviteStatus Status of an invitation to join a sub-account. SubaccountRole Role granted to a root account on a sub-account. TransferCounterpartyDirection TransferCounterpartyDirection identifies how a recent counterparty was used. register_types Register this package’s Any type entries and extension entries.