#[repr(i32)]pub enum AuthErrorCode {
Show 39 variants
AUTH_UNSPECIFIED = 0,
AUTH_USERNAME_INVALID = 1,
AUTH_USERNAME_TAKEN = 2,
AUTH_USERNAME_COOLDOWN = 3,
AUTH_USERNAME_FEATURE_LOCKED = 4,
AUTH_USERNAME_RESERVED = 5,
AUTH_INVALID_REQUEST = 6,
AUTH_AUTHENTICATION_REQUIRED = 7,
AUTH_SESSION_KIND_NOT_ALLOWED = 8,
AUTH_WALLET_LOGIN_FAILED = 9,
AUTH_RESOURCE_NOT_FOUND = 10,
AUTH_SUBACCOUNT_ACCESS_DENIED = 11,
AUTH_API_KEY_ACCESS_DENIED = 12,
AUTH_API_KEY_INVALID_STATUS_TRANSITION = 14,
AUTH_POLICY_INVALID = 15,
AUTH_SMART_ACCOUNT_ALREADY_LINKED = 16,
AUTH_INVITE_ACCESS_DENIED = 17,
AUTH_INVITE_INVALID_STATE = 18,
AUTH_MFA_DISABLED = 19,
AUTH_MFA_NOT_ENROLLED = 20,
AUTH_MFA_SESSION_INVALID = 21,
AUTH_MFA_CHALLENGE_NOT_FOUND = 22,
AUTH_MFA_CHALLENGE_INVALID = 23,
AUTH_MFA_CHALLENGE_LOCKED = 24,
AUTH_MFA_OTP_INVALID = 25,
AUTH_MFA_RECOVERY_INVALID = 26,
AUTH_MFA_PASSKEY_NOT_AVAILABLE = 27,
AUTH_MFA_PASSKEY_CREDENTIAL_INVALID = 28,
AUTH_MFA_PASSKEY_VERIFY_FAILED = 29,
AUTH_MFA_ENROLLMENT_BINDING_INVALID = 30,
AUTH_STEP_UP_REQUIRED = 31,
AUTH_STEP_UP_PROOF_UNAVAILABLE = 32,
AUTH_STEP_UP_ALREADY_CLAIMED = 33,
AUTH_POLICY_IN_USE = 34,
AUTH_POLICY_LOCKED = 35,
AUTH_POLICY_SCOPE_MISMATCH = 36,
AUTH_REVISION_CONFLICT = 37,
AUTH_MFA_ELEVATION_REQUIRED = 38,
AUTH_MFA_LAST_FACTOR_REQUIRED = 39,
}Expand description
High-level error codes for authentication and account-domain failures.
Variants
AUTH_UNSPECIFIED = 0
No auth error code specified.
AUTH_USERNAME_INVALID = 1
Username format or characters are invalid.
AUTH_USERNAME_TAKEN = 2
Username is already used by another account.
AUTH_USERNAME_COOLDOWN = 3
Username was changed too recently.
AUTH_USERNAME_FEATURE_LOCKED = 4
Account is not currently eligible to claim or change a username.
AUTH_USERNAME_RESERVED = 5
Username is reserved and cannot be claimed by this account.
AUTH_INVALID_REQUEST = 6
Request is malformed or missing required input.
AUTH_AUTHENTICATION_REQUIRED = 7
Authentication is required for this operation.
AUTH_SESSION_KIND_NOT_ALLOWED = 8
Presented session type is not allowed for this operation.
AUTH_WALLET_LOGIN_FAILED = 9
Wallet login failed because the nonce or signature could not be verified.
AUTH_RESOURCE_NOT_FOUND = 10
Requested resource was not found.
AUTH_SUBACCOUNT_ACCESS_DENIED = 11
Caller does not have access to the requested sub-account.
AUTH_API_KEY_ACCESS_DENIED = 12
Caller does not have access to the requested API key.
AUTH_API_KEY_INVALID_STATUS_TRANSITION = 14
Requested API key status transition is not allowed.
AUTH_POLICY_INVALID = 15
Policy definition or binding is invalid.
AUTH_SMART_ACCOUNT_ALREADY_LINKED = 16
Smart-account address is already linked to another account.
AUTH_INVITE_ACCESS_DENIED = 17
Caller does not have access to the requested invite.
AUTH_INVITE_INVALID_STATE = 18
Invite cannot be used in its current state.
AUTH_MFA_DISABLED = 19
MFA is not available for this account.
AUTH_MFA_NOT_ENROLLED = 20
Required MFA factor is not enrolled.
AUTH_MFA_SESSION_INVALID = 21
MFA session is missing, expired, or invalid.
AUTH_MFA_CHALLENGE_NOT_FOUND = 22
MFA challenge was not found.
AUTH_MFA_CHALLENGE_INVALID = 23
MFA challenge payload is invalid.
AUTH_MFA_CHALLENGE_LOCKED = 24
MFA challenge is locked after too many failed attempts.
AUTH_MFA_OTP_INVALID = 25
One-time password is invalid.
AUTH_MFA_RECOVERY_INVALID = 26
Recovery code is invalid.
AUTH_MFA_PASSKEY_NOT_AVAILABLE = 27
Passkey verification is not available for this challenge.
AUTH_MFA_PASSKEY_CREDENTIAL_INVALID = 28
Passkey credential is invalid for this account or challenge.
AUTH_MFA_PASSKEY_VERIFY_FAILED = 29
Passkey verification failed.
AUTH_MFA_ENROLLMENT_BINDING_INVALID = 30
MFA enrollment binding is invalid or expired.
AUTH_STEP_UP_REQUIRED = 31
A fresh step-up proof is required for this protected operation.
AUTH_STEP_UP_PROOF_UNAVAILABLE = 32
A requested step-up proof is unavailable.
AUTH_STEP_UP_ALREADY_CLAIMED = 33
The step-up proof has already been claimed.
AUTH_POLICY_IN_USE = 34
The requested policy cannot be removed because it is still in use.
AUTH_POLICY_LOCKED = 35
The requested policy is locked against this mutation.
AUTH_POLICY_SCOPE_MISMATCH = 36
The requested policy does not belong to the target account scope.
AUTH_REVISION_CONFLICT = 37
The resource changed after the caller read it.
AUTH_MFA_ELEVATION_REQUIRED = 38
A recently MFA-elevated interactive session is required.
AUTH_MFA_LAST_FACTOR_REQUIRED = 39
At least one active MFA factor must remain enrolled.
Implementations
Sourceimpl AuthErrorCode
impl AuthErrorCode
Sourcepub const AuthUnspecified: Self = Self::AUTH_UNSPECIFIED
pub const AuthUnspecified: Self = Self::AUTH_UNSPECIFIED
Idiomatic alias for Self::AUTH_UNSPECIFIED; Debug prints the variant name.
Sourcepub const AuthUsernameInvalid: Self = Self::AUTH_USERNAME_INVALID
pub const AuthUsernameInvalid: Self = Self::AUTH_USERNAME_INVALID
Idiomatic alias for Self::AUTH_USERNAME_INVALID; Debug prints the variant name.
Sourcepub const AuthUsernameTaken: Self = Self::AUTH_USERNAME_TAKEN
pub const AuthUsernameTaken: Self = Self::AUTH_USERNAME_TAKEN
Idiomatic alias for Self::AUTH_USERNAME_TAKEN; Debug prints the variant name.
Sourcepub const AuthUsernameCooldown: Self = Self::AUTH_USERNAME_COOLDOWN
pub const AuthUsernameCooldown: Self = Self::AUTH_USERNAME_COOLDOWN
Idiomatic alias for Self::AUTH_USERNAME_COOLDOWN; Debug prints the variant name.
Sourcepub const AuthUsernameFeatureLocked: Self = Self::AUTH_USERNAME_FEATURE_LOCKED
pub const AuthUsernameFeatureLocked: Self = Self::AUTH_USERNAME_FEATURE_LOCKED
Idiomatic alias for Self::AUTH_USERNAME_FEATURE_LOCKED; Debug prints the variant name.
Sourcepub const AuthUsernameReserved: Self = Self::AUTH_USERNAME_RESERVED
pub const AuthUsernameReserved: Self = Self::AUTH_USERNAME_RESERVED
Idiomatic alias for Self::AUTH_USERNAME_RESERVED; Debug prints the variant name.
Sourcepub const AuthInvalidRequest: Self = Self::AUTH_INVALID_REQUEST
pub const AuthInvalidRequest: Self = Self::AUTH_INVALID_REQUEST
Idiomatic alias for Self::AUTH_INVALID_REQUEST; Debug prints the variant name.
Sourcepub const AuthAuthenticationRequired: Self = Self::AUTH_AUTHENTICATION_REQUIRED
pub const AuthAuthenticationRequired: Self = Self::AUTH_AUTHENTICATION_REQUIRED
Idiomatic alias for Self::AUTH_AUTHENTICATION_REQUIRED; Debug prints the variant name.
Sourcepub const AuthSessionKindNotAllowed: Self = Self::AUTH_SESSION_KIND_NOT_ALLOWED
pub const AuthSessionKindNotAllowed: Self = Self::AUTH_SESSION_KIND_NOT_ALLOWED
Idiomatic alias for Self::AUTH_SESSION_KIND_NOT_ALLOWED; Debug prints the variant name.
Sourcepub const AuthWalletLoginFailed: Self = Self::AUTH_WALLET_LOGIN_FAILED
pub const AuthWalletLoginFailed: Self = Self::AUTH_WALLET_LOGIN_FAILED
Idiomatic alias for Self::AUTH_WALLET_LOGIN_FAILED; Debug prints the variant name.
Sourcepub const AuthResourceNotFound: Self = Self::AUTH_RESOURCE_NOT_FOUND
pub const AuthResourceNotFound: Self = Self::AUTH_RESOURCE_NOT_FOUND
Idiomatic alias for Self::AUTH_RESOURCE_NOT_FOUND; Debug prints the variant name.
Sourcepub const AuthSubaccountAccessDenied: Self = Self::AUTH_SUBACCOUNT_ACCESS_DENIED
pub const AuthSubaccountAccessDenied: Self = Self::AUTH_SUBACCOUNT_ACCESS_DENIED
Idiomatic alias for Self::AUTH_SUBACCOUNT_ACCESS_DENIED; Debug prints the variant name.
Sourcepub const AuthApiKeyAccessDenied: Self = Self::AUTH_API_KEY_ACCESS_DENIED
pub const AuthApiKeyAccessDenied: Self = Self::AUTH_API_KEY_ACCESS_DENIED
Idiomatic alias for Self::AUTH_API_KEY_ACCESS_DENIED; Debug prints the variant name.
Sourcepub const AuthApiKeyInvalidStatusTransition: Self = Self::AUTH_API_KEY_INVALID_STATUS_TRANSITION
pub const AuthApiKeyInvalidStatusTransition: Self = Self::AUTH_API_KEY_INVALID_STATUS_TRANSITION
Idiomatic alias for Self::AUTH_API_KEY_INVALID_STATUS_TRANSITION; Debug prints the variant name.
Sourcepub const AuthPolicyInvalid: Self = Self::AUTH_POLICY_INVALID
pub const AuthPolicyInvalid: Self = Self::AUTH_POLICY_INVALID
Idiomatic alias for Self::AUTH_POLICY_INVALID; Debug prints the variant name.
Sourcepub const AuthSmartAccountAlreadyLinked: Self = Self::AUTH_SMART_ACCOUNT_ALREADY_LINKED
pub const AuthSmartAccountAlreadyLinked: Self = Self::AUTH_SMART_ACCOUNT_ALREADY_LINKED
Idiomatic alias for Self::AUTH_SMART_ACCOUNT_ALREADY_LINKED; Debug prints the variant name.
Sourcepub const AuthInviteAccessDenied: Self = Self::AUTH_INVITE_ACCESS_DENIED
pub const AuthInviteAccessDenied: Self = Self::AUTH_INVITE_ACCESS_DENIED
Idiomatic alias for Self::AUTH_INVITE_ACCESS_DENIED; Debug prints the variant name.
Sourcepub const AuthInviteInvalidState: Self = Self::AUTH_INVITE_INVALID_STATE
pub const AuthInviteInvalidState: Self = Self::AUTH_INVITE_INVALID_STATE
Idiomatic alias for Self::AUTH_INVITE_INVALID_STATE; Debug prints the variant name.
Sourcepub const AuthMfaDisabled: Self = Self::AUTH_MFA_DISABLED
pub const AuthMfaDisabled: Self = Self::AUTH_MFA_DISABLED
Idiomatic alias for Self::AUTH_MFA_DISABLED; Debug prints the variant name.
Sourcepub const AuthMfaNotEnrolled: Self = Self::AUTH_MFA_NOT_ENROLLED
pub const AuthMfaNotEnrolled: Self = Self::AUTH_MFA_NOT_ENROLLED
Idiomatic alias for Self::AUTH_MFA_NOT_ENROLLED; Debug prints the variant name.
Sourcepub const AuthMfaSessionInvalid: Self = Self::AUTH_MFA_SESSION_INVALID
pub const AuthMfaSessionInvalid: Self = Self::AUTH_MFA_SESSION_INVALID
Idiomatic alias for Self::AUTH_MFA_SESSION_INVALID; Debug prints the variant name.
Sourcepub const AuthMfaChallengeNotFound: Self = Self::AUTH_MFA_CHALLENGE_NOT_FOUND
pub const AuthMfaChallengeNotFound: Self = Self::AUTH_MFA_CHALLENGE_NOT_FOUND
Idiomatic alias for Self::AUTH_MFA_CHALLENGE_NOT_FOUND; Debug prints the variant name.
Sourcepub const AuthMfaChallengeInvalid: Self = Self::AUTH_MFA_CHALLENGE_INVALID
pub const AuthMfaChallengeInvalid: Self = Self::AUTH_MFA_CHALLENGE_INVALID
Idiomatic alias for Self::AUTH_MFA_CHALLENGE_INVALID; Debug prints the variant name.
Sourcepub const AuthMfaChallengeLocked: Self = Self::AUTH_MFA_CHALLENGE_LOCKED
pub const AuthMfaChallengeLocked: Self = Self::AUTH_MFA_CHALLENGE_LOCKED
Idiomatic alias for Self::AUTH_MFA_CHALLENGE_LOCKED; Debug prints the variant name.
Sourcepub const AuthMfaOtpInvalid: Self = Self::AUTH_MFA_OTP_INVALID
pub const AuthMfaOtpInvalid: Self = Self::AUTH_MFA_OTP_INVALID
Idiomatic alias for Self::AUTH_MFA_OTP_INVALID; Debug prints the variant name.
Sourcepub const AuthMfaRecoveryInvalid: Self = Self::AUTH_MFA_RECOVERY_INVALID
pub const AuthMfaRecoveryInvalid: Self = Self::AUTH_MFA_RECOVERY_INVALID
Idiomatic alias for Self::AUTH_MFA_RECOVERY_INVALID; Debug prints the variant name.
Sourcepub const AuthMfaPasskeyNotAvailable: Self = Self::AUTH_MFA_PASSKEY_NOT_AVAILABLE
pub const AuthMfaPasskeyNotAvailable: Self = Self::AUTH_MFA_PASSKEY_NOT_AVAILABLE
Idiomatic alias for Self::AUTH_MFA_PASSKEY_NOT_AVAILABLE; Debug prints the variant name.
Sourcepub const AuthMfaPasskeyCredentialInvalid: Self = Self::AUTH_MFA_PASSKEY_CREDENTIAL_INVALID
pub const AuthMfaPasskeyCredentialInvalid: Self = Self::AUTH_MFA_PASSKEY_CREDENTIAL_INVALID
Idiomatic alias for Self::AUTH_MFA_PASSKEY_CREDENTIAL_INVALID; Debug prints the variant name.
Sourcepub const AuthMfaPasskeyVerifyFailed: Self = Self::AUTH_MFA_PASSKEY_VERIFY_FAILED
pub const AuthMfaPasskeyVerifyFailed: Self = Self::AUTH_MFA_PASSKEY_VERIFY_FAILED
Idiomatic alias for Self::AUTH_MFA_PASSKEY_VERIFY_FAILED; Debug prints the variant name.
Sourcepub const AuthMfaEnrollmentBindingInvalid: Self = Self::AUTH_MFA_ENROLLMENT_BINDING_INVALID
pub const AuthMfaEnrollmentBindingInvalid: Self = Self::AUTH_MFA_ENROLLMENT_BINDING_INVALID
Idiomatic alias for Self::AUTH_MFA_ENROLLMENT_BINDING_INVALID; Debug prints the variant name.
Sourcepub const AuthStepUpRequired: Self = Self::AUTH_STEP_UP_REQUIRED
pub const AuthStepUpRequired: Self = Self::AUTH_STEP_UP_REQUIRED
Idiomatic alias for Self::AUTH_STEP_UP_REQUIRED; Debug prints the variant name.
Idiomatic alias for Self::AUTH_STEP_UP_PROOF_UNAVAILABLE; Debug prints the variant name.
Sourcepub const AuthStepUpAlreadyClaimed: Self = Self::AUTH_STEP_UP_ALREADY_CLAIMED
pub const AuthStepUpAlreadyClaimed: Self = Self::AUTH_STEP_UP_ALREADY_CLAIMED
Idiomatic alias for Self::AUTH_STEP_UP_ALREADY_CLAIMED; Debug prints the variant name.
Sourcepub const AuthPolicyInUse: Self = Self::AUTH_POLICY_IN_USE
pub const AuthPolicyInUse: Self = Self::AUTH_POLICY_IN_USE
Idiomatic alias for Self::AUTH_POLICY_IN_USE; Debug prints the variant name.
Sourcepub const AuthPolicyLocked: Self = Self::AUTH_POLICY_LOCKED
pub const AuthPolicyLocked: Self = Self::AUTH_POLICY_LOCKED
Idiomatic alias for Self::AUTH_POLICY_LOCKED; Debug prints the variant name.
Sourcepub const AuthPolicyScopeMismatch: Self = Self::AUTH_POLICY_SCOPE_MISMATCH
pub const AuthPolicyScopeMismatch: Self = Self::AUTH_POLICY_SCOPE_MISMATCH
Idiomatic alias for Self::AUTH_POLICY_SCOPE_MISMATCH; Debug prints the variant name.
Sourcepub const AuthRevisionConflict: Self = Self::AUTH_REVISION_CONFLICT
pub const AuthRevisionConflict: Self = Self::AUTH_REVISION_CONFLICT
Idiomatic alias for Self::AUTH_REVISION_CONFLICT; Debug prints the variant name.
Sourcepub const AuthMfaElevationRequired: Self = Self::AUTH_MFA_ELEVATION_REQUIRED
pub const AuthMfaElevationRequired: Self = Self::AUTH_MFA_ELEVATION_REQUIRED
Idiomatic alias for Self::AUTH_MFA_ELEVATION_REQUIRED; Debug prints the variant name.
Sourcepub const AuthMfaLastFactorRequired: Self = Self::AUTH_MFA_LAST_FACTOR_REQUIRED
pub const AuthMfaLastFactorRequired: Self = Self::AUTH_MFA_LAST_FACTOR_REQUIRED
Idiomatic alias for Self::AUTH_MFA_LAST_FACTOR_REQUIRED; Debug prints the variant name.