#[repr(i32)]pub enum ZipperReasonCode {
Show 49 variants
REASON_UNSPECIFIED = 0,
DEPOSIT_WAIT_EXPIRED = 1_001,
DEPOSIT_AMOUNT_INVALID = 1_002,
DEPOSIT_AMOUNT_BELOW_MINIMUM = 1_003,
DEPOSIT_AMOUNT_NOT_ABOVE_FEE = 1_004,
DEPOSIT_NET_AMOUNT_BELOW_MINIMUM = 1_005,
EVM_DEPOSIT_SOURCE_TX_INVALID = 1_101,
EVM_DEPOSIT_SOURCE_TX_ZERO = 1_102,
EVM_DEPOSIT_SOURCE_TX_NOT_FOUND = 1_103,
EVM_DEPOSIT_SOURCE_TX_REVERTED = 1_104,
EVM_DEPOSIT_TRANSFER_MISMATCH = 1_105,
UTXO_DEPOSIT_TRANSACTION_MISMATCH = 1_201,
BTC_DEPOSIT_TRANSACTION_MISMATCH = 1_202,
BCH_DEPOSIT_TRANSACTION_MISMATCH = 1_203,
DOGE_DEPOSIT_TRANSACTION_MISMATCH = 1_204,
LTC_DEPOSIT_TRANSACTION_MISMATCH = 1_205,
UTXO_DEPOSIT_SOURCE_IS_DEPOSIT_ADDRESS = 1_206,
SOLANA_DEPOSIT_SIGNATURE_INVALID = 1_301,
SOLANA_DEPOSIT_TRANSACTION_FAILED = 1_302,
SOLANA_DEPOSIT_TRANSFER_MISMATCH = 1_303,
XRP_DEPOSIT_SOURCE_HASH_INDEX_INVALID = 1_401,
XRP_DEPOSIT_SOURCE_ADDRESS_INVALID = 1_402,
XRP_DEPOSIT_ADDRESS_INVALID = 1_403,
XRP_DEPOSIT_PAYMENT_MISMATCH = 1_404,
REJECTION_UNMAPPED = 1_999,
WITHDRAWAL_AMOUNT_INVALID = 2_001,
WITHDRAWAL_AMOUNT_BELOW_MINIMUM = 2_002,
WITHDRAWAL_ASSET_INVALID = 2_003,
WITHDRAWAL_SENDER_INVALID = 2_004,
WITHDRAWAL_DESTINATION_INVALID = 2_005,
WITHDRAWAL_ASSET_UNAVAILABLE = 2_006,
EVM_WITHDRAWAL_DESTINATION_INVALID = 2_101,
BTC_WITHDRAWAL_DESTINATION_INVALID = 2_201,
BCH_WITHDRAWAL_DESTINATION_INVALID = 2_202,
DOGE_WITHDRAWAL_DESTINATION_INVALID = 2_203,
LTC_WITHDRAWAL_DESTINATION_INVALID = 2_204,
SOLANA_WITHDRAWAL_DESTINATION_INVALID = 2_301,
XRP_WITHDRAWAL_CLASSIC_ADDRESS_INVALID = 2_401,
XRP_WITHDRAWAL_DESTINATION_TAG_INVALID = 2_402,
WITHDRAWAL_LIQUIDITY_INSUFFICIENT = 3_001,
COMPLIANCE_HIGH_RISK_ADDRESS = 3_002,
REQUEST_VERIFICATION_REJECTED = 3_901,
REJECTED = 3_902,
ERROR_UNMAPPED = 9_000,
ERROR_NETWORK_UNSUPPORTED = 9_001,
ERROR_REQUEST_PROCESSING_FAILED = 9_002,
ERROR_REQUEST_VERIFICATION_FAILED = 9_003,
ERROR_RESULT_SUBMISSION_FAILED = 9_004,
ERROR_STATUS_UNKNOWN = 9_005,
}Expand description
ZipperReasonCode identifies a specific Zipper request outcome. Numeric values are stable and may be used for client decisions, analytics, and support.
Variants
REASON_UNSPECIFIED = 0
No specific reason is available.
DEPOSIT_WAIT_EXPIRED = 1_001
Deposit confirmations were not reached before the wait expired.
DEPOSIT_AMOUNT_INVALID = 1_002
Deposit amount is invalid.
DEPOSIT_AMOUNT_BELOW_MINIMUM = 1_003
Deposit amount is below the configured minimum.
DEPOSIT_AMOUNT_NOT_ABOVE_FEE = 1_004
Deposit amount is not greater than the fee.
DEPOSIT_NET_AMOUNT_BELOW_MINIMUM = 1_005
Deposit amount after fees is below the configured minimum.
EVM_DEPOSIT_SOURCE_TX_INVALID = 1_101
EVM deposit source transaction hash is invalid.
EVM_DEPOSIT_SOURCE_TX_ZERO = 1_102
EVM deposit source transaction hash is zero.
EVM_DEPOSIT_SOURCE_TX_NOT_FOUND = 1_103
EVM deposit source transaction was not found.
EVM_DEPOSIT_SOURCE_TX_REVERTED = 1_104
EVM deposit source transaction reverted.
EVM_DEPOSIT_TRANSFER_MISMATCH = 1_105
EVM deposit transfer does not match the request.
UTXO_DEPOSIT_TRANSACTION_MISMATCH = 1_201
UTXO deposit transaction does not match the request.
BTC_DEPOSIT_TRANSACTION_MISMATCH = 1_202
Bitcoin deposit transaction does not match the request.
BCH_DEPOSIT_TRANSACTION_MISMATCH = 1_203
Bitcoin Cash deposit transaction does not match the request.
DOGE_DEPOSIT_TRANSACTION_MISMATCH = 1_204
Dogecoin deposit transaction does not match the request.
LTC_DEPOSIT_TRANSACTION_MISMATCH = 1_205
Litecoin deposit transaction does not match the request.
UTXO_DEPOSIT_SOURCE_IS_DEPOSIT_ADDRESS = 1_206
UTXO deposit source is a registered deposit address.
SOLANA_DEPOSIT_SIGNATURE_INVALID = 1_301
Solana deposit signature is invalid.
SOLANA_DEPOSIT_TRANSACTION_FAILED = 1_302
Solana deposit transaction failed.
SOLANA_DEPOSIT_TRANSFER_MISMATCH = 1_303
Solana deposit transfer does not match the request.
XRP_DEPOSIT_SOURCE_HASH_INDEX_INVALID = 1_401
XRP deposit source hash index is invalid.
XRP_DEPOSIT_SOURCE_ADDRESS_INVALID = 1_402
XRP deposit source address is invalid.
XRP_DEPOSIT_ADDRESS_INVALID = 1_403
XRP deposit address is invalid.
XRP_DEPOSIT_PAYMENT_MISMATCH = 1_404
XRP deposit payment does not match the request.
REJECTION_UNMAPPED = 1_999
The request was rejected without a more specific mapped reason.
WITHDRAWAL_AMOUNT_INVALID = 2_001
Withdrawal amount is invalid.
WITHDRAWAL_AMOUNT_BELOW_MINIMUM = 2_002
Withdrawal amount is below the configured minimum.
WITHDRAWAL_ASSET_INVALID = 2_003
Withdrawal asset address is invalid.
WITHDRAWAL_SENDER_INVALID = 2_004
Withdrawal sender account is invalid.
WITHDRAWAL_DESTINATION_INVALID = 2_005
Withdrawal destination address is invalid.
WITHDRAWAL_ASSET_UNAVAILABLE = 2_006
Withdrawal asset is unavailable on the destination network.
EVM_WITHDRAWAL_DESTINATION_INVALID = 2_101
EVM withdrawal destination address is invalid.
BTC_WITHDRAWAL_DESTINATION_INVALID = 2_201
Bitcoin withdrawal destination address is invalid.
BCH_WITHDRAWAL_DESTINATION_INVALID = 2_202
Bitcoin Cash withdrawal destination address is invalid.
DOGE_WITHDRAWAL_DESTINATION_INVALID = 2_203
Dogecoin withdrawal destination address is invalid.
LTC_WITHDRAWAL_DESTINATION_INVALID = 2_204
Litecoin withdrawal destination address is invalid.
SOLANA_WITHDRAWAL_DESTINATION_INVALID = 2_301
Solana withdrawal destination address is invalid.
XRP_WITHDRAWAL_CLASSIC_ADDRESS_INVALID = 2_401
XRP withdrawal classic address is invalid.
XRP_WITHDRAWAL_DESTINATION_TAG_INVALID = 2_402
XRP withdrawal destination tag is invalid.
WITHDRAWAL_LIQUIDITY_INSUFFICIENT = 3_001
Available liquidity is insufficient for the withdrawal.
COMPLIANCE_HIGH_RISK_ADDRESS = 3_002
Request address was classified as high risk.
REQUEST_VERIFICATION_REJECTED = 3_901
Request verification was rejected without a more specific reason.
REJECTED = 3_902
Request processing completed with a rejected result.
ERROR_UNMAPPED = 9_000
Request processing failed with an unmapped error.
ERROR_NETWORK_UNSUPPORTED = 9_001
Selected network is unsupported.
ERROR_REQUEST_PROCESSING_FAILED = 9_002
Request processing failed.
ERROR_REQUEST_VERIFICATION_FAILED = 9_003
Request verification failed.
ERROR_RESULT_SUBMISSION_FAILED = 9_004
Request result submission failed.
ERROR_STATUS_UNKNOWN = 9_005
Request status could not be determined.
Implementations
Sourceimpl ZipperReasonCode
impl ZipperReasonCode
Sourcepub const ReasonUnspecified: Self = Self::REASON_UNSPECIFIED
pub const ReasonUnspecified: Self = Self::REASON_UNSPECIFIED
Idiomatic alias for Self::REASON_UNSPECIFIED; Debug prints the variant name.
Sourcepub const DepositWaitExpired: Self = Self::DEPOSIT_WAIT_EXPIRED
pub const DepositWaitExpired: Self = Self::DEPOSIT_WAIT_EXPIRED
Idiomatic alias for Self::DEPOSIT_WAIT_EXPIRED; Debug prints the variant name.
Sourcepub const DepositAmountInvalid: Self = Self::DEPOSIT_AMOUNT_INVALID
pub const DepositAmountInvalid: Self = Self::DEPOSIT_AMOUNT_INVALID
Idiomatic alias for Self::DEPOSIT_AMOUNT_INVALID; Debug prints the variant name.
Sourcepub const DepositAmountBelowMinimum: Self = Self::DEPOSIT_AMOUNT_BELOW_MINIMUM
pub const DepositAmountBelowMinimum: Self = Self::DEPOSIT_AMOUNT_BELOW_MINIMUM
Idiomatic alias for Self::DEPOSIT_AMOUNT_BELOW_MINIMUM; Debug prints the variant name.
Sourcepub const DepositAmountNotAboveFee: Self = Self::DEPOSIT_AMOUNT_NOT_ABOVE_FEE
pub const DepositAmountNotAboveFee: Self = Self::DEPOSIT_AMOUNT_NOT_ABOVE_FEE
Idiomatic alias for Self::DEPOSIT_AMOUNT_NOT_ABOVE_FEE; Debug prints the variant name.
Sourcepub const DepositNetAmountBelowMinimum: Self = Self::DEPOSIT_NET_AMOUNT_BELOW_MINIMUM
pub const DepositNetAmountBelowMinimum: Self = Self::DEPOSIT_NET_AMOUNT_BELOW_MINIMUM
Idiomatic alias for Self::DEPOSIT_NET_AMOUNT_BELOW_MINIMUM; Debug prints the variant name.
Sourcepub const EvmDepositSourceTxInvalid: Self = Self::EVM_DEPOSIT_SOURCE_TX_INVALID
pub const EvmDepositSourceTxInvalid: Self = Self::EVM_DEPOSIT_SOURCE_TX_INVALID
Idiomatic alias for Self::EVM_DEPOSIT_SOURCE_TX_INVALID; Debug prints the variant name.
Sourcepub const EvmDepositSourceTxZero: Self = Self::EVM_DEPOSIT_SOURCE_TX_ZERO
pub const EvmDepositSourceTxZero: Self = Self::EVM_DEPOSIT_SOURCE_TX_ZERO
Idiomatic alias for Self::EVM_DEPOSIT_SOURCE_TX_ZERO; Debug prints the variant name.
Sourcepub const EvmDepositSourceTxNotFound: Self = Self::EVM_DEPOSIT_SOURCE_TX_NOT_FOUND
pub const EvmDepositSourceTxNotFound: Self = Self::EVM_DEPOSIT_SOURCE_TX_NOT_FOUND
Idiomatic alias for Self::EVM_DEPOSIT_SOURCE_TX_NOT_FOUND; Debug prints the variant name.
Sourcepub const EvmDepositSourceTxReverted: Self = Self::EVM_DEPOSIT_SOURCE_TX_REVERTED
pub const EvmDepositSourceTxReverted: Self = Self::EVM_DEPOSIT_SOURCE_TX_REVERTED
Idiomatic alias for Self::EVM_DEPOSIT_SOURCE_TX_REVERTED; Debug prints the variant name.
Sourcepub const EvmDepositTransferMismatch: Self = Self::EVM_DEPOSIT_TRANSFER_MISMATCH
pub const EvmDepositTransferMismatch: Self = Self::EVM_DEPOSIT_TRANSFER_MISMATCH
Idiomatic alias for Self::EVM_DEPOSIT_TRANSFER_MISMATCH; Debug prints the variant name.
Sourcepub const UtxoDepositTransactionMismatch: Self = Self::UTXO_DEPOSIT_TRANSACTION_MISMATCH
pub const UtxoDepositTransactionMismatch: Self = Self::UTXO_DEPOSIT_TRANSACTION_MISMATCH
Idiomatic alias for Self::UTXO_DEPOSIT_TRANSACTION_MISMATCH; Debug prints the variant name.
Sourcepub const BtcDepositTransactionMismatch: Self = Self::BTC_DEPOSIT_TRANSACTION_MISMATCH
pub const BtcDepositTransactionMismatch: Self = Self::BTC_DEPOSIT_TRANSACTION_MISMATCH
Idiomatic alias for Self::BTC_DEPOSIT_TRANSACTION_MISMATCH; Debug prints the variant name.
Sourcepub const BchDepositTransactionMismatch: Self = Self::BCH_DEPOSIT_TRANSACTION_MISMATCH
pub const BchDepositTransactionMismatch: Self = Self::BCH_DEPOSIT_TRANSACTION_MISMATCH
Idiomatic alias for Self::BCH_DEPOSIT_TRANSACTION_MISMATCH; Debug prints the variant name.
Sourcepub const DogeDepositTransactionMismatch: Self = Self::DOGE_DEPOSIT_TRANSACTION_MISMATCH
pub const DogeDepositTransactionMismatch: Self = Self::DOGE_DEPOSIT_TRANSACTION_MISMATCH
Idiomatic alias for Self::DOGE_DEPOSIT_TRANSACTION_MISMATCH; Debug prints the variant name.
Sourcepub const LtcDepositTransactionMismatch: Self = Self::LTC_DEPOSIT_TRANSACTION_MISMATCH
pub const LtcDepositTransactionMismatch: Self = Self::LTC_DEPOSIT_TRANSACTION_MISMATCH
Idiomatic alias for Self::LTC_DEPOSIT_TRANSACTION_MISMATCH; Debug prints the variant name.
Sourcepub const UtxoDepositSourceIsDepositAddress: Self = Self::UTXO_DEPOSIT_SOURCE_IS_DEPOSIT_ADDRESS
pub const UtxoDepositSourceIsDepositAddress: Self = Self::UTXO_DEPOSIT_SOURCE_IS_DEPOSIT_ADDRESS
Idiomatic alias for Self::UTXO_DEPOSIT_SOURCE_IS_DEPOSIT_ADDRESS; Debug prints the variant name.
Sourcepub const SolanaDepositSignatureInvalid: Self = Self::SOLANA_DEPOSIT_SIGNATURE_INVALID
pub const SolanaDepositSignatureInvalid: Self = Self::SOLANA_DEPOSIT_SIGNATURE_INVALID
Idiomatic alias for Self::SOLANA_DEPOSIT_SIGNATURE_INVALID; Debug prints the variant name.
Sourcepub const SolanaDepositTransactionFailed: Self = Self::SOLANA_DEPOSIT_TRANSACTION_FAILED
pub const SolanaDepositTransactionFailed: Self = Self::SOLANA_DEPOSIT_TRANSACTION_FAILED
Idiomatic alias for Self::SOLANA_DEPOSIT_TRANSACTION_FAILED; Debug prints the variant name.
Sourcepub const SolanaDepositTransferMismatch: Self = Self::SOLANA_DEPOSIT_TRANSFER_MISMATCH
pub const SolanaDepositTransferMismatch: Self = Self::SOLANA_DEPOSIT_TRANSFER_MISMATCH
Idiomatic alias for Self::SOLANA_DEPOSIT_TRANSFER_MISMATCH; Debug prints the variant name.
Sourcepub const XrpDepositSourceHashIndexInvalid: Self = Self::XRP_DEPOSIT_SOURCE_HASH_INDEX_INVALID
pub const XrpDepositSourceHashIndexInvalid: Self = Self::XRP_DEPOSIT_SOURCE_HASH_INDEX_INVALID
Idiomatic alias for Self::XRP_DEPOSIT_SOURCE_HASH_INDEX_INVALID; Debug prints the variant name.
Sourcepub const XrpDepositSourceAddressInvalid: Self = Self::XRP_DEPOSIT_SOURCE_ADDRESS_INVALID
pub const XrpDepositSourceAddressInvalid: Self = Self::XRP_DEPOSIT_SOURCE_ADDRESS_INVALID
Idiomatic alias for Self::XRP_DEPOSIT_SOURCE_ADDRESS_INVALID; Debug prints the variant name.
Sourcepub const XrpDepositAddressInvalid: Self = Self::XRP_DEPOSIT_ADDRESS_INVALID
pub const XrpDepositAddressInvalid: Self = Self::XRP_DEPOSIT_ADDRESS_INVALID
Idiomatic alias for Self::XRP_DEPOSIT_ADDRESS_INVALID; Debug prints the variant name.
Sourcepub const XrpDepositPaymentMismatch: Self = Self::XRP_DEPOSIT_PAYMENT_MISMATCH
pub const XrpDepositPaymentMismatch: Self = Self::XRP_DEPOSIT_PAYMENT_MISMATCH
Idiomatic alias for Self::XRP_DEPOSIT_PAYMENT_MISMATCH; Debug prints the variant name.
Sourcepub const RejectionUnmapped: Self = Self::REJECTION_UNMAPPED
pub const RejectionUnmapped: Self = Self::REJECTION_UNMAPPED
Idiomatic alias for Self::REJECTION_UNMAPPED; Debug prints the variant name.
Sourcepub const WithdrawalAmountInvalid: Self = Self::WITHDRAWAL_AMOUNT_INVALID
pub const WithdrawalAmountInvalid: Self = Self::WITHDRAWAL_AMOUNT_INVALID
Idiomatic alias for Self::WITHDRAWAL_AMOUNT_INVALID; Debug prints the variant name.
Sourcepub const WithdrawalAmountBelowMinimum: Self = Self::WITHDRAWAL_AMOUNT_BELOW_MINIMUM
pub const WithdrawalAmountBelowMinimum: Self = Self::WITHDRAWAL_AMOUNT_BELOW_MINIMUM
Idiomatic alias for Self::WITHDRAWAL_AMOUNT_BELOW_MINIMUM; Debug prints the variant name.
Sourcepub const WithdrawalAssetInvalid: Self = Self::WITHDRAWAL_ASSET_INVALID
pub const WithdrawalAssetInvalid: Self = Self::WITHDRAWAL_ASSET_INVALID
Idiomatic alias for Self::WITHDRAWAL_ASSET_INVALID; Debug prints the variant name.
Sourcepub const WithdrawalSenderInvalid: Self = Self::WITHDRAWAL_SENDER_INVALID
pub const WithdrawalSenderInvalid: Self = Self::WITHDRAWAL_SENDER_INVALID
Idiomatic alias for Self::WITHDRAWAL_SENDER_INVALID; Debug prints the variant name.
Sourcepub const WithdrawalDestinationInvalid: Self = Self::WITHDRAWAL_DESTINATION_INVALID
pub const WithdrawalDestinationInvalid: Self = Self::WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Idiomatic alias for Self::WITHDRAWAL_ASSET_UNAVAILABLE; Debug prints the variant name.
Sourcepub const EvmWithdrawalDestinationInvalid: Self = Self::EVM_WITHDRAWAL_DESTINATION_INVALID
pub const EvmWithdrawalDestinationInvalid: Self = Self::EVM_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::EVM_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const BtcWithdrawalDestinationInvalid: Self = Self::BTC_WITHDRAWAL_DESTINATION_INVALID
pub const BtcWithdrawalDestinationInvalid: Self = Self::BTC_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::BTC_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const BchWithdrawalDestinationInvalid: Self = Self::BCH_WITHDRAWAL_DESTINATION_INVALID
pub const BchWithdrawalDestinationInvalid: Self = Self::BCH_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::BCH_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const DogeWithdrawalDestinationInvalid: Self = Self::DOGE_WITHDRAWAL_DESTINATION_INVALID
pub const DogeWithdrawalDestinationInvalid: Self = Self::DOGE_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::DOGE_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const LtcWithdrawalDestinationInvalid: Self = Self::LTC_WITHDRAWAL_DESTINATION_INVALID
pub const LtcWithdrawalDestinationInvalid: Self = Self::LTC_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::LTC_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const SolanaWithdrawalDestinationInvalid: Self = Self::SOLANA_WITHDRAWAL_DESTINATION_INVALID
pub const SolanaWithdrawalDestinationInvalid: Self = Self::SOLANA_WITHDRAWAL_DESTINATION_INVALID
Idiomatic alias for Self::SOLANA_WITHDRAWAL_DESTINATION_INVALID; Debug prints the variant name.
Sourcepub const XrpWithdrawalClassicAddressInvalid: Self = Self::XRP_WITHDRAWAL_CLASSIC_ADDRESS_INVALID
pub const XrpWithdrawalClassicAddressInvalid: Self = Self::XRP_WITHDRAWAL_CLASSIC_ADDRESS_INVALID
Idiomatic alias for Self::XRP_WITHDRAWAL_CLASSIC_ADDRESS_INVALID; Debug prints the variant name.
Sourcepub const XrpWithdrawalDestinationTagInvalid: Self = Self::XRP_WITHDRAWAL_DESTINATION_TAG_INVALID
pub const XrpWithdrawalDestinationTagInvalid: Self = Self::XRP_WITHDRAWAL_DESTINATION_TAG_INVALID
Idiomatic alias for Self::XRP_WITHDRAWAL_DESTINATION_TAG_INVALID; Debug prints the variant name.
Sourcepub const WithdrawalLiquidityInsufficient: Self = Self::WITHDRAWAL_LIQUIDITY_INSUFFICIENT
pub const WithdrawalLiquidityInsufficient: Self = Self::WITHDRAWAL_LIQUIDITY_INSUFFICIENT
Idiomatic alias for Self::WITHDRAWAL_LIQUIDITY_INSUFFICIENT; Debug prints the variant name.
Sourcepub const ComplianceHighRiskAddress: Self = Self::COMPLIANCE_HIGH_RISK_ADDRESS
pub const ComplianceHighRiskAddress: Self = Self::COMPLIANCE_HIGH_RISK_ADDRESS
Idiomatic alias for Self::COMPLIANCE_HIGH_RISK_ADDRESS; Debug prints the variant name.
Sourcepub const RequestVerificationRejected: Self = Self::REQUEST_VERIFICATION_REJECTED
pub const RequestVerificationRejected: Self = Self::REQUEST_VERIFICATION_REJECTED
Idiomatic alias for Self::REQUEST_VERIFICATION_REJECTED; Debug prints the variant name.
Sourcepub const Rejected: Self = Self::REJECTED
pub const Rejected: Self = Self::REJECTED
Idiomatic alias for Self::REJECTED; Debug prints the variant name.
Sourcepub const ErrorUnmapped: Self = Self::ERROR_UNMAPPED
pub const ErrorUnmapped: Self = Self::ERROR_UNMAPPED
Idiomatic alias for Self::ERROR_UNMAPPED; Debug prints the variant name.
Sourcepub const ErrorNetworkUnsupported: Self = Self::ERROR_NETWORK_UNSUPPORTED
pub const ErrorNetworkUnsupported: Self = Self::ERROR_NETWORK_UNSUPPORTED
Idiomatic alias for Self::ERROR_NETWORK_UNSUPPORTED; Debug prints the variant name.
Sourcepub const ErrorRequestProcessingFailed: Self = Self::ERROR_REQUEST_PROCESSING_FAILED
pub const ErrorRequestProcessingFailed: Self = Self::ERROR_REQUEST_PROCESSING_FAILED
Idiomatic alias for Self::ERROR_REQUEST_PROCESSING_FAILED; Debug prints the variant name.
Sourcepub const ErrorRequestVerificationFailed: Self = Self::ERROR_REQUEST_VERIFICATION_FAILED
pub const ErrorRequestVerificationFailed: Self = Self::ERROR_REQUEST_VERIFICATION_FAILED
Idiomatic alias for Self::ERROR_REQUEST_VERIFICATION_FAILED; Debug prints the variant name.
Sourcepub const ErrorResultSubmissionFailed: Self = Self::ERROR_RESULT_SUBMISSION_FAILED
pub const ErrorResultSubmissionFailed: Self = Self::ERROR_RESULT_SUBMISSION_FAILED
Idiomatic alias for Self::ERROR_RESULT_SUBMISSION_FAILED; Debug prints the variant name.
Sourcepub const ErrorStatusUnknown: Self = Self::ERROR_STATUS_UNKNOWN
pub const ErrorStatusUnknown: Self = Self::ERROR_STATUS_UNKNOWN
Idiomatic alias for Self::ERROR_STATUS_UNKNOWN; Debug prints the variant name.