#[repr(i32)]pub enum ErrorCode {
Show 65 variants
ERROR_CODE_UNSPECIFIED = 0,
ERROR_CODE_BAD_REQUEST = 1,
ERROR_CODE_INVALID_ARGUMENT = 2,
ERROR_CODE_INSUFFICIENT_FUNDS = 3,
ERROR_CODE_UNKNOWN_SYMBOL = 4,
ERROR_CODE_BAD_PRICE = 5,
ERROR_CODE_BAD_QTY = 6,
ERROR_CODE_MIN_NOTIONAL = 7,
ERROR_CODE_QTY_STEP_SIZE = 8,
ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_ORDER_ID = 9,
ERROR_CODE_UNAVAILABLE = 10,
ERROR_CODE_UNAUTHENTICATED = 11,
ERROR_CODE_PERMISSION_DENIED = 12,
ERROR_CODE_NOT_FOUND = 13,
ERROR_CODE_UPSTREAM_ERROR = 14,
ERROR_CODE_FEE_ASSET_NOT_ALLOWED = 15,
ERROR_CODE_PAIR_DISABLED = 16,
ERROR_CODE_ORDER_UNKNOWN = 17,
ERROR_CODE_INTERNAL_ERROR = 18,
ERROR_CODE_SUBACCOUNT_INACTIVE = 19,
ERROR_CODE_POLICY_MARKET_DENY = 20,
ERROR_CODE_POLICY_MAX_NOTIONAL = 21,
ERROR_CODE_POLICY_TRADING_HALTED = 22,
ERROR_CODE_POLICY_SPOT_TRADE_DENY = 23,
ERROR_CODE_API_KEY_ROOT_SCOPE_ONLY = 24,
ERROR_CODE_API_KEY_SUB_SCOPE_ONLY = 25,
ERROR_CODE_API_KEY_SUBACCOUNT_MISMATCH = 26,
ERROR_CODE_API_KEY_POLICY_REQUIRED = 27,
ERROR_CODE_API_KEY_UNKNOWN = 28,
ERROR_CODE_API_KEY_MARKET_DENY = 29,
ERROR_CODE_PRICE_TICK_SIZE = 30,
ERROR_CODE_MIN_QTY = 31,
ERROR_CODE_POST_ONLY_LIMIT_ONLY = 32,
ERROR_CODE_BATCH_TOO_LARGE = 33,
ERROR_CODE_MODIFICATION_REQUIRES_REPLACE = 35,
ERROR_CODE_CONFLICT_IDEMPOTENCY_KEY_REUSE = 36,
ERROR_CODE_MARKET_PRICE_UNAVAILABLE = 37,
ERROR_CODE_PAIR_NOT_LISTED_YET = 50,
ERROR_CODE_PAIR_DELISTED = 51,
ERROR_CODE_PAIR_CANCEL_ONLY = 52,
ERROR_CODE_PAIR_POST_ONLY = 53,
ERROR_CODE_PAIR_REDUCE_ONLY = 54,
ERROR_CODE_RISK_LIMIT = 55,
ERROR_CODE_MARKET_HALTED = 56,
ERROR_CODE_ACCOUNT_UNKNOWN = 57,
ERROR_CODE_POST_ONLY_CROSS = 58,
ERROR_CODE_REDUCE_ONLY_BLOCKED = 59,
ERROR_CODE_PRICE_BAND_VIOLATION = 60,
ERROR_CODE_MARKET_CAP_VIOLATION = 61,
ERROR_CODE_EMPTY_BOOK = 62,
ERROR_CODE_FOK_INSUFFICIENT_LIQUIDITY = 63,
ERROR_CODE_ORDER_ALREADY_TERMINAL = 64,
ERROR_CODE_TRIGGER_PRICE_INVALID = 40,
ERROR_CODE_TRIGGER_PRICE_SOURCE_UNSUPPORTED = 41,
ERROR_CODE_TRAILING_DISTANCE_INVALID = 42,
ERROR_CODE_TRIGGER_NOT_FOUND = 43,
ERROR_CODE_TRIGGER_CANCEL_REJECTED = 44,
ERROR_CODE_TRIGGER_STATUS_INVALID = 45,
ERROR_CODE_TRIGGER_NOT_MODIFIABLE = 46,
ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_TRIGGER_ID = 47,
ERROR_CODE_MAX_SLIPPAGE_INVALID = 48,
ERROR_CODE_STALE_QUOTE = 65,
ERROR_CODE_VALIDATION_ERROR = 66,
ERROR_CODE_OVERLOADED = 67,
ERROR_CODE_MAX_QUOTE_DEBIT_TOO_SMALL = 68,
}Expand description
ErrorCode enumerates stable machine-readable error codes for the Orders API. These mirror the REST problem+json “code” field for parity between REST and ConnectRPC clients.
Variants
ERROR_CODE_UNSPECIFIED = 0
Error code was not provided.
ERROR_CODE_BAD_REQUEST = 1
Request could not be parsed or was structurally invalid.
ERROR_CODE_INVALID_ARGUMENT = 2
Request fields failed validation.
ERROR_CODE_INSUFFICIENT_FUNDS = 3
Account does not have enough available balance for the order.
ERROR_CODE_UNKNOWN_SYMBOL = 4
Requested trading symbol is unknown.
ERROR_CODE_BAD_PRICE = 5
Price is invalid for the requested order.
ERROR_CODE_BAD_QTY = 6
Quantity is invalid for the requested order.
ERROR_CODE_MIN_NOTIONAL = 7
Order notional is below the pair minimum.
ERROR_CODE_QTY_STEP_SIZE = 8
Quantity does not align with the pair step size.
ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_ORDER_ID = 9
Client order ID is already in use for a different active order.
ERROR_CODE_UNAVAILABLE = 10
Service is temporarily unavailable.
ERROR_CODE_UNAUTHENTICATED = 11
Caller is not authenticated.
ERROR_CODE_PERMISSION_DENIED = 12
Caller is authenticated but not allowed to perform this action.
ERROR_CODE_NOT_FOUND = 13
Requested order or resource was not found.
ERROR_CODE_UPSTREAM_ERROR = 14
Upstream dependency returned an error.
ERROR_CODE_FEE_ASSET_NOT_ALLOWED = 15
Requested fee asset is not allowed for this order.
ERROR_CODE_PAIR_DISABLED = 16
Additional domain-specific codes used by the Orders API.
ERROR_CODE_ORDER_UNKNOWN = 17
ERROR_CODE_INTERNAL_ERROR = 18
ERROR_CODE_SUBACCOUNT_INACTIVE = 19
Sub-account is present but not in an active state (disabled, deleted, etc.).
ERROR_CODE_POLICY_MARKET_DENY = 20
Sub-account policy prevented trading on this market (e.g. pair mask).
ERROR_CODE_POLICY_MAX_NOTIONAL = 21
Sub-account policy max order notional exceeded.
ERROR_CODE_POLICY_TRADING_HALTED = 22
Trading has been globally halted for this sub-account.
ERROR_CODE_POLICY_SPOT_TRADE_DENY = 23
Sub-account policy does not allow spot trading (action mask).
ERROR_CODE_API_KEY_ROOT_SCOPE_ONLY = 24
API key is scoped to the master/root account and cannot trade on sub-accounts.
ERROR_CODE_API_KEY_SUB_SCOPE_ONLY = 25
API key is scoped to a specific sub-account and cannot trade on the master/root account.
ERROR_CODE_API_KEY_SUBACCOUNT_MISMATCH = 26
API key is scoped to a different sub-account than the one requested.
ERROR_CODE_API_KEY_POLICY_REQUIRED = 27
API key must have an attached policy before it can be used for trading.
ERROR_CODE_API_KEY_UNKNOWN = 28
API key referenced in the request could not be resolved by the Orders service.
ERROR_CODE_API_KEY_MARKET_DENY = 29
API key policy does not allow trading this market, even though the sub-account policy does.
ERROR_CODE_PRICE_TICK_SIZE = 30
Price must align with the pair tick size (LIMIT orders).
ERROR_CODE_MIN_QTY = 31
Quantity is below the pair minimum quantity (base units).
ERROR_CODE_POST_ONLY_LIMIT_ONLY = 32
Post-only is only valid for LIMIT orders.
ERROR_CODE_BATCH_TOO_LARGE = 33
Batch size exceeds the maximum allowed.
ERROR_CODE_MODIFICATION_REQUIRES_REPLACE = 35
Modify request in AMEND_ONLY mode requires replace semantics.
ERROR_CODE_CONFLICT_IDEMPOTENCY_KEY_REUSE = 36
Idempotency key was reused with a different payload.
ERROR_CODE_MARKET_PRICE_UNAVAILABLE = 37
MARKET BUY cannot be reserved because no reference/top-of-book price is available.
ERROR_CODE_PAIR_NOT_LISTED_YET = 50
Pair exists but is not listed yet.
ERROR_CODE_PAIR_DELISTED = 51
Pair was delisted and is no longer tradable.
ERROR_CODE_PAIR_CANCEL_ONLY = 52
Pair is in cancel-only mode.
ERROR_CODE_PAIR_POST_ONLY = 53
Pair is in post-only mode and requires post_only=true.
ERROR_CODE_PAIR_REDUCE_ONLY = 54
Pair is in reduce-only mode and does not accept new spot orders.
ERROR_CODE_RISK_LIMIT = 55
Account-level risk limits were exceeded.
ERROR_CODE_MARKET_HALTED = 56
Market is halted.
ERROR_CODE_ACCOUNT_UNKNOWN = 57
Referenced account could not be resolved by the trading service.
ERROR_CODE_POST_ONLY_CROSS = 58
Post-only order would cross the book.
ERROR_CODE_REDUCE_ONLY_BLOCKED = 59
Reduce-only policy blocked the order.
ERROR_CODE_PRICE_BAND_VIOLATION = 60
Price band guard rejected the order.
ERROR_CODE_MARKET_CAP_VIOLATION = 61
Market-cap guard rejected the order.
ERROR_CODE_EMPTY_BOOK = 62
Market order could not execute due to empty book.
ERROR_CODE_FOK_INSUFFICIENT_LIQUIDITY = 63
FOK order rejected due to insufficient immediate liquidity.
ERROR_CODE_ORDER_ALREADY_TERMINAL = 64
Client order ID points to an order that already reached terminal state.
ERROR_CODE_TRIGGER_PRICE_INVALID = 40
Trigger-specific error codes (40-49 range). Trigger price is invalid (e.g., TP below current price for long).
ERROR_CODE_TRIGGER_PRICE_SOURCE_UNSUPPORTED = 41
Trigger price source not supported (e.g., INDEX_PRICE before it’s available).
ERROR_CODE_TRAILING_DISTANCE_INVALID = 42
Trailing stop distance must be positive.
ERROR_CODE_TRIGGER_NOT_FOUND = 43
Trigger not found (for cancel/get operations).
ERROR_CODE_TRIGGER_CANCEL_REJECTED = 44
Trigger cannot be canceled in current state.
ERROR_CODE_TRIGGER_STATUS_INVALID = 45
Trigger status does not allow requested lifecycle operation.
ERROR_CODE_TRIGGER_NOT_MODIFIABLE = 46
Trigger type/state does not support requested lifecycle operation.
ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_TRIGGER_ID = 47
Duplicate client trigger ID was reused with a different trigger payload.
ERROR_CODE_MAX_SLIPPAGE_INVALID = 48
Trailing-stop max slippage (ticks or bps) is invalid.
ERROR_CODE_STALE_QUOTE = 65
Client reference price is stale compared to server-side BBO/drift policy.
ERROR_CODE_VALIDATION_ERROR = 66
Request failed structural or cross-field validation.
ERROR_CODE_OVERLOADED = 67
This edge is at its bounded concurrent BatchReplace admission capacity.
ERROR_CODE_MAX_QUOTE_DEBIT_TOO_SMALL = 68
The all-in quote budget cannot resolve one valid step-aligned base quantity.
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub const Unspecified: Self = Self::ERROR_CODE_UNSPECIFIED
pub const Unspecified: Self = Self::ERROR_CODE_UNSPECIFIED
Idiomatic alias for Self::ERROR_CODE_UNSPECIFIED; Debug prints the variant name.
Sourcepub const BadRequest: Self = Self::ERROR_CODE_BAD_REQUEST
pub const BadRequest: Self = Self::ERROR_CODE_BAD_REQUEST
Idiomatic alias for Self::ERROR_CODE_BAD_REQUEST; Debug prints the variant name.
Sourcepub const InvalidArgument: Self = Self::ERROR_CODE_INVALID_ARGUMENT
pub const InvalidArgument: Self = Self::ERROR_CODE_INVALID_ARGUMENT
Idiomatic alias for Self::ERROR_CODE_INVALID_ARGUMENT; Debug prints the variant name.
Sourcepub const InsufficientFunds: Self = Self::ERROR_CODE_INSUFFICIENT_FUNDS
pub const InsufficientFunds: Self = Self::ERROR_CODE_INSUFFICIENT_FUNDS
Idiomatic alias for Self::ERROR_CODE_INSUFFICIENT_FUNDS; Debug prints the variant name.
Sourcepub const UnknownSymbol: Self = Self::ERROR_CODE_UNKNOWN_SYMBOL
pub const UnknownSymbol: Self = Self::ERROR_CODE_UNKNOWN_SYMBOL
Idiomatic alias for Self::ERROR_CODE_UNKNOWN_SYMBOL; Debug prints the variant name.
Sourcepub const BadPrice: Self = Self::ERROR_CODE_BAD_PRICE
pub const BadPrice: Self = Self::ERROR_CODE_BAD_PRICE
Idiomatic alias for Self::ERROR_CODE_BAD_PRICE; Debug prints the variant name.
Sourcepub const BadQty: Self = Self::ERROR_CODE_BAD_QTY
pub const BadQty: Self = Self::ERROR_CODE_BAD_QTY
Idiomatic alias for Self::ERROR_CODE_BAD_QTY; Debug prints the variant name.
Sourcepub const MinNotional: Self = Self::ERROR_CODE_MIN_NOTIONAL
pub const MinNotional: Self = Self::ERROR_CODE_MIN_NOTIONAL
Idiomatic alias for Self::ERROR_CODE_MIN_NOTIONAL; Debug prints the variant name.
Sourcepub const QtyStepSize: Self = Self::ERROR_CODE_QTY_STEP_SIZE
pub const QtyStepSize: Self = Self::ERROR_CODE_QTY_STEP_SIZE
Idiomatic alias for Self::ERROR_CODE_QTY_STEP_SIZE; Debug prints the variant name.
Sourcepub const ConflictDuplicateClientOrderId: Self = Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_ORDER_ID
pub const ConflictDuplicateClientOrderId: Self = Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_ORDER_ID
Idiomatic alias for Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_ORDER_ID; Debug prints the variant name.
Idiomatic alias for Self::ERROR_CODE_UNAVAILABLE; Debug prints the variant name.
Sourcepub const Unauthenticated: Self = Self::ERROR_CODE_UNAUTHENTICATED
pub const Unauthenticated: Self = Self::ERROR_CODE_UNAUTHENTICATED
Idiomatic alias for Self::ERROR_CODE_UNAUTHENTICATED; Debug prints the variant name.
Sourcepub const PermissionDenied: Self = Self::ERROR_CODE_PERMISSION_DENIED
pub const PermissionDenied: Self = Self::ERROR_CODE_PERMISSION_DENIED
Idiomatic alias for Self::ERROR_CODE_PERMISSION_DENIED; Debug prints the variant name.
Sourcepub const NotFound: Self = Self::ERROR_CODE_NOT_FOUND
pub const NotFound: Self = Self::ERROR_CODE_NOT_FOUND
Idiomatic alias for Self::ERROR_CODE_NOT_FOUND; Debug prints the variant name.
Sourcepub const UpstreamError: Self = Self::ERROR_CODE_UPSTREAM_ERROR
pub const UpstreamError: Self = Self::ERROR_CODE_UPSTREAM_ERROR
Idiomatic alias for Self::ERROR_CODE_UPSTREAM_ERROR; Debug prints the variant name.
Sourcepub const FeeAssetNotAllowed: Self = Self::ERROR_CODE_FEE_ASSET_NOT_ALLOWED
pub const FeeAssetNotAllowed: Self = Self::ERROR_CODE_FEE_ASSET_NOT_ALLOWED
Idiomatic alias for Self::ERROR_CODE_FEE_ASSET_NOT_ALLOWED; Debug prints the variant name.
Sourcepub const PairDisabled: Self = Self::ERROR_CODE_PAIR_DISABLED
pub const PairDisabled: Self = Self::ERROR_CODE_PAIR_DISABLED
Idiomatic alias for Self::ERROR_CODE_PAIR_DISABLED; Debug prints the variant name.
Sourcepub const OrderUnknown: Self = Self::ERROR_CODE_ORDER_UNKNOWN
pub const OrderUnknown: Self = Self::ERROR_CODE_ORDER_UNKNOWN
Idiomatic alias for Self::ERROR_CODE_ORDER_UNKNOWN; Debug prints the variant name.
Sourcepub const InternalError: Self = Self::ERROR_CODE_INTERNAL_ERROR
pub const InternalError: Self = Self::ERROR_CODE_INTERNAL_ERROR
Idiomatic alias for Self::ERROR_CODE_INTERNAL_ERROR; Debug prints the variant name.
Sourcepub const SubaccountInactive: Self = Self::ERROR_CODE_SUBACCOUNT_INACTIVE
pub const SubaccountInactive: Self = Self::ERROR_CODE_SUBACCOUNT_INACTIVE
Idiomatic alias for Self::ERROR_CODE_SUBACCOUNT_INACTIVE; Debug prints the variant name.
Sourcepub const PolicyMarketDeny: Self = Self::ERROR_CODE_POLICY_MARKET_DENY
pub const PolicyMarketDeny: Self = Self::ERROR_CODE_POLICY_MARKET_DENY
Idiomatic alias for Self::ERROR_CODE_POLICY_MARKET_DENY; Debug prints the variant name.
Sourcepub const PolicyMaxNotional: Self = Self::ERROR_CODE_POLICY_MAX_NOTIONAL
pub const PolicyMaxNotional: Self = Self::ERROR_CODE_POLICY_MAX_NOTIONAL
Idiomatic alias for Self::ERROR_CODE_POLICY_MAX_NOTIONAL; Debug prints the variant name.
Sourcepub const PolicyTradingHalted: Self = Self::ERROR_CODE_POLICY_TRADING_HALTED
pub const PolicyTradingHalted: Self = Self::ERROR_CODE_POLICY_TRADING_HALTED
Idiomatic alias for Self::ERROR_CODE_POLICY_TRADING_HALTED; Debug prints the variant name.
Sourcepub const PolicySpotTradeDeny: Self = Self::ERROR_CODE_POLICY_SPOT_TRADE_DENY
pub const PolicySpotTradeDeny: Self = Self::ERROR_CODE_POLICY_SPOT_TRADE_DENY
Idiomatic alias for Self::ERROR_CODE_POLICY_SPOT_TRADE_DENY; Debug prints the variant name.
Sourcepub const ApiKeyRootScopeOnly: Self = Self::ERROR_CODE_API_KEY_ROOT_SCOPE_ONLY
pub const ApiKeyRootScopeOnly: Self = Self::ERROR_CODE_API_KEY_ROOT_SCOPE_ONLY
Idiomatic alias for Self::ERROR_CODE_API_KEY_ROOT_SCOPE_ONLY; Debug prints the variant name.
Sourcepub const ApiKeySubScopeOnly: Self = Self::ERROR_CODE_API_KEY_SUB_SCOPE_ONLY
pub const ApiKeySubScopeOnly: Self = Self::ERROR_CODE_API_KEY_SUB_SCOPE_ONLY
Idiomatic alias for Self::ERROR_CODE_API_KEY_SUB_SCOPE_ONLY; Debug prints the variant name.
Sourcepub const ApiKeySubaccountMismatch: Self = Self::ERROR_CODE_API_KEY_SUBACCOUNT_MISMATCH
pub const ApiKeySubaccountMismatch: Self = Self::ERROR_CODE_API_KEY_SUBACCOUNT_MISMATCH
Idiomatic alias for Self::ERROR_CODE_API_KEY_SUBACCOUNT_MISMATCH; Debug prints the variant name.
Sourcepub const ApiKeyPolicyRequired: Self = Self::ERROR_CODE_API_KEY_POLICY_REQUIRED
pub const ApiKeyPolicyRequired: Self = Self::ERROR_CODE_API_KEY_POLICY_REQUIRED
Idiomatic alias for Self::ERROR_CODE_API_KEY_POLICY_REQUIRED; Debug prints the variant name.
Sourcepub const ApiKeyUnknown: Self = Self::ERROR_CODE_API_KEY_UNKNOWN
pub const ApiKeyUnknown: Self = Self::ERROR_CODE_API_KEY_UNKNOWN
Idiomatic alias for Self::ERROR_CODE_API_KEY_UNKNOWN; Debug prints the variant name.
Sourcepub const ApiKeyMarketDeny: Self = Self::ERROR_CODE_API_KEY_MARKET_DENY
pub const ApiKeyMarketDeny: Self = Self::ERROR_CODE_API_KEY_MARKET_DENY
Idiomatic alias for Self::ERROR_CODE_API_KEY_MARKET_DENY; Debug prints the variant name.
Sourcepub const PriceTickSize: Self = Self::ERROR_CODE_PRICE_TICK_SIZE
pub const PriceTickSize: Self = Self::ERROR_CODE_PRICE_TICK_SIZE
Idiomatic alias for Self::ERROR_CODE_PRICE_TICK_SIZE; Debug prints the variant name.
Sourcepub const MinQty: Self = Self::ERROR_CODE_MIN_QTY
pub const MinQty: Self = Self::ERROR_CODE_MIN_QTY
Idiomatic alias for Self::ERROR_CODE_MIN_QTY; Debug prints the variant name.
Sourcepub const PostOnlyLimitOnly: Self = Self::ERROR_CODE_POST_ONLY_LIMIT_ONLY
pub const PostOnlyLimitOnly: Self = Self::ERROR_CODE_POST_ONLY_LIMIT_ONLY
Idiomatic alias for Self::ERROR_CODE_POST_ONLY_LIMIT_ONLY; Debug prints the variant name.
Sourcepub const BatchTooLarge: Self = Self::ERROR_CODE_BATCH_TOO_LARGE
pub const BatchTooLarge: Self = Self::ERROR_CODE_BATCH_TOO_LARGE
Idiomatic alias for Self::ERROR_CODE_BATCH_TOO_LARGE; Debug prints the variant name.
Sourcepub const ModificationRequiresReplace: Self = Self::ERROR_CODE_MODIFICATION_REQUIRES_REPLACE
pub const ModificationRequiresReplace: Self = Self::ERROR_CODE_MODIFICATION_REQUIRES_REPLACE
Idiomatic alias for Self::ERROR_CODE_MODIFICATION_REQUIRES_REPLACE; Debug prints the variant name.
Sourcepub const ConflictIdempotencyKeyReuse: Self = Self::ERROR_CODE_CONFLICT_IDEMPOTENCY_KEY_REUSE
pub const ConflictIdempotencyKeyReuse: Self = Self::ERROR_CODE_CONFLICT_IDEMPOTENCY_KEY_REUSE
Idiomatic alias for Self::ERROR_CODE_CONFLICT_IDEMPOTENCY_KEY_REUSE; Debug prints the variant name.
Idiomatic alias for Self::ERROR_CODE_MARKET_PRICE_UNAVAILABLE; Debug prints the variant name.
Sourcepub const PairNotListedYet: Self = Self::ERROR_CODE_PAIR_NOT_LISTED_YET
pub const PairNotListedYet: Self = Self::ERROR_CODE_PAIR_NOT_LISTED_YET
Idiomatic alias for Self::ERROR_CODE_PAIR_NOT_LISTED_YET; Debug prints the variant name.
Sourcepub const PairDelisted: Self = Self::ERROR_CODE_PAIR_DELISTED
pub const PairDelisted: Self = Self::ERROR_CODE_PAIR_DELISTED
Idiomatic alias for Self::ERROR_CODE_PAIR_DELISTED; Debug prints the variant name.
Sourcepub const PairCancelOnly: Self = Self::ERROR_CODE_PAIR_CANCEL_ONLY
pub const PairCancelOnly: Self = Self::ERROR_CODE_PAIR_CANCEL_ONLY
Idiomatic alias for Self::ERROR_CODE_PAIR_CANCEL_ONLY; Debug prints the variant name.
Sourcepub const PairPostOnly: Self = Self::ERROR_CODE_PAIR_POST_ONLY
pub const PairPostOnly: Self = Self::ERROR_CODE_PAIR_POST_ONLY
Idiomatic alias for Self::ERROR_CODE_PAIR_POST_ONLY; Debug prints the variant name.
Sourcepub const PairReduceOnly: Self = Self::ERROR_CODE_PAIR_REDUCE_ONLY
pub const PairReduceOnly: Self = Self::ERROR_CODE_PAIR_REDUCE_ONLY
Idiomatic alias for Self::ERROR_CODE_PAIR_REDUCE_ONLY; Debug prints the variant name.
Sourcepub const RiskLimit: Self = Self::ERROR_CODE_RISK_LIMIT
pub const RiskLimit: Self = Self::ERROR_CODE_RISK_LIMIT
Idiomatic alias for Self::ERROR_CODE_RISK_LIMIT; Debug prints the variant name.
Sourcepub const MarketHalted: Self = Self::ERROR_CODE_MARKET_HALTED
pub const MarketHalted: Self = Self::ERROR_CODE_MARKET_HALTED
Idiomatic alias for Self::ERROR_CODE_MARKET_HALTED; Debug prints the variant name.
Sourcepub const AccountUnknown: Self = Self::ERROR_CODE_ACCOUNT_UNKNOWN
pub const AccountUnknown: Self = Self::ERROR_CODE_ACCOUNT_UNKNOWN
Idiomatic alias for Self::ERROR_CODE_ACCOUNT_UNKNOWN; Debug prints the variant name.
Sourcepub const PostOnlyCross: Self = Self::ERROR_CODE_POST_ONLY_CROSS
pub const PostOnlyCross: Self = Self::ERROR_CODE_POST_ONLY_CROSS
Idiomatic alias for Self::ERROR_CODE_POST_ONLY_CROSS; Debug prints the variant name.
Sourcepub const ReduceOnlyBlocked: Self = Self::ERROR_CODE_REDUCE_ONLY_BLOCKED
pub const ReduceOnlyBlocked: Self = Self::ERROR_CODE_REDUCE_ONLY_BLOCKED
Idiomatic alias for Self::ERROR_CODE_REDUCE_ONLY_BLOCKED; Debug prints the variant name.
Sourcepub const PriceBandViolation: Self = Self::ERROR_CODE_PRICE_BAND_VIOLATION
pub const PriceBandViolation: Self = Self::ERROR_CODE_PRICE_BAND_VIOLATION
Idiomatic alias for Self::ERROR_CODE_PRICE_BAND_VIOLATION; Debug prints the variant name.
Sourcepub const MarketCapViolation: Self = Self::ERROR_CODE_MARKET_CAP_VIOLATION
pub const MarketCapViolation: Self = Self::ERROR_CODE_MARKET_CAP_VIOLATION
Idiomatic alias for Self::ERROR_CODE_MARKET_CAP_VIOLATION; Debug prints the variant name.
Sourcepub const EmptyBook: Self = Self::ERROR_CODE_EMPTY_BOOK
pub const EmptyBook: Self = Self::ERROR_CODE_EMPTY_BOOK
Idiomatic alias for Self::ERROR_CODE_EMPTY_BOOK; Debug prints the variant name.
Sourcepub const FokInsufficientLiquidity: Self = Self::ERROR_CODE_FOK_INSUFFICIENT_LIQUIDITY
pub const FokInsufficientLiquidity: Self = Self::ERROR_CODE_FOK_INSUFFICIENT_LIQUIDITY
Idiomatic alias for Self::ERROR_CODE_FOK_INSUFFICIENT_LIQUIDITY; Debug prints the variant name.
Sourcepub const OrderAlreadyTerminal: Self = Self::ERROR_CODE_ORDER_ALREADY_TERMINAL
pub const OrderAlreadyTerminal: Self = Self::ERROR_CODE_ORDER_ALREADY_TERMINAL
Idiomatic alias for Self::ERROR_CODE_ORDER_ALREADY_TERMINAL; Debug prints the variant name.
Sourcepub const TriggerPriceInvalid: Self = Self::ERROR_CODE_TRIGGER_PRICE_INVALID
pub const TriggerPriceInvalid: Self = Self::ERROR_CODE_TRIGGER_PRICE_INVALID
Idiomatic alias for Self::ERROR_CODE_TRIGGER_PRICE_INVALID; Debug prints the variant name.
Sourcepub const TriggerPriceSourceUnsupported: Self = Self::ERROR_CODE_TRIGGER_PRICE_SOURCE_UNSUPPORTED
pub const TriggerPriceSourceUnsupported: Self = Self::ERROR_CODE_TRIGGER_PRICE_SOURCE_UNSUPPORTED
Idiomatic alias for Self::ERROR_CODE_TRIGGER_PRICE_SOURCE_UNSUPPORTED; Debug prints the variant name.
Sourcepub const TrailingDistanceInvalid: Self = Self::ERROR_CODE_TRAILING_DISTANCE_INVALID
pub const TrailingDistanceInvalid: Self = Self::ERROR_CODE_TRAILING_DISTANCE_INVALID
Idiomatic alias for Self::ERROR_CODE_TRAILING_DISTANCE_INVALID; Debug prints the variant name.
Sourcepub const TriggerNotFound: Self = Self::ERROR_CODE_TRIGGER_NOT_FOUND
pub const TriggerNotFound: Self = Self::ERROR_CODE_TRIGGER_NOT_FOUND
Idiomatic alias for Self::ERROR_CODE_TRIGGER_NOT_FOUND; Debug prints the variant name.
Sourcepub const TriggerCancelRejected: Self = Self::ERROR_CODE_TRIGGER_CANCEL_REJECTED
pub const TriggerCancelRejected: Self = Self::ERROR_CODE_TRIGGER_CANCEL_REJECTED
Idiomatic alias for Self::ERROR_CODE_TRIGGER_CANCEL_REJECTED; Debug prints the variant name.
Sourcepub const TriggerStatusInvalid: Self = Self::ERROR_CODE_TRIGGER_STATUS_INVALID
pub const TriggerStatusInvalid: Self = Self::ERROR_CODE_TRIGGER_STATUS_INVALID
Idiomatic alias for Self::ERROR_CODE_TRIGGER_STATUS_INVALID; Debug prints the variant name.
Sourcepub const TriggerNotModifiable: Self = Self::ERROR_CODE_TRIGGER_NOT_MODIFIABLE
pub const TriggerNotModifiable: Self = Self::ERROR_CODE_TRIGGER_NOT_MODIFIABLE
Idiomatic alias for Self::ERROR_CODE_TRIGGER_NOT_MODIFIABLE; Debug prints the variant name.
Sourcepub const ConflictDuplicateClientTriggerId: Self = Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_TRIGGER_ID
pub const ConflictDuplicateClientTriggerId: Self = Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_TRIGGER_ID
Idiomatic alias for Self::ERROR_CODE_CONFLICT_DUPLICATE_CLIENT_TRIGGER_ID; Debug prints the variant name.
Sourcepub const MaxSlippageInvalid: Self = Self::ERROR_CODE_MAX_SLIPPAGE_INVALID
pub const MaxSlippageInvalid: Self = Self::ERROR_CODE_MAX_SLIPPAGE_INVALID
Idiomatic alias for Self::ERROR_CODE_MAX_SLIPPAGE_INVALID; Debug prints the variant name.
Sourcepub const StaleQuote: Self = Self::ERROR_CODE_STALE_QUOTE
pub const StaleQuote: Self = Self::ERROR_CODE_STALE_QUOTE
Idiomatic alias for Self::ERROR_CODE_STALE_QUOTE; Debug prints the variant name.
Sourcepub const ValidationError: Self = Self::ERROR_CODE_VALIDATION_ERROR
pub const ValidationError: Self = Self::ERROR_CODE_VALIDATION_ERROR
Idiomatic alias for Self::ERROR_CODE_VALIDATION_ERROR; Debug prints the variant name.
Sourcepub const Overloaded: Self = Self::ERROR_CODE_OVERLOADED
pub const Overloaded: Self = Self::ERROR_CODE_OVERLOADED
Idiomatic alias for Self::ERROR_CODE_OVERLOADED; Debug prints the variant name.
Sourcepub const MaxQuoteDebitTooSmall: Self = Self::ERROR_CODE_MAX_QUOTE_DEBIT_TOO_SMALL
pub const MaxQuoteDebitTooSmall: Self = Self::ERROR_CODE_MAX_QUOTE_DEBIT_TOO_SMALL
Idiomatic alias for Self::ERROR_CODE_MAX_QUOTE_DEBIT_TOO_SMALL; Debug prints the variant name.