Modules
Structs
- Create
Internal Transfer Request - CreateInternalTransferRequest creates or returns one accepted Trading to Trading internal transfer for the authenticated source account.
- Create
Internal Transfer Request Owned View - Self-contained,
'staticowned view of aCreateInternalTransferRequestmessage. - Create
Internal Transfer Request View - CreateInternalTransferRequest creates or returns one accepted Trading to Trading internal transfer for the authenticated source account.
- Create
Internal Transfer Response - CreateInternalTransferResponse returns the accepted request and transfer identifiers for later correlation.
- Create
Internal Transfer Response Owned View - Self-contained,
'staticowned view of aCreateInternalTransferResponsemessage. - Create
Internal Transfer Response View - CreateInternalTransferResponse returns the accepted request and transfer identifiers for later correlation.
- Resolved
Destination - ResolvedDestination describes the normalized transfer destination selected by the server after public-id / smart-account resolution.
- Resolved
Destination Owned View - Self-contained,
'staticowned view of aResolvedDestinationmessage. - Resolved
Destination View - ResolvedDestination describes the normalized transfer destination selected by the server after public-id / smart-account resolution.
Enums
- Internal
Transfer Status - InternalTransferStatus is the public user-facing status for an internal transfer request.
Functions
- register_
types - Register this package’s
Anytype entries and extension entries.